@@ -142,6 +142,7 @@ func main() {
 		log.Log.Reason(err).Error("monitoring virt-launcher failed")
 		os.Exit(1)
 	}
+	log.Log.Info("virt-launcher-monitor: Exiting...")
 
 	os.Exit(exitCode)
 }
@@ -194,14 +195,13 @@ func RunAndMonitor(containerDiskDir, uid string) (int, error) {
 				if err != nil {
 					log.Log.Reason(err).Errorf("Failed to reap process %d", wpid)
 				}
-
-				log.Log.Infof("Reaped pid %d with status %d", wpid, int(wstatus))
 				if wpid == cmd.Process.Pid {
+					log.Log.Infof("Reaped Launcher main pid")
 					exitStatus <- wstatus.ExitStatus()
 				}
-
+				log.Log.Infof("Reaped pid %d with status %d", wpid, int(wstatus))
 			default:
-				log.Log.V(3).Log("signalling virt-launcher to shut down")
+				log.Log.Infof("signalling virt-launcher to shut down")
 				err := cmd.Process.Signal(syscall.SIGTERM)
 				sig.Signal()
 				if err != nil {
@@ -230,6 +230,7 @@ func RunAndMonitor(containerDiskDir, uid string) (int, error) {
 	}
 
 	if pid > 0 {
+		log.Log.Infof("Killing QEMU gracefully.")
 		p, err := os.FindProcess(pid)
 		if err != nil {
 			return 1, err
