@@ -10,12 +10,12 @@ rm -f vendor/libvirt.org/go/libvirt/BUILD.bazel
 # generate BUILD files
 bazel run \
     --config=${ARCHITECTURE} \
-    //:gazelle -- -exclude vendor/google.golang.org/grpc --exclude cluster-up
+    //:gazelle -- -exclude vendor/google.golang.org/grpc --exclude kubevirtci/cluster-up
 
 # inject changes to libvirt BUILD file
 bazel run \
     --config=${ARCHITECTURE} \
-    -- @com_github_bazelbuild_buildtools//buildozer 'add cdeps //:libvirt-libs' //vendor/libvirt.org/go/libvirt:go_default_library
+    -- :buildozer 'add cdeps //:libvirt-libs' //vendor/libvirt.org/go/libvirt:go_default_library
 # align BAZEL files to a single format
 bazel run \
     --config=${ARCHITECTURE} \
