@@ -19,9 +19,22 @@
 
 package virt_api
 
-import "github.com/machadovilaca/operator-observability/pkg/operatormetrics"
+import (
+	"github.com/machadovilaca/operator-observability/pkg/operatormetrics"
+
+	"kubevirt.io/kubevirt/pkg/monitoring/metrics/common/client"
+	"kubevirt.io/kubevirt/pkg/monitoring/metrics/common/workqueue"
+)
 
 func SetupMetrics() error {
+	if err := client.SetupMetrics(); err != nil {
+		return err
+	}
+
+	if err := workqueue.SetupMetrics(); err != nil {
+		return err
+	}
+
 	return operatormetrics.RegisterMetrics(
 		connectionMetrics,
 		vmMetrics,
