@@ -257,6 +257,7 @@ var _ = Describe("VMI Stats Collector", func() {
 				{
 					ObjectMeta: metav1.ObjectMeta{
 						Name:        "running",
+						Namespace:   "test-ns",
 						Annotations: annotations,
 					},
 				},
@@ -293,6 +294,7 @@ var _ = Describe("VMI Stats Collector", func() {
 				{
 					ObjectMeta: metav1.ObjectMeta{
 						Name:        "running",
+						Namespace:   "test-ns",
 						Annotations: annotations,
 					},
 				},
@@ -367,14 +369,14 @@ var _ = Describe("VMI Stats Collector", func() {
 			}
 		},
 			Entry("no interfaces", [][]string{}),
-			Entry("one interface", [][]string{{"default", "192.168.1.2", "InternalIP"}}),
+			Entry("one interface", [][]string{{"default", "", "192.168.1.2", "ExternalInterface"}}),
 			Entry("two interfaces", [][]string{
-				{"networkA", "170.170.170.170", "InternalIP"},
-				{"networkB", "180.180.180.180", "InternalIP"},
+				{"networkA", "", "170.170.170.170", "ExternalInterface"},
+				{"networkB", "", "180.180.180.180", "ExternalInterface"},
 			}),
 		)
 
-		It("should not create metric for an interface with empty IP address", func() {
+		It("should create metric for interfaces with empty name, but with interface name", func() {
 			vmi := &k6tv1.VirtualMachineInstance{
 				ObjectMeta: metav1.ObjectMeta{
 					Namespace: "test-ns",
@@ -384,16 +386,14 @@ var _ = Describe("VMI Stats Collector", func() {
 					NodeName: "testNode",
 					Interfaces: []k6tv1.VirtualMachineInstanceNetworkInterface{
 						{
-							InfoSource: "domain",
-							Name:       "default",
-							IP:         "10.244.140.86",
+							InfoSource:    "guest-agent",
+							InterfaceName: "br-int",
+							MAC:           "00:00:00:00:00:01",
 						},
 						{
-							InfoSource: "domain, multus-status",
-							Name:       "networkA",
-						},
-						{
-							InfoSource: "domain, multus-status",
+							InfoSource:    "guest-agent",
+							InterfaceName: "ovs-system",
+							MAC:           "00:00:00:00:00:02",
 						},
 					},
 				},
@@ -401,8 +401,45 @@ var _ = Describe("VMI Stats Collector", func() {
 
 			metrics := collectVMIInterfacesInfo(vmi)
 			Expect(metrics).To(HaveLen(2))
-			Expect(metrics[0].Labels).To(Equal([]string{"testNode", "test-ns", "testvmi", "default", "10.244.140.86", "InternalIP"}))
-			Expect(metrics[1].Labels).To(Equal([]string{"testNode", "test-ns", "testvmi", "networkA", "", "InternalIP"}))
+			Expect(metrics[0].Labels).To(Equal([]string{"testNode", "test-ns", "testvmi", "", "br-int", "", "SystemInterface"}))
+			Expect(metrics[1].Labels).To(Equal([]string{"testNode", "test-ns", "testvmi", "", "ovs-system", "", "SystemInterface"}))
+		})
+
+		It("should not create metric for an interface with empty IP address, name and interface name", func() {
+			vmi := &k6tv1.VirtualMachineInstance{
+				ObjectMeta: metav1.ObjectMeta{
+					Namespace: "test-ns",
+					Name:      "testvmi",
+				},
+				Status: k6tv1.VirtualMachineInstanceStatus{
+					NodeName: "testNode",
+					Interfaces: []k6tv1.VirtualMachineInstanceNetworkInterface{
+						{
+							InfoSource:    "domain, guest-agent, multus-status",
+							Name:          "net-0",
+							InterfaceName: "br-ex",
+							IP:            "10.11.126.126",
+						},
+						{
+							InfoSource:    "guest-agent",
+							InterfaceName: "ovs-system",
+						},
+						{
+							InfoSource:    "guest-agent",
+							InterfaceName: "br-int",
+						},
+						{
+							InfoSource: "guest-agent",
+						},
+					},
+				},
+			}
+
+			metrics := collectVMIInterfacesInfo(vmi)
+			Expect(metrics).To(HaveLen(3))
+			Expect(metrics[0].Labels).To(Equal([]string{"testNode", "test-ns", "testvmi", "net-0", "br-ex", "10.11.126.126", "ExternalInterface"}))
+			Expect(metrics[1].Labels).To(Equal([]string{"testNode", "test-ns", "testvmi", "", "ovs-system", "", "SystemInterface"}))
+			Expect(metrics[2].Labels).To(Equal([]string{"testNode", "test-ns", "testvmi", "", "br-int", "", "SystemInterface"}))
 		})
 	})
 
@@ -584,8 +621,9 @@ func interfacesFor(values [][]string) []k6tv1.VirtualMachineInstanceNetworkInter
 	interfaces := make([]k6tv1.VirtualMachineInstanceNetworkInterface, len(values))
 	for i, v := range values {
 		interfaces[i] = k6tv1.VirtualMachineInstanceNetworkInterface{
-			Name: v[0],
-			IP:   v[1],
+			Name:          v[0],
+			InterfaceName: v[1],
+			IP:            v[2],
 		}
 	}
 	return interfaces
@@ -623,14 +661,14 @@ func setupTestCollector() {
 	clusterPreferenceInformer, _ := testutils.NewFakeInformerFor(&instancetypev1beta1.VirtualMachineClusterPreference{})
 
 	_ = instanceTypeInformer.GetStore().Add(&instancetypev1beta1.VirtualMachineInstancetype{
-		ObjectMeta: newObjectMetaForInstancetypes("i-managed", "kubevirt.io"),
+		ObjectMeta: newObjectMetaForInstancetypes("i-managed", "test-ns", "kubevirt.io"),
 	})
 	_ = instanceTypeInformer.GetStore().Add(&instancetypev1beta1.VirtualMachineInstancetype{
-		ObjectMeta: newObjectMetaForInstancetypes("i-unmanaged", "some-user"),
+		ObjectMeta: newObjectMetaForInstancetypes("i-unmanaged", "test-ns", "some-user"),
 	})
 
 	_ = clusterInstanceTypeInformer.GetStore().Add(&instancetypev1beta1.VirtualMachineClusterInstancetype{
-		ObjectMeta: newObjectMetaForInstancetypes("ci-managed", "kubevirt.io"),
+		ObjectMeta: newObjectMetaForInstancetypes("ci-managed", "", "kubevirt.io"),
 		Spec: instancetypev1beta1.VirtualMachineInstancetypeSpec{
 			CPU: instancetypev1beta1.CPUInstancetype{
 				Guest: 2,
@@ -641,18 +679,18 @@ func setupTestCollector() {
 		},
 	})
 	_ = clusterInstanceTypeInformer.GetStore().Add(&instancetypev1beta1.VirtualMachineClusterInstancetype{
-		ObjectMeta: newObjectMetaForInstancetypes("ci-unmanaged", ""),
+		ObjectMeta: newObjectMetaForInstancetypes("ci-unmanaged", "", ""),
 	})
 
 	_ = preferenceInformer.GetStore().Add(&instancetypev1beta1.VirtualMachinePreference{
-		ObjectMeta: newObjectMetaForInstancetypes("p-managed", "kubevirt.io"),
+		ObjectMeta: newObjectMetaForInstancetypes("p-managed", "test-ns", "kubevirt.io"),
 	})
 	_ = preferenceInformer.GetStore().Add(&instancetypev1beta1.VirtualMachinePreference{
-		ObjectMeta: newObjectMetaForInstancetypes("p-unmanaged", "some-vendor.com"),
+		ObjectMeta: newObjectMetaForInstancetypes("p-unmanaged", "test-ns", "some-vendor.com"),
 	})
 
 	_ = clusterPreferenceInformer.GetStore().Add(&instancetypev1beta1.VirtualMachineClusterPreference{
-		ObjectMeta: newObjectMetaForInstancetypes("cp-managed", "kubevirt.io"),
+		ObjectMeta: newObjectMetaForInstancetypes("cp-managed", "", "kubevirt.io"),
 	})
 
 	instancetypeMethods = &instancetype.InstancetypeMethods{
@@ -681,11 +719,17 @@ func setupTestCollector() {
 	})
 }
 
-func newObjectMetaForInstancetypes(name, vendor string) metav1.ObjectMeta {
-	return metav1.ObjectMeta{
+func newObjectMetaForInstancetypes(name, namespace, vendor string) metav1.ObjectMeta {
+	om := metav1.ObjectMeta{
 		Name:   name,
 		Labels: map[string]string{instancetypeVendorLabel: vendor},
 	}
+
+	if namespace != "" {
+		om.Namespace = namespace
+	}
+
+	return om
 }
 
 func newPodMetaForInformer(name, namespace, createdByUID string) metav1.ObjectMeta {
