@@ -21,7 +21,8 @@ package downwardapi
 
 import (
 	"encoding/json"
-	"sort"
+	"maps"
+	"slices"
 
 	networkv1 "github.com/k8snetworkplumbingwg/network-attachment-definition-client/pkg/apis/k8s.cni.cncf.io/v1"
 
@@ -50,23 +51,11 @@ func generateNetworkInfo(networkDeviceInfoMap map[string]*networkv1.DeviceInfo)
 	var downwardAPIInterfaces []Interface
 
 	// Sort keys of the map with to get deterministic order
-	netNames := mapKeys(networkDeviceInfoMap)
-	sort.Strings(netNames)
-
-	for _, networkName := range netNames {
+	sortedNetNames := slices.Sorted(maps.Keys(networkDeviceInfoMap))
+	for _, networkName := range sortedNetNames {
 		deviceInfo := networkDeviceInfoMap[networkName]
 		downwardAPIInterfaces = append(downwardAPIInterfaces, Interface{Network: networkName, DeviceInfo: deviceInfo})
 	}
 	networkInfo := NetworkInfo{Interfaces: downwardAPIInterfaces}
 	return networkInfo
 }
-
-func mapKeys(m map[string]*networkv1.DeviceInfo) []string {
-	keys := make([]string, 0, len(m))
-
-	for k := range m {
-		keys = append(keys, k)
-	}
-
-	return keys
-}
