@@ -48,7 +48,6 @@ type cacheCreator interface {
 
 type clusterConfigurer interface {
 	GetNetworkBindings() map[string]v1.InterfaceBindingPlugin
-	DynamicPodInterfaceNamingEnabled() bool
 }
 
 type NetConf struct {
@@ -110,12 +109,6 @@ func (c *NetConf) Setup(vmi *v1.VirtualMachineInstance, networks []v1.Network, l
 		ownerID = util.NonRootUID
 	}
 	queuesCapacity := int(converter.NetworkQueuesCapacity(vmi))
-
-	vmiIfacesStatuses := vmi.Status.Interfaces
-	if !c.clusterConfigurer.DynamicPodInterfaceNamingEnabled() {
-		vmiIfacesStatuses = nil
-	}
-
 	netpod := netpod.NewNetPod(
 		networks,
 		vmispec.FilterInterfacesByNetworks(vmi.Spec.Domain.Devices.Interfaces, networks),
@@ -128,7 +121,7 @@ func (c *NetConf) Setup(vmi *v1.VirtualMachineInstance, networks []v1.Network, l
 		netpod.WithCacheCreator(c.cacheCreator),
 		netpod.WithBindingPlugins(c.clusterConfigurer.GetNetworkBindings()),
 		netpod.WithLogger(log.Log.Object(vmi)),
-		netpod.WithVMIIfaceStatuses(vmiIfacesStatuses),
+		netpod.WithVMIIfaceStatuses(vmi.Status.Interfaces),
 	)
 
 	if err := netpod.Setup(); err != nil {
