@@ -14,7 +14,6 @@
  * limitations under the License.
  *
  * Copyright 2023 Red Hat, Inc.
- *
  */
 
 package netpod_test
@@ -331,6 +330,12 @@ var _ = Describe("netpod", func() {
 					NextHopAddress:   defaultGatewayIP4Address,
 					TableID:          0,
 				},
+				// Static route to a wider subnet containing the local subnet
+				{
+					Destination:      "10.222.0.0/16",
+					NextHopInterface: "eth0",
+					TableID:          0,
+				},
 			}},
 		}}
 
@@ -418,6 +423,7 @@ var _ = Describe("netpod", func() {
 			podIfaceOrignalMAC,
 			defaultGatewayIP4Address,
 			"192.168.1.0/24",
+			"10.222.0.0/16",
 		)
 		Expect(err).NotTo(HaveOccurred())
 		Expect(cache.ReadDHCPInterfaceCache(&baseCacheCreator, "0", "eth0")).To(Equal(expDHCPConfig))
@@ -426,6 +432,163 @@ var _ = Describe("netpod", func() {
 		}))
 	})
 
+	It("setup bridge binding with IP custom primary interface name", func() {
+		const (
+			defaultGatewayIP4Address = "10.222.222.254"
+			podIfaceOrignalMAC       = "12:34:56:78:90:ab"
+			customPrimaryIfaceName   = "cust-iface"
+		)
+		nmstatestub := nmstateStub{status: nmstate.Status{
+			Interfaces: []nmstate.Interface{{
+				Name:       customPrimaryIfaceName,
+				Index:      0,
+				TypeName:   nmstate.TypeVETH,
+				State:      nmstate.IfaceStateUp,
+				MacAddress: podIfaceOrignalMAC,
+				MTU:        1500,
+				IPv4: nmstate.IP{
+					Enabled: pointer.P(true),
+					Address: []nmstate.IPAddress{{
+						IP:        primaryIPv4Address,
+						PrefixLen: 30,
+					}},
+				},
+				IPv6: nmstate.IP{
+					Enabled: pointer.P(true),
+					Address: []nmstate.IPAddress{{
+						IP:        primaryIPv6Address,
+						PrefixLen: 64,
+					}},
+				},
+			}},
+			Routes: nmstate.Routes{Running: []nmstate.Route{
+				// Default Route
+				{
+					Destination:      "0.0.0.0/0",
+					NextHopInterface: customPrimaryIfaceName,
+					NextHopAddress:   defaultGatewayIP4Address,
+					TableID:          0,
+				},
+				// Local Route (should be ignored)
+				{
+					Destination:      "10.222.222.0/30",
+					NextHopInterface: customPrimaryIfaceName,
+					NextHopAddress:   primaryIPv4Address,
+					TableID:          0,
+				},
+				// Static Route
+				{
+					Destination:      "192.168.1.0/24",
+					NextHopInterface: customPrimaryIfaceName,
+					NextHopAddress:   defaultGatewayIP4Address,
+					TableID:          0,
+				},
+				// Static route to a wider subnet containing the local subnet
+				{
+					Destination:      "10.222.0.0/16",
+					NextHopInterface: customPrimaryIfaceName,
+					TableID:          0,
+				},
+			}},
+		}}
+
+		vmiIface := v1.Interface{
+			Name:                   defaultPodNetworkName,
+			InterfaceBindingMethod: v1.InterfaceBindingMethod{Bridge: &v1.InterfaceBridge{}},
+		}
+		vmiIfaceStatuses := []v1.VirtualMachineInstanceNetworkInterface{
+			{Name: defaultPodNetworkName, PodInterfaceName: customPrimaryIfaceName},
+		}
+		netPod := netpod.NewNetPod(
+			[]v1.Network{*v1.DefaultPodNetwork()},
+			[]v1.Interface{vmiIface},
+			vmiUID, 0, 0, 0, state,
+			netpod.WithNMStateAdapter(&nmstatestub),
+			netpod.WithCacheCreator(&baseCacheCreator),
+			netpod.WithVMIIfaceStatuses(vmiIfaceStatuses),
+		)
+		Expect(netPod.Setup()).To(Succeed())
+		Expect(nmstatestub.spec).To(Equal(
+			nmstate.Spec{
+				Interfaces: []nmstate.Interface{
+					{
+						Name:     "k6t-cust-iface",
+						TypeName: nmstate.TypeBridge,
+						State:    nmstate.IfaceStateUp,
+						Ethtool:  nmstate.Ethtool{Feature: nmstate.Feature{TxChecksum: pointer.P(false)}},
+						IPv4: nmstate.IP{
+							Enabled: pointer.P(true),
+							Address: []nmstate.IPAddress{{IP: "169.254.75.10", PrefixLen: 32}},
+						},
+						Metadata: &nmstate.IfaceMetadata{Pid: 0, NetworkName: defaultPodNetworkName},
+					},
+					{
+						Name:        "cust-iface-nic",
+						Index:       0,
+						CopyMacFrom: "k6t-cust-iface",
+						Controller:  "k6t-cust-iface",
+						State:       nmstate.IfaceStateUp,
+						IPv4:        ipDisabled,
+						IPv6:        ipDisabled,
+						LinuxStack:  nmstate.LinuxIfaceStack{PortLearning: pointer.P(false)},
+						Metadata:    &nmstate.IfaceMetadata{Pid: 0, NetworkName: defaultPodNetworkName},
+					},
+					{
+						Name:       "tap0",
+						TypeName:   nmstate.TypeTap,
+						State:      nmstate.IfaceStateUp,
+						MTU:        1500,
+						Controller: "k6t-cust-iface",
+						Tap:        &nmstate.TapDevice{Queues: 0, UID: 0, GID: 0},
+						Metadata:   &nmstate.IfaceMetadata{Pid: 0, NetworkName: defaultPodNetworkName},
+					},
+					{
+						Name:       customPrimaryIfaceName,
+						TypeName:   nmstate.TypeDummy,
+						MacAddress: podIfaceOrignalMAC,
+						MTU:        1500,
+						IPv4: nmstate.IP{
+							Enabled: pointer.P(true),
+							Address: []nmstate.IPAddress{{
+								IP:        primaryIPv4Address,
+								PrefixLen: 30,
+							}},
+						},
+						IPv6: nmstate.IP{
+							Enabled: pointer.P(true),
+							Address: []nmstate.IPAddress{{
+								IP:        primaryIPv6Address,
+								PrefixLen: 64,
+							}},
+						},
+						Metadata: &nmstate.IfaceMetadata{Pid: 0, NetworkName: defaultPodNetworkName},
+					},
+				},
+				LinuxStack: nmstate.LinuxStack{IPv4: nmstate.LinuxStackIP4{
+					ArpIgnore: pointer.P(procsys.ARPReplyMode1),
+				}},
+			}),
+		)
+		Expect(cache.ReadPodInterfaceCache(&baseCacheCreator, vmiUID, defaultPodNetworkName)).To(Equal(&cache.PodIfaceCacheData{
+			Iface:  &vmiIface,
+			PodIP:  primaryIPv4Address,
+			PodIPs: []string{primaryIPv4Address, primaryIPv6Address},
+		}))
+
+		expDHCPConfig, err := expectedDHCPConfig(
+			"10.222.222.1/30",
+			podIfaceOrignalMAC,
+			defaultGatewayIP4Address,
+			"192.168.1.0/24",
+			"10.222.0.0/16",
+		)
+		Expect(err).NotTo(HaveOccurred())
+		Expect(cache.ReadDHCPInterfaceCache(&baseCacheCreator, "0", customPrimaryIfaceName)).To(Equal(expDHCPConfig))
+		Expect(cache.ReadDomainInterfaceCache(&baseCacheCreator, "0", defaultPodNetworkName)).To(Equal(&api.Interface{
+			MAC: &api.MAC{MAC: podIfaceOrignalMAC},
+		}))
+	})
+
 	It("setup bridge binding without IP", func() {
 		const podIfaceOrignalMAC = "12:34:56:78:90:ab"
 		const linklocalIPv6Address = "fe80::1"
@@ -1614,6 +1777,125 @@ var _ = Describe("netpod", func() {
 		_, err = cache.ReadDomainInterfaceCache(&baseCacheCreator, "0", testNet2)
 		Expect(err).To(HaveOccurred())
 	})
+
+	When("binding plugin with managedTap domainAttachmentType", func() {
+		const managedTap = "managed-tap"
+
+		It("fails setup config when pod interface is missing", func() {
+			netPod := netpod.NewNetPod(
+				[]v1.Network{*v1.DefaultPodNetwork()},
+				[]v1.Interface{{Name: defaultPodNetworkName, Binding: &v1.PluginBinding{Name: managedTap}}},
+				vmiUID, 0, 0, 0, state,
+				netpod.WithNMStateAdapter(&nmstateStub{status: nmstate.Status{
+					Interfaces: []nmstate.Interface{{Name: "other0"}},
+				}}),
+				netpod.WithCacheCreator(&baseCacheCreator),
+				netpod.WithBindingPlugins(map[string]v1.InterfaceBindingPlugin{
+					managedTap: {DomainAttachmentType: v1.ManagedTap},
+				}),
+			)
+			err := netPod.Setup()
+			Expect(err).To(MatchError(ContainSubstring("pod link (eth0) is missing")))
+		})
+
+		It("setup succeeds", func() {
+			const podIfaceOrignalMAC = "12:34:56:78:90:ab"
+
+			nmstatestub := nmstateStub{status: nmstate.Status{
+				Interfaces: []nmstate.Interface{{
+					Name:       "eth0",
+					Index:      0,
+					TypeName:   nmstate.TypeVETH,
+					State:      nmstate.IfaceStateUp,
+					MacAddress: podIfaceOrignalMAC,
+					MTU:        1500,
+					IPv4: nmstate.IP{
+						Enabled: pointer.P(true),
+						Address: []nmstate.IPAddress{{
+							IP:        primaryIPv4Address,
+							PrefixLen: 30,
+						}},
+					},
+					IPv6: nmstate.IP{
+						Enabled: pointer.P(true),
+						Address: []nmstate.IPAddress{{
+							IP:        primaryIPv6Address,
+							PrefixLen: 64,
+						}},
+					},
+				}},
+			}}
+
+			vmiIface := v1.Interface{Name: defaultPodNetworkName, Binding: &v1.PluginBinding{Name: managedTap}}
+			netPod := netpod.NewNetPod(
+				[]v1.Network{*v1.DefaultPodNetwork()},
+				[]v1.Interface{vmiIface},
+				vmiUID, 0, 0, 0, state,
+				netpod.WithNMStateAdapter(&nmstatestub),
+				netpod.WithCacheCreator(&baseCacheCreator),
+				netpod.WithBindingPlugins(map[string]v1.InterfaceBindingPlugin{
+					managedTap: {DomainAttachmentType: v1.ManagedTap},
+				}),
+			)
+			Expect(netPod.Setup()).To(Succeed())
+			Expect(nmstatestub.spec).To(Equal(
+				nmstate.Spec{
+					Interfaces: []nmstate.Interface{
+						{
+							Name:     "k6t-eth0",
+							TypeName: nmstate.TypeBridge,
+							State:    nmstate.IfaceStateUp,
+							Ethtool:  nmstate.Ethtool{Feature: nmstate.Feature{TxChecksum: pointer.P(false)}},
+							Metadata: &nmstate.IfaceMetadata{Pid: 0, NetworkName: defaultPodNetworkName},
+						},
+						{
+							Name:        "eth0-nic",
+							Index:       0,
+							State:       nmstate.IfaceStateUp,
+							CopyMacFrom: "k6t-eth0",
+							Controller:  "k6t-eth0",
+							IPv4:        ipDisabled,
+							IPv6:        ipDisabled,
+							LinuxStack:  nmstate.LinuxIfaceStack{PortLearning: pointer.P(false)},
+							Metadata:    &nmstate.IfaceMetadata{Pid: 0, NetworkName: defaultPodNetworkName},
+						},
+						{
+							Name:       "tap0",
+							TypeName:   nmstate.TypeTap,
+							State:      nmstate.IfaceStateUp,
+							MTU:        1500,
+							Controller: "k6t-eth0",
+							Tap:        &nmstate.TapDevice{Queues: 0, UID: 0, GID: 0},
+							Metadata:   &nmstate.IfaceMetadata{Pid: 0, NetworkName: defaultPodNetworkName},
+						},
+						{
+							Name:       "eth0",
+							TypeName:   nmstate.TypeDummy,
+							MacAddress: podIfaceOrignalMAC,
+							MTU:        1500,
+							IPv4: nmstate.IP{
+								Enabled: pointer.P(true),
+								Address: []nmstate.IPAddress{{IP: primaryIPv4Address, PrefixLen: 30}},
+							},
+							IPv6: nmstate.IP{
+								Enabled: pointer.P(true),
+								Address: []nmstate.IPAddress{{IP: primaryIPv6Address, PrefixLen: 64}},
+							},
+							Metadata: &nmstate.IfaceMetadata{Pid: 0, NetworkName: defaultPodNetworkName},
+						},
+					},
+					LinuxStack: nmstate.LinuxStack{IPv4: nmstate.LinuxStackIP4{
+						ArpIgnore: pointer.P(procsys.ARPReplyMode1),
+					}},
+				},
+			))
+			Expect(cache.ReadPodInterfaceCache(&baseCacheCreator, vmiUID, defaultPodNetworkName)).To(Equal(&cache.PodIfaceCacheData{
+				Iface:  &vmiIface,
+				PodIP:  primaryIPv4Address,
+				PodIPs: []string{primaryIPv4Address, primaryIPv6Address},
+			}))
+		})
+	})
 })
 
 type nmstateStub struct {
@@ -1675,7 +1957,7 @@ func (c *tempCacheCreator) New(filePath string) *cache.Cache {
 	return cache.NewCustomCache(filePath, kfs.NewWithRootPath(c.tmpDir))
 }
 
-func expectedDHCPConfig(podIfaceCIDR, podIfaceMAC, defaultGW, staticRouteDst string) (*cache.DHCPConfig, error) {
+func expectedDHCPConfig(podIfaceCIDR, podIfaceMAC, defaultGW, staticRouteDst, staticRouteToWiderSubnet string) (*cache.DHCPConfig, error) {
 	ipv4, err := vishnetlink.ParseAddr(podIfaceCIDR)
 	if err != nil {
 		return nil, err
@@ -1688,9 +1970,16 @@ func expectedDHCPConfig(podIfaceCIDR, podIfaceMAC, defaultGW, staticRouteDst str
 	if err != nil {
 		return nil, err
 	}
+
+	staticRouteToWiderSubnetDest, err := vishnetlink.ParseAddr(staticRouteToWiderSubnet)
+	if err != nil {
+		return nil, err
+	}
+
 	routes := []vishnetlink.Route{
 		{Gw: net.ParseIP(defaultGW)},
 		{Dst: destAddr.IPNet, Gw: net.ParseIP(defaultGW)},
+		{Dst: staticRouteToWiderSubnetDest.IPNet, Gw: nil},
 	}
 	return &cache.DHCPConfig{
 		IP:           *ipv4,
