@@ -41,6 +41,7 @@ import (
 	"kubevirt.io/kubevirt/pkg/apimachinery/patch"
 	"kubevirt.io/kubevirt/pkg/controller"
 	"kubevirt.io/kubevirt/pkg/pointer"
+	"kubevirt.io/kubevirt/pkg/tpm"
 	"kubevirt.io/kubevirt/pkg/util"
 	virtconfig "kubevirt.io/kubevirt/pkg/virt-config"
 )
@@ -267,12 +268,6 @@ func CurrentPVCName(vmi *corev1.VirtualMachineInstance) string {
 	return ""
 }
 
-func HasPersistentTPMDevice(vmiSpec *corev1.VirtualMachineInstanceSpec) bool {
-	return vmiSpec.Domain.Devices.TPM != nil &&
-		vmiSpec.Domain.Devices.TPM.Persistent != nil &&
-		*vmiSpec.Domain.Devices.TPM.Persistent
-}
-
 func HasPersistentEFI(vmiSpec *corev1.VirtualMachineInstanceSpec) bool {
 	return vmiSpec.Domain.Firmware != nil &&
 		vmiSpec.Domain.Firmware.Bootloader != nil &&
@@ -282,14 +277,14 @@ func HasPersistentEFI(vmiSpec *corev1.VirtualMachineInstanceSpec) bool {
 }
 
 func IsBackendStorageNeededForVMI(vmiSpec *corev1.VirtualMachineInstanceSpec) bool {
-	return HasPersistentTPMDevice(vmiSpec) || HasPersistentEFI(vmiSpec)
+	return tpm.HasPersistentDevice(vmiSpec) || HasPersistentEFI(vmiSpec)
 }
 
 func IsBackendStorageNeededForVM(vm *corev1.VirtualMachine) bool {
 	if vm.Spec.Template == nil {
 		return false
 	}
-	return HasPersistentTPMDevice(&vm.Spec.Template.Spec) || HasPersistentEFI(&vm.Spec.Template.Spec)
+	return tpm.HasPersistentDevice(&vm.Spec.Template.Spec) || HasPersistentEFI(&vm.Spec.Template.Spec)
 }
 
 // MigrationHandoff runs at the end of a successful live migration.
