@@ -38,6 +38,7 @@ import (
 	"kubevirt.io/client-go/kubecli"
 	cdiv1 "kubevirt.io/containerized-data-importer-api/pkg/apis/core/v1beta1"
 
+	"kubevirt.io/kubevirt/pkg/libvmi"
 	"kubevirt.io/kubevirt/pkg/pointer"
 	"kubevirt.io/kubevirt/pkg/testutils"
 	virtconfig "kubevirt.io/kubevirt/pkg/virt-config"
@@ -253,43 +254,6 @@ var _ = Describe("Backend Storage", func() {
 		})
 	})
 
-	Context("createPVC", func() {
-		var k8sClient *k8sfake.Clientset
-		const (
-			nsName  = "testns"
-			vmiName = "testvmi"
-			pvcName = "persistent-state-for-" + vmiName
-		)
-
-		BeforeEach(func() {
-			k8sClient = k8sfake.NewSimpleClientset()
-			virtClient.EXPECT().CoreV1().Return(k8sClient.CoreV1()).AnyTimes()
-		})
-
-		It("Should create a PVC with the correct labels", func() {
-			vmi := &virtv1.VirtualMachineInstance{
-				ObjectMeta: k8smetav1.ObjectMeta{
-					Name:      vmiName,
-					Namespace: nsName,
-				},
-			}
-
-			sc := storagev1.StorageClass{
-				ObjectMeta: k8smetav1.ObjectMeta{
-					Name:        "sc",
-					Annotations: map[string]string{"storageclass.kubernetes.io/is-default-class": "true"},
-				},
-			}
-			err := storageClassStore.Add(&sc)
-			Expect(err).NotTo(HaveOccurred())
-
-			pvc, err := backendStorage.createPVC(vmi, map[string]string{})
-			Expect(err).NotTo(HaveOccurred())
-			Expect(pvc).NotTo(BeNil())
-			Expect(pvc.Labels).To(HaveKeyWithValue(LabelApplyStorageProfile, "true"))
-		})
-	})
-
 	Context("Legacy PVCs", func() {
 		var k8sClient *k8sfake.Clientset
 
@@ -326,7 +290,34 @@ var _ = Describe("Backend Storage", func() {
 			Expect(pvc).NotTo(BeNil())
 			pvc, err = k8sClient.CoreV1().PersistentVolumeClaims(nsName).Get(context.TODO(), pvcName, k8smetav1.GetOptions{})
 			Expect(err).NotTo(HaveOccurred())
-			Expect(pvc.Labels).To(HaveKeyWithValue(PVCPrefix, vmiName))
+			Expect(pvc.Labels).To(HaveKeyWithValue("persistent-state-for", vmiName))
 		})
 	})
+	Context("IsBackendStorageNeeded", func() {
+		var vm *virtv1.VirtualMachine
+
+		BeforeEach(func() {
+			vm = libvmi.NewVirtualMachine(libvmi.New(libvmi.WithUefi(false)))
+			vm.Spec.Template.Spec.Domain.Devices.TPM = &virtv1.TPMDevice{}
+		})
+
+		DescribeTable("should", func(expected bool, alter func(vm *virtv1.VirtualMachine)) {
+			alter(vm)
+			Expect(IsBackendStorageNeededForVM(vm)).To(Equal(expected))
+			Expect(IsBackendStorageNeededForVMI(&vm.Spec.Template.Spec)).To(Equal(expected))
+		},
+			Entry("be false when no persistent feature is set", false, func(_ *virtv1.VirtualMachine) {
+			}),
+			Entry("be true when persistent TPM is set", true, func(vm *virtv1.VirtualMachine) {
+				vm.Spec.Template.Spec.Domain.Devices.TPM.Persistent = pointer.P(true)
+			}),
+			Entry("be true when persistent EFI is set", true, func(vm *virtv1.VirtualMachine) {
+				vm.Spec.Template.Spec.Domain.Firmware.Bootloader.EFI.Persistent = pointer.P(true)
+			}),
+			Entry("be true when persistent TPM and EFI are set", true, func(vm *virtv1.VirtualMachine) {
+				vm.Spec.Template.Spec.Domain.Devices.TPM.Persistent = pointer.P(true)
+				vm.Spec.Template.Spec.Domain.Firmware.Bootloader.EFI.Persistent = pointer.P(true)
+			}),
+		)
+	})
 })
