@@ -2,10 +2,8 @@ package util
 
 import (
 	"crypto/rand"
-	"errors"
 	"fmt"
 	"math/big"
-	"os"
 	"strings"
 
 	"k8s.io/apimachinery/pkg/api/resource"
@@ -21,22 +19,13 @@ const (
 	RequestHeaderClientCAFileKey              = "requestheader-client-ca-file"
 	VirtShareDir                              = "/var/run/kubevirt"
 	VirtPrivateDir                            = "/var/run/kubevirt-private"
-	VirtLibDir                                = "/var/lib/kubevirt"
 	KubeletRoot                               = "/var/lib/kubelet"
 	KubeletPodsDir                            = KubeletRoot + "/pods"
 	HostRootMount                             = "/proc/1/root/"
-	CPUManagerOS3Path                         = HostRootMount + "var/lib/origin/openshift.local.volumes/cpu_manager_state"
-	CPUManagerPath                            = HostRootMount + "var/lib/kubelet/cpu_manager_state"
 
-	// Alphanums is the list of alphanumeric characters used to create a securely generated random string
-	Alphanums = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz"
-
-	NonRootUID         = 107
-	NonRootUserString  = "qemu"
-	RootUser           = 0
-	memoryDumpOverhead = 100 * 1024 * 1024
-
-	UnprivilegedContainerSELinuxLabel = "system_u:object_r:container_file_t:s0"
+	NonRootUID        = 107
+	NonRootUserString = "qemu"
+	RootUser          = 0
 )
 
 func IsNonRootVMI(vmi *v1.VirtualMachineInstance) bool {
@@ -46,7 +35,7 @@ func IsNonRootVMI(vmi *v1.VirtualMachineInstance) bool {
 	return ok || nonRoot
 }
 
-func IsSRIOVVmi(vmi *v1.VirtualMachineInstance) bool {
+func isSRIOVVmi(vmi *v1.VirtualMachineInstance) bool {
 	for _, iface := range vmi.Spec.Domain.Devices.Interfaces {
 		if iface.SRIOV != nil {
 			return true
@@ -86,7 +75,7 @@ func IsHostDevVMI(vmi *v1.VirtualMachineInstance) bool {
 // Check if a VMI spec requests a VFIO device
 func IsVFIOVMI(vmi *v1.VirtualMachineInstance) bool {
 
-	if IsHostDevVMI(vmi) || IsGPUVMI(vmi) || IsSRIOVVmi(vmi) {
+	if IsHostDevVMI(vmi) || IsGPUVMI(vmi) || isSRIOVVmi(vmi) {
 		return true
 	}
 	return false
@@ -97,44 +86,11 @@ func IsSEVVMI(vmi *v1.VirtualMachineInstance) bool {
 	return vmi.Spec.Domain.LaunchSecurity != nil && vmi.Spec.Domain.LaunchSecurity.SEV != nil
 }
 
-// Check if a VMI spec requests AMD SEV-ES
-func IsSEVESVMI(vmi *v1.VirtualMachineInstance) bool {
-	return IsSEVVMI(vmi) &&
-		vmi.Spec.Domain.LaunchSecurity.SEV.Policy != nil &&
-		vmi.Spec.Domain.LaunchSecurity.SEV.Policy.EncryptedState != nil &&
-		*vmi.Spec.Domain.LaunchSecurity.SEV.Policy.EncryptedState
-}
-
 // Check if a VMI spec requests SEV with attestation
 func IsSEVAttestationRequested(vmi *v1.VirtualMachineInstance) bool {
 	return IsSEVVMI(vmi) && vmi.Spec.Domain.LaunchSecurity.SEV.Attestation != nil
 }
 
-func IsAMD64VMI(vmi *v1.VirtualMachineInstance) bool {
-	return vmi.Spec.Architecture == "amd64"
-}
-
-func IsARM64VMI(vmi *v1.VirtualMachineInstance) bool {
-	return vmi.Spec.Architecture == "arm64"
-}
-
-func IsEFIVMI(vmi *v1.VirtualMachineInstance) bool {
-	return vmi.Spec.Domain.Firmware != nil &&
-		vmi.Spec.Domain.Firmware.Bootloader != nil &&
-		vmi.Spec.Domain.Firmware.Bootloader.EFI != nil
-}
-
-func IsVmiUsingHyperVReenlightenment(vmi *v1.VirtualMachineInstance) bool {
-	if vmi == nil {
-		return false
-	}
-
-	domainFeatures := vmi.Spec.Domain.Features
-
-	return domainFeatures != nil && domainFeatures.Hyperv != nil && domainFeatures.Hyperv.Reenlightenment != nil &&
-		domainFeatures.Hyperv.Reenlightenment.Enabled != nil && *domainFeatures.Hyperv.Reenlightenment.Enabled
-}
-
 // WantVirtioNetDevice checks whether a VMI references at least one "virtio" network interface.
 // Note that the reference can be explicit or implicit (unspecified nic models defaults to "virtio").
 func WantVirtioNetDevice(vmi *v1.VirtualMachineInstance) bool {
@@ -146,12 +102,6 @@ func WantVirtioNetDevice(vmi *v1.VirtualMachineInstance) bool {
 	return false
 }
 
-// NeedVirtioNetDevice checks whether a VMI requires the presence of the "virtio" net device.
-// This happens when the VMI wants to use a "virtio" network interface, and software emulation is disallowed.
-func NeedVirtioNetDevice(vmi *v1.VirtualMachineInstance, allowEmulation bool) bool {
-	return WantVirtioNetDevice(vmi) && !allowEmulation
-}
-
 func NeedTunDevice(vmi *v1.VirtualMachineInstance) bool {
 	return (len(vmi.Spec.Domain.Devices.Interfaces) > 0) ||
 		(vmi.Spec.Domain.Devices.AutoattachPodInterface == nil) ||
@@ -162,23 +112,6 @@ func IsAutoAttachVSOCK(vmi *v1.VirtualMachineInstance) bool {
 	return vmi.Spec.Domain.Devices.AutoattachVSOCK != nil && *vmi.Spec.Domain.Devices.AutoattachVSOCK
 }
 
-// UseSoftwareEmulationForDevice determines whether to fallback to software emulation for the given device.
-// This happens when the given device doesn't exist, and software emulation is enabled.
-func UseSoftwareEmulationForDevice(devicePath string, allowEmulation bool) (bool, error) {
-	if !allowEmulation {
-		return false, nil
-	}
-
-	_, err := os.Stat(devicePath)
-	if err == nil {
-		return false, nil
-	}
-	if errors.Is(err, os.ErrNotExist) {
-		return true, nil
-	}
-	return false, err
-}
-
 func ResourceNameToEnvVar(prefix string, resourceName string) string {
 	varName := strings.ToUpper(resourceName)
 	varName = strings.Replace(varName, "/", "_", -1)
@@ -200,16 +133,6 @@ func HasKernelBootContainerImage(vmi *v1.VirtualMachineInstance) bool {
 	return true
 }
 
-func HasHugePages(vmi *v1.VirtualMachineInstance) bool {
-	return vmi.Spec.Domain.Memory != nil && vmi.Spec.Domain.Memory.Hugepages != nil
-}
-
-func IsReadOnlyDisk(disk *v1.Disk) bool {
-	isReadOnlyCDRom := disk.CDRom != nil && (disk.CDRom.ReadOnly == nil || *disk.CDRom.ReadOnly)
-
-	return isReadOnlyCDRom
-}
-
 // AlignImageSizeTo1MiB rounds down the size to the nearest multiple of 1MiB
 // A warning or an error may get logged
 // The caller is responsible for ensuring the rounded-down size is not 0
@@ -231,10 +154,6 @@ func AlignImageSizeTo1MiB(size int64, logger *log.FilteredLogger) int64 {
 
 }
 
-func MarkAsNonroot(vmi *v1.VirtualMachineInstance) {
-	vmi.Status.RuntimeUser = 107
-}
-
 func SetDefaultVolumeDisk(spec *v1.VirtualMachineInstanceSpec) {
 	diskAndFilesystemNames := make(map[string]struct{})
 
@@ -259,6 +178,7 @@ func SetDefaultVolumeDisk(spec *v1.VirtualMachineInstanceSpec) {
 }
 
 func CalcExpectedMemoryDumpSize(vmi *v1.VirtualMachineInstance) *resource.Quantity {
+	const memoryDumpOverhead = 100 * 1024 * 1024
 	domain := vmi.Spec.Domain
 	vmiMemoryReq := domain.Resources.Requests.Memory()
 	expectedPvcSize := resource.NewQuantity(int64(memoryDumpOverhead), vmiMemoryReq.Format)
@@ -266,15 +186,17 @@ func CalcExpectedMemoryDumpSize(vmi *v1.VirtualMachineInstance) *resource.Quanti
 	return expectedPvcSize
 }
 
-// GenerateSecureRandomString creates a securely generated random string using crypto/rand
-func GenerateSecureRandomString(n int) (string, error) {
-	ret := make([]byte, n)
+// GenerateVMExportToken creates a cryptographically secure token for VM export
+func GenerateVMExportToken() (string, error) {
+	const alphanums = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz"
+	const tokenLen = 20
+	ret := make([]byte, tokenLen)
 	for i := range ret {
-		num, err := rand.Int(rand.Reader, big.NewInt(int64(len(Alphanums))))
+		num, err := rand.Int(rand.Reader, big.NewInt(int64(len(alphanums))))
 		if err != nil {
 			return "", err
 		}
-		ret[i] = Alphanums[num.Int64()]
+		ret[i] = alphanums[num.Int64()]
 	}
 
 	return string(ret), nil
@@ -293,24 +215,3 @@ func GenerateKubeVirtGroupVersionKind(obj runtime.Object) (runtime.Object, error
 
 	return objCopy, nil
 }
-
-/*
-TranslateBuildArch translates the build_arch to arch
-
-	case1:
-	  build_arch is crossbuild-s390x, which will be translated to s390x arch
-	case2:
-	  build_arch is s390x, which will be translated to s390x arch
-*/
-func TranslateBuildArch() string {
-	buildArch := os.Getenv("BUILD_ARCH")
-
-	if buildArch == "" {
-		return ""
-	}
-	archElements := strings.Split(buildArch, "-")
-	if len(archElements) == 2 {
-		return archElements[1]
-	}
-	return archElements[0]
-}
