@@ -45,16 +45,18 @@ import (
 	v1 "kubevirt.io/api/core/v1"
 	"kubevirt.io/client-go/kubecli"
 	"kubevirt.io/client-go/log"
-
 	cdiv1 "kubevirt.io/containerized-data-importer-api/pkg/apis/core/v1beta1"
 
 	"kubevirt.io/kubevirt/pkg/apimachinery/patch"
 	"kubevirt.io/kubevirt/pkg/controller"
-	"kubevirt.io/kubevirt/pkg/instancetype"
+	"kubevirt.io/kubevirt/pkg/instancetype/expand"
+	"kubevirt.io/kubevirt/pkg/instancetype/find"
+	preferenceFind "kubevirt.io/kubevirt/pkg/instancetype/preference/find"
 	"kubevirt.io/kubevirt/pkg/pointer"
 	storagetypes "kubevirt.io/kubevirt/pkg/storage/types"
 	kutil "kubevirt.io/kubevirt/pkg/util"
 	virtconfig "kubevirt.io/kubevirt/pkg/virt-config"
+	"kubevirt.io/kubevirt/pkg/virt-config/featuregate"
 )
 
 const (
@@ -78,6 +80,10 @@ const (
 	volumeMigrationManualRecoveryRequiredErr = "VM recovery required: Volume migration failed, leaving some volumes pointing to non-consistent targets; manual intervention is needed to reassign them to their original volumes."
 )
 
+type instancetypeVMExpander interface {
+	Expand(vm *v1.VirtualMachine) (*v1.VirtualMachine, error)
+}
+
 type SubresourceAPIApp struct {
 	virtCli                 kubecli.KubevirtClient
 	consoleServerPort       int
@@ -85,16 +91,20 @@ type SubresourceAPIApp struct {
 	handlerTLSConfiguration *tls.Config
 	credentialsLock         *sync.Mutex
 	clusterConfig           *virtconfig.ClusterConfig
-	instancetypeMethods     instancetype.Methods
+	instancetypeExpander    instancetypeVMExpander
 	handlerHttpClient       *http.Client
 }
 
 func NewSubresourceAPIApp(virtCli kubecli.KubevirtClient, consoleServerPort int, tlsConfiguration *tls.Config, clusterConfig *virtconfig.ClusterConfig) *SubresourceAPIApp {
 	// When this method is called from tools/openapispec.go when running 'make generate',
 	// the virtCli is nil, and accessing GeneratedKubeVirtClient() would cause nil dereference.
-	var instancetypeMethods instancetype.Methods
+	var instancetypeExpander instancetypeVMExpander
 	if virtCli != nil {
-		instancetypeMethods = &instancetype.InstancetypeMethods{Clientset: virtCli}
+		instancetypeExpander = expand.New(
+			clusterConfig,
+			find.NewSpecFinder(nil, nil, nil, virtCli),
+			preferenceFind.NewSpecFinder(nil, nil, nil, virtCli),
+		)
 	}
 
 	httpClient := &http.Client{
@@ -111,12 +121,20 @@ func NewSubresourceAPIApp(virtCli kubecli.KubevirtClient, consoleServerPort int,
 		credentialsLock:         &sync.Mutex{},
 		handlerTLSConfiguration: tlsConfiguration,
 		clusterConfig:           clusterConfig,
-		instancetypeMethods:     instancetypeMethods,
+		instancetypeExpander:    instancetypeExpander,
 		handlerHttpClient:       httpClient,
 	}
 }
 
 type validation func(*v1.VirtualMachineInstance) (err *errors.StatusError)
+
+// This function prototype is used with putRequestHandlerWithErrorPostProcessing.
+// The errorPostProcessing function will get called if an error occurs when attempting
+// to make a request to virt-handler. Depending on where in the stack the error occurred
+// the VMI might be nil.
+//
+// Use this function to inject more human readible context into the error response.
+type errorPostProcessing func(*v1.VirtualMachineInstance, error) (err error)
 type URLResolver func(*v1.VirtualMachineInstance, kubecli.VirtHandlerConn) (string, error)
 
 func (app *SubresourceAPIApp) prepareConnection(request *restful.Request, validate validation, getVirtHandlerURL URLResolver) (vmi *v1.VirtualMachineInstance, url string, conn kubecli.VirtHandlerConn, statusError *errors.StatusError) {
@@ -150,9 +168,24 @@ func (app *SubresourceAPIApp) fetchAndValidateVirtualMachineInstance(namespace,
 	return
 }
 
-func (app *SubresourceAPIApp) putRequestHandler(request *restful.Request, response *restful.Response, validate validation, getVirtHandlerURL URLResolver, dryRun bool) {
-	_, url, conn, statusErr := app.prepareConnection(request, validate, getVirtHandlerURL)
+func (app *SubresourceAPIApp) putRequestHandler(request *restful.Request, response *restful.Response, preValidate validation, getVirtHandlerURL URLResolver, dryRun bool) {
+
+	app.putRequestHandlerWithErrorPostProcessing(request, response, preValidate, nil, getVirtHandlerURL, dryRun)
+}
+
+func (app *SubresourceAPIApp) putRequestHandlerWithErrorPostProcessing(request *restful.Request, response *restful.Response, preValidate validation, errorPostProcessing errorPostProcessing, getVirtHandlerURL URLResolver, dryRun bool) {
+
+	if preValidate == nil {
+		preValidate = func(vmi *v1.VirtualMachineInstance) *errors.StatusError { return nil }
+	}
+	if errorPostProcessing == nil {
+		errorPostProcessing = func(vmi *v1.VirtualMachineInstance, err error) error { return err }
+	}
+
+	vmi, url, conn, statusErr := app.prepareConnection(request, preValidate, getVirtHandlerURL)
 	if statusErr != nil {
+		err := errorPostProcessing(vmi, fmt.Errorf(statusErr.ErrStatus.Message))
+		statusErr.ErrStatus.Message = err.Error()
 		writeError(statusErr, response)
 		return
 	}
@@ -162,6 +195,7 @@ func (app *SubresourceAPIApp) putRequestHandler(request *restful.Request, respon
 	}
 	err := conn.Put(url, request.Request.Body)
 	if err != nil {
+		err = errorPostProcessing(vmi, err)
 		writeError(errors.NewInternalError(err), response)
 		return
 	}
@@ -787,6 +821,26 @@ func (app *SubresourceAPIApp) UnfreezeVMIRequestHandler(request *restful.Request
 
 }
 
+func (app *SubresourceAPIApp) ResetVMIRequestHandler(request *restful.Request, response *restful.Response) {
+
+	// Post process any error responses in order to append human
+	// readable explanation for why the reset may have failed.
+	errorPostProcessing := func(vmi *v1.VirtualMachineInstance, err error) error {
+		// VMI reset request could have been sent while VMI was in the process of transitioning
+		// from scheduled to running.
+		if vmi != nil && !vmi.IsRunning() {
+			return fmt.Errorf("Failed to reset non-running VMI with phase %s: %v", vmi.Status.Phase, err)
+		}
+		return err
+	}
+
+	getURL := func(vmi *v1.VirtualMachineInstance, conn kubecli.VirtHandlerConn) (string, error) {
+		return conn.ResetURI(vmi)
+	}
+
+	app.putRequestHandlerWithErrorPostProcessing(request, response, nil, errorPostProcessing, getURL, false)
+}
+
 func (app *SubresourceAPIApp) SoftRebootVMIRequestHandler(request *restful.Request, response *restful.Response) {
 
 	validate := func(vmi *v1.VirtualMachineInstance) *errors.StatusError {
@@ -1519,7 +1573,7 @@ func (app *SubresourceAPIApp) RemoveMemoryDumpVMRequestHandler(request *restful.
 
 func (app *SubresourceAPIApp) ensureSEVEnabled(response *restful.Response) bool {
 	if !app.clusterConfig.WorkloadEncryptionSEVEnabled() {
-		writeError(errors.NewBadRequest(fmt.Sprintf(featureGateDisabledErrFmt, virtconfig.WorkloadEncryptionSEV)), response)
+		writeError(errors.NewBadRequest(fmt.Sprintf(featureGateDisabledErrFmt, featuregate.WorkloadEncryptionSEV)), response)
 		return false
 	}
 	return true
