@@ -1,6 +1,7 @@
 package admitters
 
 import (
+	"context"
 	"encoding/json"
 	"fmt"
 	"net/http"
@@ -38,7 +39,7 @@ var _ = Describe("Validating Preference Admitter", func() {
 
 	DescribeTable("should accept valid preference", func(version string) {
 		ar := createPreferenceAdmissionReview(preferenceObj, version)
-		response := admitter.Admit(ar)
+		response := admitter.Admit(context.Background(), ar)
 
 		Expect(response.Allowed).To(BeTrue(), "Expected preference to be allowed.")
 	},
@@ -49,19 +50,38 @@ var _ = Describe("Validating Preference Admitter", func() {
 
 	It("should reject unsupported version", func() {
 		ar := createPreferenceAdmissionReview(preferenceObj, "unsupportedversion")
-		response := admitter.Admit(ar)
+		response := admitter.Admit(context.Background(), ar)
 
 		Expect(response.Allowed).To(BeFalse(), "Expected preference to not be allowed")
 		Expect(response.Result.Code).To(Equal(int32(http.StatusBadRequest)), "Expected error 400: BadRequest")
 	})
 
-	It("should reject unsupported SpreadOptions Across value", func() {
+	It("should reject unsupported PreferredCPUTopolgy value", func() {
+		unsupportedTopology := instancetypev1beta1.PreferredCPUTopology("foo")
+		preferenceObj = &instancetypev1beta1.VirtualMachinePreference{
+			Spec: instancetypev1beta1.VirtualMachinePreferenceSpec{
+				CPU: &instancetypev1beta1.CPUPreferences{
+					PreferredCPUTopology: pointer.P(unsupportedTopology),
+				},
+			},
+		}
+		ar := createPreferenceAdmissionReview(preferenceObj, instancetypev1beta1.SchemeGroupVersion.Version)
+		response := admitter.Admit(context.Background(), ar)
+
+		Expect(response.Allowed).To(BeFalse(), "Expected preference to not be allowed")
+		Expect(response.Result.Details.Causes).To(HaveLen(1))
+		Expect(response.Result.Details.Causes[0].Type).To(Equal(metav1.CauseTypeFieldValueInvalid))
+		Expect(response.Result.Details.Causes[0].Message).To(Equal(fmt.Sprintf(preferredCPUTopologyUnknownErrFmt, unsupportedTopology)))
+		Expect(response.Result.Details.Causes[0].Field).To(Equal(k8sfield.NewPath("spec", "cpu", "preferredCPUTopology").String()))
+	})
+
+	DescribeTable("should reject unsupported SpreadOptions Across value", func(preferredCPUTopology instancetypev1beta1.PreferredCPUTopology) {
 		var unsupportedAcrossValue instancetypev1beta1.SpreadAcross = "foobar"
 		preferenceObj = &instancetypev1beta1.VirtualMachinePreference{
 			Spec: instancetypev1beta1.VirtualMachinePreferenceSpec{
 				PreferSpreadSocketToCoreRatio: uint32(3),
 				CPU: &instancetypev1beta1.CPUPreferences{
-					PreferredCPUTopology: pointer.P(instancetypev1beta1.PreferSpread),
+					PreferredCPUTopology: &preferredCPUTopology,
 					SpreadOptions: &instancetypev1beta1.SpreadOptions{
 						Across: pointer.P(unsupportedAcrossValue),
 					},
@@ -69,30 +89,33 @@ var _ = Describe("Validating Preference Admitter", func() {
 			},
 		}
 		ar := createPreferenceAdmissionReview(preferenceObj, instancetypev1beta1.SchemeGroupVersion.Version)
-		response := admitter.Admit(ar)
+		response := admitter.Admit(context.Background(), ar)
 
 		Expect(response.Allowed).To(BeFalse(), "Expected preference to not be allowed")
 		Expect(response.Result.Details.Causes).To(HaveLen(1))
 		Expect(response.Result.Details.Causes[0].Type).To(Equal(metav1.CauseTypeFieldValueInvalid))
 		Expect(response.Result.Details.Causes[0].Message).To(Equal(fmt.Sprintf(spreadAcrossUnsupportedErrFmt, unsupportedAcrossValue)))
 		Expect(response.Result.Details.Causes[0].Field).To(Equal(k8sfield.NewPath("spec", "cpu", "spreadOptions", "across").String()))
-	})
+	},
+		Entry("with spread", instancetypev1beta1.Spread),
+		Entry("with preferSpread", instancetypev1beta1.DeprecatedPreferSpread),
+	)
 
 	DescribeTable("should reject when spreading vCPUs across CoresThreads with a ratio higher than 2 set through", func(preferenceObj instancetypev1beta1.VirtualMachinePreference) {
 		ar := createPreferenceAdmissionReview(&preferenceObj, instancetypev1beta1.SchemeGroupVersion.Version)
-		response := admitter.Admit(ar)
+		response := admitter.Admit(context.Background(), ar)
 		Expect(response.Allowed).To(BeFalse(), "Expected preference to not be allowed")
 		Expect(response.Result.Details.Causes).To(HaveLen(1))
 		Expect(response.Result.Details.Causes[0].Type).To(Equal(metav1.CauseTypeFieldValueInvalid))
 		Expect(response.Result.Details.Causes[0].Message).To(Equal(spreadAcrossCoresThreadsRatioErr))
 		Expect(response.Result.Details.Causes[0].Field).To(Equal(k8sfield.NewPath("spec", "cpu", "spreadOptions", "ratio").String()))
 	},
-		Entry("PreferSpreadSocketToCoreRatio",
+		Entry("PreferSpreadSocketToCoreRatio with spread",
 			instancetypev1beta1.VirtualMachinePreference{
 				Spec: instancetypev1beta1.VirtualMachinePreferenceSpec{
 					PreferSpreadSocketToCoreRatio: uint32(3),
 					CPU: &instancetypev1beta1.CPUPreferences{
-						PreferredCPUTopology: pointer.P(instancetypev1beta1.PreferSpread),
+						PreferredCPUTopology: pointer.P(instancetypev1beta1.Spread),
 						SpreadOptions: &instancetypev1beta1.SpreadOptions{
 							Across: pointer.P(instancetypev1beta1.SpreadAcrossCoresThreads),
 						},
@@ -100,11 +123,37 @@ var _ = Describe("Validating Preference Admitter", func() {
 				},
 			},
 		),
-		Entry("SpreadOptions",
+		Entry("PreferSpreadSocketToCoreRatio with preferSpread",
+			instancetypev1beta1.VirtualMachinePreference{
+				Spec: instancetypev1beta1.VirtualMachinePreferenceSpec{
+					PreferSpreadSocketToCoreRatio: uint32(3),
+					CPU: &instancetypev1beta1.CPUPreferences{
+						PreferredCPUTopology: pointer.P(instancetypev1beta1.DeprecatedPreferSpread),
+						SpreadOptions: &instancetypev1beta1.SpreadOptions{
+							Across: pointer.P(instancetypev1beta1.SpreadAcrossCoresThreads),
+						},
+					},
+				},
+			},
+		),
+		Entry("SpreadOptions with spread",
 			instancetypev1beta1.VirtualMachinePreference{
 				Spec: instancetypev1beta1.VirtualMachinePreferenceSpec{
 					CPU: &instancetypev1beta1.CPUPreferences{
-						PreferredCPUTopology: pointer.P(instancetypev1beta1.PreferSpread),
+						PreferredCPUTopology: pointer.P(instancetypev1beta1.Spread),
+						SpreadOptions: &instancetypev1beta1.SpreadOptions{
+							Across: pointer.P(instancetypev1beta1.SpreadAcrossCoresThreads),
+							Ratio:  pointer.P(uint32(3)),
+						},
+					},
+				},
+			},
+		),
+		Entry("SpreadOptions with preferSpread",
+			instancetypev1beta1.VirtualMachinePreference{
+				Spec: instancetypev1beta1.VirtualMachinePreferenceSpec{
+					CPU: &instancetypev1beta1.CPUPreferences{
+						PreferredCPUTopology: pointer.P(instancetypev1beta1.DeprecatedPreferSpread),
 						SpreadOptions: &instancetypev1beta1.SpreadOptions{
 							Across: pointer.P(instancetypev1beta1.SpreadAcrossCoresThreads),
 							Ratio:  pointer.P(uint32(3)),
@@ -115,6 +164,26 @@ var _ = Describe("Validating Preference Admitter", func() {
 		),
 	)
 
+	DescribeTable("should raise warning for", func(deprecatedTopology, expectedAlternativeTopology instancetypev1beta1.PreferredCPUTopology) {
+		preferenceObj := &instancetypev1beta1.VirtualMachinePreference{
+			Spec: instancetypev1beta1.VirtualMachinePreferenceSpec{
+				CPU: &instancetypev1beta1.CPUPreferences{
+					PreferredCPUTopology: pointer.P(deprecatedTopology),
+				},
+			},
+		}
+		ar := createPreferenceAdmissionReview(preferenceObj, instancetypev1beta1.SchemeGroupVersion.Version)
+		response := admitter.Admit(context.Background(), ar)
+		Expect(response.Allowed).To(BeTrue())
+		Expect(response.Warnings).To(HaveLen(1))
+		Expect(response.Warnings[0]).To(ContainSubstring(fmt.Sprintf(deprecatedPreferredCPUTopologyErrFmt, deprecatedTopology, expectedAlternativeTopology)))
+	},
+		Entry("DeprecatedPreferSockets and provide Sockets as an alternative", instancetypev1beta1.DeprecatedPreferSockets, instancetypev1beta1.Sockets),
+		Entry("DeprecatedPreferCores and provide Cores as an alternative", instancetypev1beta1.DeprecatedPreferCores, instancetypev1beta1.Cores),
+		Entry("DeprecatedPreferThreads and provide Threads as an alternative", instancetypev1beta1.DeprecatedPreferThreads, instancetypev1beta1.Threads),
+		Entry("DeprecatedPreferSpread and provide Spread as an alternative", instancetypev1beta1.DeprecatedPreferSpread, instancetypev1beta1.Spread),
+		Entry("DeprecatedPreferAny and provide Any as an alternative", instancetypev1beta1.DeprecatedPreferAny, instancetypev1beta1.Any),
+	)
 })
 
 var _ = Describe("Validating ClusterPreference Admitter", func() {
@@ -136,7 +205,7 @@ var _ = Describe("Validating ClusterPreference Admitter", func() {
 
 	DescribeTable("should accept valid preference", func(version string) {
 		ar := createClusterPreferenceAdmissionReview(clusterPreferenceObj, version)
-		response := admitter.Admit(ar)
+		response := admitter.Admit(context.Background(), ar)
 
 		Expect(response.Allowed).To(BeTrue(), "Expected preference to be allowed.")
 	},
@@ -147,19 +216,19 @@ var _ = Describe("Validating ClusterPreference Admitter", func() {
 
 	It("should reject unsupported version", func() {
 		ar := createClusterPreferenceAdmissionReview(clusterPreferenceObj, "unsupportedversion")
-		response := admitter.Admit(ar)
+		response := admitter.Admit(context.Background(), ar)
 
 		Expect(response.Allowed).To(BeFalse(), "Expected preference to not be allowed")
 		Expect(response.Result.Code).To(Equal(int32(http.StatusBadRequest)), "Expected error 400: BadRequest")
 	})
 
-	It("should reject unsupported SpreadOptions Across value", func() {
+	DescribeTable("should reject unsupported SpreadOptions Across value", func(preferredCPUTopology instancetypev1beta1.PreferredCPUTopology) {
 		var unsupportedAcrossValue instancetypev1beta1.SpreadAcross = "foobar"
 		clusterPreferenceObj = &instancetypev1beta1.VirtualMachineClusterPreference{
 			Spec: instancetypev1beta1.VirtualMachinePreferenceSpec{
 				PreferSpreadSocketToCoreRatio: uint32(3),
 				CPU: &instancetypev1beta1.CPUPreferences{
-					PreferredCPUTopology: pointer.P(instancetypev1beta1.PreferSpread),
+					PreferredCPUTopology: &preferredCPUTopology,
 					SpreadOptions: &instancetypev1beta1.SpreadOptions{
 						Across: pointer.P(unsupportedAcrossValue),
 					},
@@ -167,30 +236,33 @@ var _ = Describe("Validating ClusterPreference Admitter", func() {
 			},
 		}
 		ar := createClusterPreferenceAdmissionReview(clusterPreferenceObj, instancetypev1beta1.SchemeGroupVersion.Version)
-		response := admitter.Admit(ar)
+		response := admitter.Admit(context.Background(), ar)
 
 		Expect(response.Allowed).To(BeFalse(), "Expected preference to not be allowed")
 		Expect(response.Result.Details.Causes).To(HaveLen(1))
 		Expect(response.Result.Details.Causes[0].Type).To(Equal(metav1.CauseTypeFieldValueInvalid))
 		Expect(response.Result.Details.Causes[0].Message).To(Equal(fmt.Sprintf(spreadAcrossUnsupportedErrFmt, unsupportedAcrossValue)))
 		Expect(response.Result.Details.Causes[0].Field).To(Equal(k8sfield.NewPath("spec", "cpu", "spreadOptions", "across").String()))
-	})
+	},
+		Entry("with spread", instancetypev1beta1.Spread),
+		Entry("with preferSpread", instancetypev1beta1.DeprecatedPreferSpread),
+	)
 
 	DescribeTable("should reject when spreading vCPUs across CoresThreads with a ratio higher than 2 set through", func(clusterPreferenceObj instancetypev1beta1.VirtualMachineClusterPreference) {
 		ar := createClusterPreferenceAdmissionReview(&clusterPreferenceObj, instancetypev1beta1.SchemeGroupVersion.Version)
-		response := admitter.Admit(ar)
+		response := admitter.Admit(context.Background(), ar)
 		Expect(response.Allowed).To(BeFalse(), "Expected preference to not be allowed")
 		Expect(response.Result.Details.Causes).To(HaveLen(1))
 		Expect(response.Result.Details.Causes[0].Type).To(Equal(metav1.CauseTypeFieldValueInvalid))
 		Expect(response.Result.Details.Causes[0].Message).To(Equal(spreadAcrossCoresThreadsRatioErr))
 		Expect(response.Result.Details.Causes[0].Field).To(Equal(k8sfield.NewPath("spec", "cpu", "spreadOptions", "ratio").String()))
 	},
-		Entry("PreferSpreadSocketToCoreRatio",
+		Entry("PreferSpreadSocketToCoreRatio with spread",
 			instancetypev1beta1.VirtualMachineClusterPreference{
 				Spec: instancetypev1beta1.VirtualMachinePreferenceSpec{
 					PreferSpreadSocketToCoreRatio: uint32(3),
 					CPU: &instancetypev1beta1.CPUPreferences{
-						PreferredCPUTopology: pointer.P(instancetypev1beta1.PreferSpread),
+						PreferredCPUTopology: pointer.P(instancetypev1beta1.Spread),
 						SpreadOptions: &instancetypev1beta1.SpreadOptions{
 							Across: pointer.P(instancetypev1beta1.SpreadAcrossCoresThreads),
 						},
@@ -198,11 +270,24 @@ var _ = Describe("Validating ClusterPreference Admitter", func() {
 				},
 			},
 		),
-		Entry("SpreadOptions",
+		Entry("PreferSpreadSocketToCoreRatio with preferSpread",
+			instancetypev1beta1.VirtualMachineClusterPreference{
+				Spec: instancetypev1beta1.VirtualMachinePreferenceSpec{
+					PreferSpreadSocketToCoreRatio: uint32(3),
+					CPU: &instancetypev1beta1.CPUPreferences{
+						PreferredCPUTopology: pointer.P(instancetypev1beta1.DeprecatedPreferSpread),
+						SpreadOptions: &instancetypev1beta1.SpreadOptions{
+							Across: pointer.P(instancetypev1beta1.SpreadAcrossCoresThreads),
+						},
+					},
+				},
+			},
+		),
+		Entry("SpreadOptions with spread",
 			instancetypev1beta1.VirtualMachineClusterPreference{
 				Spec: instancetypev1beta1.VirtualMachinePreferenceSpec{
 					CPU: &instancetypev1beta1.CPUPreferences{
-						PreferredCPUTopology: pointer.P(instancetypev1beta1.PreferSpread),
+						PreferredCPUTopology: pointer.P(instancetypev1beta1.Spread),
 						SpreadOptions: &instancetypev1beta1.SpreadOptions{
 							Across: pointer.P(instancetypev1beta1.SpreadAcrossCoresThreads),
 							Ratio:  pointer.P(uint32(3)),
@@ -211,6 +296,40 @@ var _ = Describe("Validating ClusterPreference Admitter", func() {
 				},
 			},
 		),
+		Entry("SpreadOptions with preferSpread",
+			instancetypev1beta1.VirtualMachineClusterPreference{
+				Spec: instancetypev1beta1.VirtualMachinePreferenceSpec{
+					CPU: &instancetypev1beta1.CPUPreferences{
+						PreferredCPUTopology: pointer.P(instancetypev1beta1.DeprecatedPreferSpread),
+						SpreadOptions: &instancetypev1beta1.SpreadOptions{
+							Across: pointer.P(instancetypev1beta1.SpreadAcrossCoresThreads),
+							Ratio:  pointer.P(uint32(3)),
+						},
+					},
+				},
+			},
+		),
+	)
+
+	DescribeTable("should raise warning for", func(deprecatedTopology, expectedAlternativeTopology instancetypev1beta1.PreferredCPUTopology) {
+		preferenceObj := &instancetypev1beta1.VirtualMachineClusterPreference{
+			Spec: instancetypev1beta1.VirtualMachinePreferenceSpec{
+				CPU: &instancetypev1beta1.CPUPreferences{
+					PreferredCPUTopology: pointer.P(deprecatedTopology),
+				},
+			},
+		}
+		ar := createClusterPreferenceAdmissionReview(preferenceObj, instancetypev1beta1.SchemeGroupVersion.Version)
+		response := admitter.Admit(context.Background(), ar)
+		Expect(response.Allowed).To(BeTrue())
+		Expect(response.Warnings).To(HaveLen(1))
+		Expect(response.Warnings[0]).To(ContainSubstring(fmt.Sprintf(deprecatedPreferredCPUTopologyErrFmt, deprecatedTopology, expectedAlternativeTopology)))
+	},
+		Entry("DeprecatedPreferSockets and provide Sockets as an alternative", instancetypev1beta1.DeprecatedPreferSockets, instancetypev1beta1.Sockets),
+		Entry("DeprecatedPreferCores and provide Cores as an alternative", instancetypev1beta1.DeprecatedPreferCores, instancetypev1beta1.Cores),
+		Entry("DeprecatedPreferThreads and provide Threads as an alternative", instancetypev1beta1.DeprecatedPreferThreads, instancetypev1beta1.Threads),
+		Entry("DeprecatedPreferSpread and provide Spread as an alternative", instancetypev1beta1.DeprecatedPreferSpread, instancetypev1beta1.Spread),
+		Entry("DeprecatedPreferAny and provide Any as an alternative", instancetypev1beta1.DeprecatedPreferAny, instancetypev1beta1.Any),
 	)
 })
 
