@@ -37,9 +37,8 @@ import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	k8sfield "k8s.io/apimachinery/pkg/util/validation/field"
 
-	"kubevirt.io/api/clone"
-	clonev1alpha1 "kubevirt.io/api/clone/v1alpha1"
-	v1 "kubevirt.io/api/core/v1"
+	clonebase "kubevirt.io/api/clone"
+	clone "kubevirt.io/api/clone/v1beta1"
 	"kubevirt.io/client-go/kubecli"
 
 	webhookutils "kubevirt.io/kubevirt/pkg/util/webhooks"
@@ -67,18 +66,18 @@ func NewVMCloneAdmitter(config *virtconfig.ClusterConfig, client kubecli.Kubevir
 
 // Admit validates an AdmissionReview
 func (admitter *VirtualMachineCloneAdmitter) Admit(ctx context.Context, ar *admissionv1.AdmissionReview) *admissionv1.AdmissionResponse {
-	if ar.Request.Resource.Group != clonev1alpha1.VirtualMachineCloneKind.Group {
-		return webhookutils.ToAdmissionResponseError(fmt.Errorf("unexpected group: %+v. Expected group: %+v", ar.Request.Resource.Group, clonev1alpha1.VirtualMachineCloneKind.Group))
+	if ar.Request.Resource.Group != clone.VirtualMachineCloneKind.Group {
+		return webhookutils.ToAdmissionResponseError(fmt.Errorf("unexpected group: %+v. Expected group: %+v", ar.Request.Resource.Group, clone.VirtualMachineCloneKind.Group))
 	}
-	if ar.Request.Resource.Resource != clone.ResourceVMClonePlural {
-		return webhookutils.ToAdmissionResponseError(fmt.Errorf("unexpected resource: %+v. Expected resource: %+v", ar.Request.Resource.Resource, clone.ResourceVMClonePlural))
+	if ar.Request.Resource.Resource != clonebase.ResourceVMClonePlural {
+		return webhookutils.ToAdmissionResponseError(fmt.Errorf("unexpected resource: %+v. Expected resource: %+v", ar.Request.Resource.Resource, clonebase.ResourceVMClonePlural))
 	}
 
 	if ar.Request.Operation == admissionv1.Create && !admitter.Config.SnapshotEnabled() {
 		return webhookutils.ToAdmissionResponseError(fmt.Errorf("snapshot feature gate is not enabled"))
 	}
 
-	vmClone := &clonev1alpha1.VirtualMachineClone{}
+	vmClone := &clone.VirtualMachineClone{}
 	err := json.Unmarshal(ar.Request.Object.Raw, vmClone)
 	if err != nil {
 		return webhookutils.ToAdmissionResponseError(err)
@@ -162,7 +161,7 @@ func validateFilters(filters []string, fieldName string) (causes []metav1.Status
 	return causes
 }
 
-func validateSourceAndTargetKind(vmClone *clonev1alpha1.VirtualMachineClone) []metav1.StatusCause {
+func validateSourceAndTargetKind(vmClone *clone.VirtualMachineClone) []metav1.StatusCause {
 	var causes []metav1.StatusCause = nil
 	sourceField := k8sfield.NewPath("spec")
 
@@ -191,7 +190,7 @@ func validateSourceAndTargetKind(vmClone *clonev1alpha1.VirtualMachineClone) []m
 	return causes
 }
 
-func validateSource(ctx context.Context, client kubecli.KubevirtClient, vmClone *clonev1alpha1.VirtualMachineClone) []metav1.StatusCause {
+func validateSource(ctx context.Context, client kubecli.KubevirtClient, vmClone *clone.VirtualMachineClone) []metav1.StatusCause {
 	var causes []metav1.StatusCause = nil
 	sourceField := k8sfield.NewPath("spec")
 	source := vmClone.Spec.Source
@@ -228,7 +227,6 @@ func validateSource(ctx context.Context, client kubecli.KubevirtClient, vmClone
 	if source.Kind != "" && source.Name != "" {
 		switch source.Kind {
 		case virtualMachineKind:
-			causes = append(causes, validateCloneSourceVM(ctx, client, source.Name, vmClone.Namespace, sourceField.Child("Source"))...)
 		case virtualMachineSnapshotKind:
 			causes = append(causes, validateCloneSourceSnapshot(ctx, client, source.Name, vmClone.Namespace, sourceField.Child("Source"))...)
 		default:
@@ -242,7 +240,7 @@ func validateSource(ctx context.Context, client kubecli.KubevirtClient, vmClone
 	return causes
 }
 
-func validateTarget(vmClone *clonev1alpha1.VirtualMachineClone) []metav1.StatusCause {
+func validateTarget(vmClone *clone.VirtualMachineClone) []metav1.StatusCause {
 	var causes []metav1.StatusCause
 
 	source := vmClone.Spec.Source
@@ -263,7 +261,7 @@ func validateTarget(vmClone *clonev1alpha1.VirtualMachineClone) []metav1.StatusC
 	return causes
 }
 
-func validateNewMacAddresses(vmClone *clonev1alpha1.VirtualMachineClone) []metav1.StatusCause {
+func validateNewMacAddresses(vmClone *clone.VirtualMachineClone) []metav1.StatusCause {
 	var causes []metav1.StatusCause
 
 	for ifaceName, ifaceMac := range vmClone.Spec.NewMacAddresses {
@@ -314,23 +312,6 @@ func validateCloneSourceExists(clientGetErr error, sourceField *k8sfield.Path, k
 	return nil
 }
 
-func validateCloneSourceVM(ctx context.Context, client kubecli.KubevirtClient, name, namespace string, sourceField *k8sfield.Path) []metav1.StatusCause {
-	vm, err := client.VirtualMachine(namespace).Get(ctx, name, metav1.GetOptions{})
-	causes := validateCloneSourceExists(err, sourceField, virtualMachineKind, name, namespace)
-
-	if causes != nil {
-		return causes
-	}
-
-	// currently, cloning leverages vm snapshot/restore to copy volumes
-	// snapshot/restore requires that volumes support CSI snapshots
-	// this limitation should be removed eventually
-	// probably by leveraging CDI cloning
-	causes = append(causes, validateCloneVolumeSnapshotSupportVM(vm, sourceField)...)
-
-	return causes
-}
-
 func validateCloneSourceSnapshot(ctx context.Context, client kubecli.KubevirtClient, name, namespace string, sourceField *k8sfield.Path) []metav1.StatusCause {
 	vmSnapshot, err := client.VirtualMachineSnapshot(namespace).Get(ctx, name, metav1.GetOptions{})
 	causes := validateCloneSourceExists(err, sourceField, virtualMachineSnapshotKind, name, namespace)
@@ -351,51 +332,6 @@ func validateCloneSourceSnapshot(ctx context.Context, client kubecli.KubevirtCli
 	return causes
 }
 
-func validateCloneVolumeSnapshotSupportVM(vm *v1.VirtualMachine, sourceField *k8sfield.Path) []metav1.StatusCause {
-	var result []metav1.StatusCause
-
-	// should never happen, but don't want to NPE
-	if vm.Spec.Template == nil {
-		return result
-	}
-
-	for _, v := range vm.Spec.Template.Spec.Volumes {
-		if v.PersistentVolumeClaim != nil || v.DataVolume != nil {
-			found := false
-			for _, vss := range vm.Status.VolumeSnapshotStatuses {
-				if v.Name == vss.Name {
-					if !vss.Enabled {
-						result = append(result, metav1.StatusCause{
-							Type:    metav1.CauseTypeFieldValueInvalid,
-							Message: fmt.Sprintf("Virtual Machine volume %s does not support snapshots", v.Name),
-							Field:   sourceField.String(),
-						})
-					}
-					found = true
-					break
-				}
-			}
-			if !found {
-				result = append(result, metav1.StatusCause{
-					Type:    metav1.CauseTypeFieldValueInvalid,
-					Message: fmt.Sprintf("Virtual Machine volume %s snapshot support unknown", v.Name),
-					Field:   sourceField.String(),
-				})
-			}
-		}
-	}
-
-	if backendstorage.IsBackendStorageNeededForVM(vm) {
-		result = append(result, metav1.StatusCause{
-			Type:    metav1.CauseTypeFieldValueInvalid,
-			Message: "Virtual Machine requires backend storage, operation not supported",
-			Field:   sourceField.String(),
-		})
-	}
-
-	return result
-}
-
 func validateCloneVolumeSnapshotSupportVMSnapshotContent(snapshotContents *snapshotv1.VirtualMachineSnapshotContent, sourceField *k8sfield.Path) []metav1.StatusCause {
 	var result []metav1.StatusCause
 
