@@ -38,8 +38,8 @@ import (
 	"k8s.io/apimachinery/pkg/util/rand"
 	"k8s.io/client-go/tools/cache"
 
-	"kubevirt.io/api/clone"
-	clonev1lpha1 "kubevirt.io/api/clone/v1alpha1"
+	clonebase "kubevirt.io/api/clone"
+	clone "kubevirt.io/api/clone/v1beta1"
 	"kubevirt.io/api/core"
 	v1 "kubevirt.io/api/core/v1"
 	"kubevirt.io/client-go/kubecli"
@@ -54,7 +54,7 @@ var _ = Describe("Validating VirtualMachineClone Admitter", func() {
 	var virtClient *kubecli.MockKubevirtClient
 	var kubevirtClient *fake.Clientset
 	var admitter *VirtualMachineCloneAdmitter
-	var vmClone *clonev1lpha1.VirtualMachineClone
+	var vmClone *clone.VirtualMachineClone
 	var config *virtconfig.ClusterConfig
 	var kvStore cache.Store
 	var vmInterface *kubecli.MockVirtualMachineInterface
@@ -243,11 +243,6 @@ var _ = Describe("Validating VirtualMachineClone Admitter", func() {
 		}),
 	)
 
-	It("should reject clone with source that uses backend storage", func() {
-		vm.Spec.Template.Spec.Domain.Devices.TPM = &v1.TPMDevice{Persistent: pointer.P(true)}
-		admitter.admitAndExpect(vmClone, false)
-	})
-
 	Context("source types", func() {
 
 		DescribeTable("should allow legal types", func(kind string) {
@@ -269,9 +264,9 @@ var _ = Describe("Validating VirtualMachineClone Admitter", func() {
 		admitter.admitAndExpect(vmClone, false)
 	})
 
-	It("Should reject a source VM that does not exist", func() {
+	It("Should allow source VM that does not exist", func() {
 		vmClone.Spec.Source.Name = "vm-that-doesnt-exist"
-		admitter.admitAndExpect(vmClone, false)
+		admitter.admitAndExpect(vmClone, true)
 	})
 
 	When("Both source and target kinds are VirtualMachine", func() {
@@ -299,9 +294,9 @@ var _ = Describe("Validating VirtualMachineClone Admitter", func() {
 		admitter.admitAndExpect(vmClone, false)
 	})
 
-	DescribeTable("Should reject a source volume not Snapshot-able", func(index int) {
+	DescribeTable("Should allow a source volume not Snapshot-able", func(index int) {
 		vm.Status.VolumeSnapshotStatuses[index].Enabled = false
-		admitter.admitAndExpect(vmClone, false)
+		admitter.admitAndExpect(vmClone, true)
 	},
 		Entry("DataVolume", 0),
 		Entry("PersistentVolumeClaim", 1),
@@ -330,7 +325,7 @@ var _ = Describe("Validating VirtualMachineClone Admitter", func() {
 			for i := range vm.Status.VolumeSnapshotStatuses {
 				vm.Status.VolumeSnapshotStatuses[i].Enabled = false
 			}
-			admitter.admitAndExpect(vmClone, false)
+			admitter.admitAndExpect(vmClone, true)
 		})
 
 		It("should reject if vmsnapshot contents don't include a volume's backup", func() {
@@ -428,15 +423,15 @@ var _ = Describe("Validating VirtualMachineClone Admitter", func() {
 
 })
 
-func createCloneAdmissionReview(vmClone *clonev1lpha1.VirtualMachineClone) *admissionv1.AdmissionReview {
+func createCloneAdmissionReview(vmClone *clone.VirtualMachineClone) *admissionv1.AdmissionReview {
 	policyBytes, _ := json.Marshal(vmClone)
 
 	ar := &admissionv1.AdmissionReview{
 		Request: &admissionv1.AdmissionRequest{
 			Operation: admissionv1.Create,
 			Resource: metav1.GroupVersionResource{
-				Group:    clonev1lpha1.VirtualMachineCloneKind.Group,
-				Resource: clone.ResourceVMClonePlural,
+				Group:    clone.VirtualMachineCloneKind.Group,
+				Resource: clonebase.ResourceVMClonePlural,
 			},
 			Object: runtime.RawExtension{
 				Raw: policyBytes,
@@ -447,13 +442,13 @@ func createCloneAdmissionReview(vmClone *clonev1lpha1.VirtualMachineClone) *admi
 	return ar
 }
 
-func (admitter *VirtualMachineCloneAdmitter) admitAndExpect(clone *clonev1lpha1.VirtualMachineClone, expectAllowed bool) {
+func (admitter *VirtualMachineCloneAdmitter) admitAndExpect(clone *clone.VirtualMachineClone, expectAllowed bool) {
 	ar := createCloneAdmissionReview(clone)
 	resp := admitter.Admit(context.Background(), ar)
 	Expect(resp.Allowed).To(Equal(expectAllowed))
 }
 
-func newValidClone() *clonev1lpha1.VirtualMachineClone {
+func newValidClone() *clone.VirtualMachineClone {
 	vmClone := kubecli.NewMinimalCloneWithNS("testclone", metav1.NamespaceDefault)
 	vmClone.Spec.Source = newValidObjReference()
 	vmClone.Spec.Target = newValidObjReference()
