@@ -30,6 +30,7 @@ import (
 	"strings"
 
 	"kubevirt.io/kubevirt/pkg/storage/utils"
+	"kubevirt.io/kubevirt/pkg/tpm"
 
 	backendstorage "kubevirt.io/kubevirt/pkg/storage/backend-storage"
 
@@ -2349,7 +2350,7 @@ func validatePersistentState(field *k8sfield.Path, spec *v1.VirtualMachineInstan
 	}
 
 	if !config.VMPersistentStateEnabled() {
-		if backendstorage.HasPersistentTPMDevice(spec) {
+		if tpm.HasPersistentDevice(spec) {
 			causes = append(causes, metav1.StatusCause{
 				Type:    metav1.CauseTypeFieldValueInvalid,
 				Message: fmt.Sprintf("%s feature gate is not enabled in kubevirt-config", featuregate.VMPersistentState),
