@@ -14,6 +14,7 @@ import (
 type NodeSelectorRenderer struct {
 	cpuFeatureLabels []string
 	cpuModelLabel    string
+	machineTypeLabel string
 	hasDedicatedCPU  bool
 	hyperv           bool
 	podNodeSelectors map[string]string
@@ -57,6 +58,11 @@ func (nsr *NodeSelectorRenderer) Render() map[string]string {
 	if nsr.cpuModelLabel != "" && nsr.cpuModelLabel != cpuModelLabel(v1.CPUModeHostModel) && nsr.cpuModelLabel != cpuModelLabel(v1.CPUModeHostPassthrough) {
 		nsr.enableSelectorLabel(nsr.cpuModelLabel)
 	}
+
+	if nsr.machineTypeLabel != "" {
+		nsr.enableSelectorLabel(nsr.machineTypeLabel)
+	}
+
 	for _, cpuFeatureLabel := range nsr.cpuFeatureLabels {
 		nsr.enableSelectorLabel(cpuFeatureLabel)
 	}
@@ -121,6 +127,13 @@ func WithModelAndFeatureLabels(modelLabel string, cpuFeatureLabels ...string) No
 	}
 }
 
+func WithMachineType(machineType string) NodeSelectorRendererOption {
+	return func(renderer *NodeSelectorRenderer) {
+		machineTypeLabelKey := v1.SupportedMachineTypeLabel + machineType
+		renderer.machineTypeLabel = machineTypeLabelKey
+	}
+}
+
 func WithTSCTimer(tscFrequency *int64) NodeSelectorRendererOption {
 	return func(renderer *NodeSelectorRenderer) {
 		renderer.tscFrequency = tscFrequency
