@@ -34,9 +34,10 @@ import (
 	"k8s.io/apimachinery/pkg/runtime"
 	k8sfake "k8s.io/client-go/kubernetes/fake"
 	"k8s.io/client-go/testing"
+	"k8s.io/client-go/tools/cache"
 	"k8s.io/client-go/tools/record"
 
-	clonev1alpha1 "kubevirt.io/api/clone/v1alpha1"
+	clone "kubevirt.io/api/clone/v1beta1"
 	virtv1 "kubevirt.io/api/core/v1"
 	snapshotv1 "kubevirt.io/api/snapshot/v1beta1"
 	"kubevirt.io/client-go/kubecli"
@@ -44,6 +45,7 @@ import (
 
 	"kubevirt.io/kubevirt/pkg/apimachinery/patch"
 	kvcontroller "kubevirt.io/kubevirt/pkg/controller"
+	controllertesting "kubevirt.io/kubevirt/pkg/controller/testing"
 	"kubevirt.io/kubevirt/pkg/libvmi"
 	"kubevirt.io/kubevirt/pkg/pointer"
 	"kubevirt.io/kubevirt/pkg/testutils"
@@ -63,12 +65,12 @@ var _ = Describe("Clone", func() {
 	var (
 		controller *VMCloneController
 		recorder   *record.FakeRecorder
-		mockQueue  *testutils.MockWorkQueue
+		mockQueue  *testutils.MockWorkQueue[string]
 
 		client    *kubevirtfake.Clientset
 		k8sClient *k8sfake.Clientset
 		sourceVM  *virtv1.VirtualMachine
-		vmClone   *clonev1alpha1.VirtualMachineClone
+		vmClone   *clone.VirtualMachineClone
 	)
 
 	addVM := func(vm *virtv1.VirtualMachine) {
@@ -76,9 +78,9 @@ var _ = Describe("Clone", func() {
 		Expect(err).ShouldNot(HaveOccurred())
 	}
 
-	addClone := func(vmClone *clonev1alpha1.VirtualMachineClone) {
+	addClone := func(vmClone *clone.VirtualMachineClone) {
 		var err error
-		vmClone, err = client.CloneV1alpha1().VirtualMachineClones(metav1.NamespaceDefault).Create(context.TODO(), vmClone, metav1.CreateOptions{})
+		vmClone, err = client.CloneV1beta1().VirtualMachineClones(metav1.NamespaceDefault).Create(context.TODO(), vmClone, metav1.CreateOptions{})
 		Expect(err).ToNot(HaveOccurred())
 		controller.vmCloneIndexer.Add(vmClone)
 		key, err := kvcontroller.KeyFunc(vmClone)
@@ -135,7 +137,7 @@ var _ = Describe("Clone", func() {
 		validateOwnerReference(vmRestore.OwnerReferences[0], vmClone)
 	}
 
-	expectRestoreCreationFailure := func(snapshotName string, vmClone *clonev1alpha1.VirtualMachineClone, restoreName string) {
+	expectRestoreCreationFailure := func(snapshotName string, vmClone *clone.VirtualMachineClone, restoreName string) {
 		client.Fake.PrependReactor("create", restoreResource, func(action testing.Action) (handled bool, ret runtime.Object, err error) {
 			create, ok := action.(testing.CreateAction)
 			Expect(ok).To(BeTrue())
@@ -154,15 +156,15 @@ var _ = Describe("Clone", func() {
 		Expect(err).To(MatchError(errors.IsNotFound, "k8serrors.IsNotFound"), "Restore should not exists")
 	}
 
-	expectCloneBeInPhase := func(phase clonev1alpha1.VirtualMachineClonePhase) {
-		clone, err := client.CloneV1alpha1().VirtualMachineClones(metav1.NamespaceDefault).Get(context.TODO(), vmClone.Name, metav1.GetOptions{})
+	expectCloneBeInPhase := func(phase clone.VirtualMachineClonePhase) {
+		clone, err := client.CloneV1beta1().VirtualMachineClones(metav1.NamespaceDefault).Get(context.TODO(), vmClone.Name, metav1.GetOptions{})
 		Expect(err).ToNot(HaveOccurred())
 		Expect(clone).ToNot(BeNil())
 		Expect(clone.Status.Phase).To(Equal(phase))
 	}
 
 	expectCloneDeletion := func() {
-		_, err := client.CloneV1alpha1().VirtualMachineClones(metav1.NamespaceDefault).Get(context.TODO(), vmClone.Name, metav1.GetOptions{})
+		_, err := client.CloneV1beta1().VirtualMachineClones(metav1.NamespaceDefault).Get(context.TODO(), vmClone.Name, metav1.GetOptions{})
 		Expect(err).To(HaveOccurred())
 		Expect(errors.IsNotFound(err)).To(BeTrue())
 	}
@@ -171,7 +173,7 @@ var _ = Describe("Clone", func() {
 		testutils.ExpectEvent(recorder, string(event))
 	}
 
-	setSnapshotSource := func(vmClone *clonev1alpha1.VirtualMachineClone, snapshotName string) {
+	setSnapshotSource := func(vmClone *clone.VirtualMachineClone, snapshotName string) {
 		source := vmClone.Spec.Source
 		source.APIGroup = pointer.P(snapshotAPIGroup)
 		source.Kind = "VirtualMachineSnapshot"
@@ -209,7 +211,7 @@ var _ = Describe("Clone", func() {
 		vmInformer, _ := testutils.NewFakeInformerFor(&virtv1.VirtualMachine{})
 		snapshotInformer, _ := testutils.NewFakeInformerFor(&snapshotv1.VirtualMachineSnapshot{})
 		restoreInformer, _ := testutils.NewFakeInformerFor(&snapshotv1.VirtualMachineRestore{})
-		cloneInformer, _ := testutils.NewFakeInformerFor(&clonev1alpha1.VirtualMachineClone{})
+		cloneInformer, _ := testutils.NewFakeInformerFor(&clone.VirtualMachineClone{})
 		snapshotContentInformer, _ := testutils.NewFakeInformerFor(&snapshotv1.VirtualMachineSnapshotContent{})
 		pvcInformer, _ := testutils.NewFakeInformerFor(&k8sv1.PersistentVolumeClaim{})
 
@@ -232,7 +234,7 @@ var _ = Describe("Clone", func() {
 
 		client = kubevirtfake.NewSimpleClientset()
 
-		virtClient.EXPECT().VirtualMachineClone(metav1.NamespaceDefault).Return(client.CloneV1alpha1().VirtualMachineClones(metav1.NamespaceDefault)).AnyTimes()
+		virtClient.EXPECT().VirtualMachineClone(metav1.NamespaceDefault).Return(client.CloneV1beta1().VirtualMachineClones(metav1.NamespaceDefault)).AnyTimes()
 		virtClient.EXPECT().VirtualMachineSnapshot(metav1.NamespaceDefault).Return(client.SnapshotV1beta1().VirtualMachineSnapshots(metav1.NamespaceDefault)).AnyTimes()
 		virtClient.EXPECT().VirtualMachineRestore(metav1.NamespaceDefault).Return(client.SnapshotV1beta1().VirtualMachineRestores(metav1.NamespaceDefault)).AnyTimes()
 		virtClient.EXPECT().VirtualMachineSnapshotContent(metav1.NamespaceDefault).Return(client.SnapshotV1beta1().VirtualMachineSnapshotContents(metav1.NamespaceDefault)).AnyTimes()
@@ -245,21 +247,92 @@ var _ = Describe("Clone", func() {
 		virtClient.EXPECT().AppsV1().Return(k8sClient.AppsV1()).AnyTimes()
 	})
 
+	sanityExecute := func() {
+		controllertesting.SanityExecute(controller, []cache.Store{
+			controller.vmCloneIndexer, controller.snapshotContentStore, controller.restoreStore, controller.vmStore,
+			controller.snapshotContentStore, controller.pvcStore,
+		}, Default)
+	}
+
 	Context("basic controller operations", func() {
 		Context("with source VM", func() {
-			DescribeTable("should create snapshot if not exists yet", func(phase clonev1alpha1.VirtualMachineClonePhase) {
+			It("should report event if source VM doesn't exist, phase shouldn't change", func() {
+				vmClone.Status.Phase = clone.PhaseUnset
+				addClone(vmClone)
+
+				controller.Execute()
+				expectEvent(SourceDoesNotExist)
+				expectCloneBeInPhase(clone.PhaseUnset)
+			})
+
+			It("clone should fail if source VM has backendstorage", func() {
+				sourceVM.Spec.Template.Spec.Domain.Devices.TPM = &virtv1.TPMDevice{
+					Persistent: pointer.P(true),
+				}
+				addVM(sourceVM)
+				vmClone.Status.Phase = clone.PhaseUnset
+				addClone(vmClone)
+
+				controller.Execute()
+				expectEvent(SourceWithBackendStorageInvalid)
+				expectCloneBeInPhase(clone.Failed)
+			})
+
+			It("should report event if VM volumeSnapshots are invalid", func() {
+				sourceVM.Spec.Template.Spec.Volumes = append(sourceVM.Spec.Template.Spec.Volumes, virtv1.Volume{
+					Name: "disk0",
+					VolumeSource: virtv1.VolumeSource{
+						DataVolume: &virtv1.DataVolumeSource{
+							Name: "testdv",
+						},
+					},
+				})
+				addVM(sourceVM)
+				vmClone.Status.Phase = clone.PhaseUnset
+				addClone(vmClone)
+
+				controller.Execute()
+				expectEvent(VMVolumeSnapshotsInvalid)
+				expectCloneBeInPhase(clone.PhaseUnset)
+			})
+
+			It("should report event if VM volumeSnapshots are not snapshotable", func() {
+				sourceVM.Spec.Template.Spec.Volumes = append(sourceVM.Spec.Template.Spec.Volumes, virtv1.Volume{
+					Name: "disk0",
+					VolumeSource: virtv1.VolumeSource{
+						DataVolume: &virtv1.DataVolumeSource{
+							Name: "testdv",
+						},
+					},
+				})
+				sourceVM.Status.VolumeSnapshotStatuses = []virtv1.VolumeSnapshotStatus{
+					{
+						Name:    "disk0",
+						Enabled: false,
+					},
+				}
+				addVM(sourceVM)
+				vmClone.Status.Phase = clone.PhaseUnset
+				addClone(vmClone)
+
+				controller.Execute()
+				expectEvent(VMVolumeSnapshotsInvalid)
+				expectCloneBeInPhase(clone.PhaseUnset)
+			})
+
+			DescribeTable("should create snapshot if not exists yet", func(phase clone.VirtualMachineClonePhase) {
 				vmClone.Status.Phase = phase
 
 				addVM(sourceVM)
 				addClone(vmClone)
 
-				controller.Execute()
+				sanityExecute()
 				expectEvent(SnapshotCreated)
 				expectSnapshotExists()
-				expectCloneBeInPhase(clonev1alpha1.SnapshotInProgress)
+				expectCloneBeInPhase(clone.SnapshotInProgress)
 			},
-				Entry("with phase unset", clonev1alpha1.PhaseUnset),
-				Entry("with phase snapshot in progress", clonev1alpha1.SnapshotInProgress),
+				Entry("with phase unset", clone.PhaseUnset),
+				Entry("with phase snapshot in progress", clone.SnapshotInProgress),
 			)
 
 			When("snapshot is created", func() {
@@ -273,15 +346,15 @@ var _ = Describe("Clone", func() {
 					snapshot.Status.ReadyToUse = pointer.P(false)
 
 					vmClone.Status.SnapshotName = pointer.P(snapshot.Name)
-					vmClone.Status.Phase = clonev1alpha1.SnapshotInProgress
+					vmClone.Status.Phase = clone.SnapshotInProgress
 
 					addVM(sourceVM)
 					addClone(vmClone)
 					addSnapshot(snapshot)
 
-					controller.Execute()
+					sanityExecute()
 					Expect(recorder.Events).To(BeEmpty())
-					expectCloneBeInPhase(clonev1alpha1.SnapshotInProgress)
+					expectCloneBeInPhase(clone.SnapshotInProgress)
 					expectRestoreDoesNotExist()
 				})
 
@@ -291,17 +364,17 @@ var _ = Describe("Clone", func() {
 					snapshot.Status.ReadyToUse = pointer.P(true)
 
 					vmClone.Status.SnapshotName = pointer.P(snapshot.Name)
-					vmClone.Status.Phase = clonev1alpha1.SnapshotInProgress
+					vmClone.Status.Phase = clone.SnapshotInProgress
 
 					addVM(sourceVM)
 					addClone(vmClone)
 					addSnapshot(snapshot)
 					addSnapshotContent(snapshotContent)
 
-					controller.Execute()
+					sanityExecute()
 					expectEvent(SnapshotReady)
 					expectEvent(RestoreCreated)
-					expectCloneBeInPhase(clonev1alpha1.RestoreInProgress)
+					expectCloneBeInPhase(clone.RestoreInProgress)
 					expectRestoreExists()
 				})
 			})
@@ -323,16 +396,16 @@ var _ = Describe("Clone", func() {
 
 					vmClone.Status.SnapshotName = pointer.P(snapshot.Name)
 					vmClone.Status.RestoreName = pointer.P(restore.Name)
-					vmClone.Status.Phase = clonev1alpha1.RestoreInProgress
+					vmClone.Status.Phase = clone.RestoreInProgress
 
 					addVM(sourceVM)
 					addClone(vmClone)
 					addSnapshot(snapshot)
 					addRestore(restore)
 
-					controller.Execute()
+					sanityExecute()
 					Expect(recorder.Events).To(BeEmpty())
-					expectCloneBeInPhase(clonev1alpha1.RestoreInProgress)
+					expectCloneBeInPhase(clone.RestoreInProgress)
 				})
 
 				It("and is ready - should update status", func() {
@@ -340,16 +413,16 @@ var _ = Describe("Clone", func() {
 
 					vmClone.Status.SnapshotName = pointer.P(snapshot.Name)
 					vmClone.Status.RestoreName = pointer.P(restore.Name)
-					vmClone.Status.Phase = clonev1alpha1.RestoreInProgress
+					vmClone.Status.Phase = clone.RestoreInProgress
 
 					addVM(sourceVM)
 					addClone(vmClone)
 					addSnapshot(snapshot)
 					addRestore(restore)
 
-					controller.Execute()
+					sanityExecute()
 					expectEvent(RestoreReady)
-					expectCloneBeInPhase(clonev1alpha1.CreatingTargetVM)
+					expectCloneBeInPhase(clone.CreatingTargetVM)
 				})
 			})
 
@@ -366,7 +439,7 @@ var _ = Describe("Clone", func() {
 					restore.Status.Complete = pointer.P(true)
 					vmClone.Status.SnapshotName = pointer.P(snapshot.Name)
 					vmClone.Status.RestoreName = pointer.P(restore.Name)
-					vmClone.Status.Phase = clonev1alpha1.CreatingTargetVM
+					vmClone.Status.Phase = clone.CreatingTargetVM
 				})
 
 				It("and the target VM is not ready - should do nothing", func() {
@@ -375,9 +448,9 @@ var _ = Describe("Clone", func() {
 					addSnapshot(snapshot)
 					addRestore(restore)
 
-					controller.Execute()
+					sanityExecute()
 					Expect(recorder.Events).To(BeEmpty())
-					expectCloneBeInPhase(clonev1alpha1.CreatingTargetVM)
+					expectCloneBeInPhase(clone.CreatingTargetVM)
 				})
 
 				It("and the target VM ready should move to Succeeded phase", func() {
@@ -390,9 +463,9 @@ var _ = Describe("Clone", func() {
 					addSnapshot(snapshot)
 					addRestore(restore)
 
-					controller.Execute()
+					sanityExecute()
 					expectEvent(TargetVMCreated)
-					expectCloneBeInPhase(clonev1alpha1.Succeeded)
+					expectCloneBeInPhase(clone.Succeeded)
 					expectSnapshotDoesNotExist()
 					expectRestoreDoesNotExist()
 				})
@@ -419,7 +492,7 @@ var _ = Describe("Clone", func() {
 
 					vmClone.Status.SnapshotName = pointer.P(snapshot.Name)
 					vmClone.Status.RestoreName = pointer.P(restore.Name)
-					vmClone.Status.Phase = clonev1alpha1.Succeeded
+					vmClone.Status.Phase = clone.Succeeded
 					vmClone.Status.TargetName = pointer.P(vmClone.Spec.Target.Name)
 
 					targetVM := sourceVM.DeepCopy()
@@ -434,9 +507,9 @@ var _ = Describe("Clone", func() {
 				})
 
 				It("if not all the PVCs are bound, nothing should happen", func() {
-					controller.Execute()
+					sanityExecute()
 					Expect(recorder.Events).To(BeEmpty())
-					expectCloneBeInPhase(clonev1alpha1.Succeeded)
+					expectCloneBeInPhase(clone.Succeeded)
 					expectSnapshotExists()
 					expectRestoreExists()
 				})
@@ -444,7 +517,7 @@ var _ = Describe("Clone", func() {
 				It("if all the pvc are bound, snapshot and restore should be deleted", func() {
 					pvc = createPVC(sourceVM.Namespace, k8sv1.ClaimBound)
 					addPVC(pvc)
-					controller.Execute()
+					sanityExecute()
 					expectEvent(PVCBound)
 					expectSnapshotDoesNotExist()
 					expectRestoreDoesNotExist()
@@ -457,20 +530,20 @@ var _ = Describe("Clone", func() {
 
 				vmClone.Status.SnapshotName = pointer.P(testSnapshotName)
 				vmClone.Status.RestoreName = pointer.P(restore.Name)
-				vmClone.Status.Phase = clonev1alpha1.RestoreInProgress
+				vmClone.Status.Phase = clone.RestoreInProgress
 
 				addVM(sourceVM)
 				addClone(vmClone)
 				addRestore(restore)
 
-				controller.Execute()
+				sanityExecute()
 				expectEvent(SnapshotDeleted)
-				expectCloneBeInPhase(clonev1alpha1.Failed)
+				expectCloneBeInPhase(clone.Failed)
 				expectSnapshotDoesNotExist()
 			})
 
 			It("when snapshot already exists and vmclone is not update yet- should update the clone phase", func() {
-				vmClone.Status.Phase = clonev1alpha1.PhaseUnset
+				vmClone.Status.Phase = clone.PhaseUnset
 
 				addVM(sourceVM)
 				addClone(vmClone)
@@ -478,8 +551,8 @@ var _ = Describe("Clone", func() {
 				snapshot := createVirtualMachineSnapshot(sourceVM)
 				addSnapshot(snapshot)
 
-				controller.Execute()
-				expectCloneBeInPhase(clonev1alpha1.SnapshotInProgress)
+				sanityExecute()
+				expectCloneBeInPhase(clone.SnapshotInProgress)
 			})
 
 			When("restore already exists and vmclone is not updated yet", func() {
@@ -491,15 +564,15 @@ var _ = Describe("Clone", func() {
 
 					vmClone.Status.SnapshotName = pointer.P(snapshot.Name)
 
-					vmClone.Status.Phase = clonev1alpha1.SnapshotInProgress
+					vmClone.Status.Phase = clone.SnapshotInProgress
 
 					addVM(sourceVM)
 					addClone(vmClone)
 					addSnapshot(snapshot)
 					addRestore(restore)
 
-					controller.Execute()
-					expectCloneBeInPhase(clonev1alpha1.RestoreInProgress)
+					sanityExecute()
+					expectCloneBeInPhase(clone.RestoreInProgress)
 					expectEvent(SnapshotReady)
 				})
 			})
@@ -513,7 +586,7 @@ var _ = Describe("Clone", func() {
 
 					vmClone.Status.SnapshotName = pointer.P(snapshot.Name)
 
-					vmClone.Status.Phase = clonev1alpha1.SnapshotInProgress
+					vmClone.Status.Phase = clone.SnapshotInProgress
 
 					expectRestoreCreationFailure(snapshot.Name, vmClone, restore.Name)
 					addVM(sourceVM)
@@ -521,8 +594,8 @@ var _ = Describe("Clone", func() {
 					addSnapshot(snapshot)
 					addSnapshotContent(snapshotContent)
 
-					controller.Execute()
-					expectCloneBeInPhase(clonev1alpha1.RestoreInProgress)
+					sanityExecute()
+					expectCloneBeInPhase(clone.RestoreInProgress)
 					expectEvent(SnapshotReady)
 					expectEvent(RestoreCreationFailed)
 				})
@@ -531,13 +604,13 @@ var _ = Describe("Clone", func() {
 			When("target VM is deleted", func() {
 				It("should delete the vm clone resource", func() {
 					vmClone.Status.TargetName = pointer.P("target-vm-name")
-					vmClone.Status.Phase = clonev1alpha1.Succeeded
+					vmClone.Status.Phase = clone.Succeeded
 
 					addVM(sourceVM)
 					addClone(vmClone)
 					//no target vm added => target vm deleted
 
-					controller.Execute()
+					sanityExecute()
 					expectCloneDeletion()
 				})
 			})
@@ -552,14 +625,14 @@ var _ = Describe("Clone", func() {
 				setSnapshotSource(vmClone, snapshot.Name)
 
 				vmClone.Status.SnapshotName = pointer.P(snapshot.Name)
-				vmClone.Status.Phase = clonev1alpha1.SnapshotInProgress
+				vmClone.Status.Phase = clone.SnapshotInProgress
 
 				addClone(vmClone)
 				addSnapshot(snapshot)
 
-				controller.Execute()
+				sanityExecute()
 				Expect(recorder.Events).To(BeEmpty())
-				expectCloneBeInPhase(clonev1alpha1.SnapshotInProgress)
+				expectCloneBeInPhase(clone.SnapshotInProgress)
 				expectRestoreDoesNotExist()
 			})
 
@@ -573,10 +646,10 @@ var _ = Describe("Clone", func() {
 				addSnapshot(snapshot)
 				addSnapshotContent(snapshotContent)
 
-				controller.Execute()
+				sanityExecute()
 				expectEvent(SnapshotReady)
 				expectEvent(RestoreCreated)
-				expectCloneBeInPhase(clonev1alpha1.RestoreInProgress)
+				expectCloneBeInPhase(clone.RestoreInProgress)
 				expectRestoreExists()
 			})
 
@@ -589,14 +662,14 @@ var _ = Describe("Clone", func() {
 				restore := createVirtualMachineRestore(sourceVM, snapshot.Name)
 
 				vmClone.Status.SnapshotName = pointer.P(snapshot.Name)
-				vmClone.Status.Phase = clonev1alpha1.PhaseUnset
+				vmClone.Status.Phase = clone.PhaseUnset
 
 				addClone(vmClone)
 				addSnapshot(snapshot)
 				addRestore(restore)
 
-				controller.Execute()
-				expectCloneBeInPhase(clonev1alpha1.RestoreInProgress)
+				sanityExecute()
+				expectCloneBeInPhase(clone.RestoreInProgress)
 			})
 		})
 	})
@@ -607,7 +680,7 @@ var _ = Describe("Clone", func() {
 			snapshot.Status.ReadyToUse = pointer.P(true)
 
 			vmClone.Status.SnapshotName = pointer.P(snapshot.Name)
-			vmClone.Status.Phase = clonev1alpha1.RestoreInProgress
+			vmClone.Status.Phase = clone.RestoreInProgress
 
 			addVM(sourceVM)
 			addSnapshot(snapshot)
@@ -617,7 +690,7 @@ var _ = Describe("Clone", func() {
 
 		AfterEach(func() {
 			expectEvent(RestoreCreated)
-			expectCloneBeInPhase(clonev1alpha1.RestoreInProgress)
+			expectCloneBeInPhase(clone.RestoreInProgress)
 		})
 
 		offlinePatchVM := func(vm *virtv1.VirtualMachine, patches []string) (virtv1.VirtualMachine, error) {
@@ -686,7 +759,7 @@ var _ = Describe("Clone", func() {
 				expectedInterfaces := expectedVM.Spec.Template.Spec.Domain.Devices.Interfaces
 				expectedInterfaces[0].MacAddress = ""
 
-				controller.Execute()
+				sanityExecute()
 				expectVMCreationFromPatches(expectedVM)
 			})
 
@@ -705,7 +778,7 @@ var _ = Describe("Clone", func() {
 				expectedInterfaces := expectedVM.Spec.Template.Spec.Domain.Devices.Interfaces
 				expectedInterfaces[0].MacAddress = newMacAddress
 
-				controller.Execute()
+				sanityExecute()
 				expectVMCreationFromPatches(expectedVM)
 			})
 
@@ -743,7 +816,7 @@ var _ = Describe("Clone", func() {
 				expectedVM := sourceVM.DeepCopy()
 				expectedVM.Spec.Template.Spec.Domain.Devices.Interfaces = expectedInterfaces
 
-				controller.Execute()
+				sanityExecute()
 				expectVMCreationFromPatches(expectedVM)
 			})
 		})
@@ -769,14 +842,14 @@ var _ = Describe("Clone", func() {
 			It("should delete smbios serial if serial is not provided", func() {
 				addClone(vmClone)
 
-				controller.Execute()
+				sanityExecute()
 				expectSMbiosSerial(emptySerial)
 			})
 
 			It("if serial is defined in clone spec - should use the one in clone spec", func() {
 				vmClone.Spec.NewSMBiosSerial = pointer.P(manuallySetSerial)
 				addClone(vmClone)
-				controller.Execute()
+				sanityExecute()
 				expectSMbiosSerial(manuallySetSerial)
 			})
 		})
@@ -824,7 +897,7 @@ var _ = Describe("Clone", func() {
 					vmClone.Spec.AnnotationFilters = filters
 				}
 				addClone(vmClone)
-				controller.Execute()
+				sanityExecute()
 				expectLabelsOrAnnotations(map[string]string{
 					"prefix1/something1":    trueStr,
 					"somePrefix2/something": trueStr,
@@ -845,7 +918,7 @@ var _ = Describe("Clone", func() {
 				addVM(sourceVM)
 				addClone(vmClone)
 
-				controller.Execute()
+				sanityExecute()
 				restore, err := client.SnapshotV1beta1().VirtualMachineRestores(metav1.NamespaceDefault).Get(context.TODO(), testRestoreName, metav1.GetOptions{})
 				Expect(err).ToNot(HaveOccurred())
 				Expect(restore.Spec.VirtualMachineSnapshotName).To(Equal(testSnapshotName))
@@ -867,7 +940,7 @@ var _ = Describe("Clone", func() {
 				addVM(sourceVM)
 				addClone(vmClone)
 
-				controller.Execute()
+				sanityExecute()
 				restore, err := client.SnapshotV1beta1().VirtualMachineRestores(metav1.NamespaceDefault).Get(context.TODO(), testRestoreName, metav1.GetOptions{})
 				Expect(err).ToNot(HaveOccurred())
 				Expect(restore.Spec.VirtualMachineSnapshotName).To(Equal(testSnapshotName))
@@ -893,11 +966,33 @@ var _ = Describe("Clone", func() {
 				Expect(expectedFirmware).ShouldNot(BeNil())
 
 				expectedFirmware.UUID = ""
-				controller.Execute()
+				sanityExecute()
 				expectVMCreationFromPatches(expectedVM)
 			})
 		})
 
+		Context("Target VM name", func() {
+			expectTargetVMNameExist := func() {
+				restore, err := client.SnapshotV1beta1().VirtualMachineRestores(metav1.NamespaceDefault).Get(context.TODO(), testRestoreName, metav1.GetOptions{})
+				Expect(err).ToNot(HaveOccurred())
+				Expect(restore.Spec.VirtualMachineSnapshotName).To(Equal(testSnapshotName))
+				patchedVM, err := offlinePatchVM(sourceVM, restore.Spec.Patches)
+				Expect(err).ToNot(HaveOccurred())
+				Expect(patchedVM.Name).ToNot(BeNil())
+			}
+
+			It("should generate target vm name if it is not provided", func() {
+				vmClone.Spec.Target = &k8sv1.TypedLocalObjectReference{
+					APIGroup: pointer.P(vmAPIGroup),
+					Kind:     "VirtualMachine",
+				}
+				addClone(vmClone)
+				controller.Execute()
+				expectTargetVMNameExist()
+			})
+
+		})
+
 	})
 })
 
@@ -977,8 +1072,8 @@ func validateOwnerReference(ownerRef metav1.OwnerReference, expectedOwner metav1
 
 	Expect(ownerRef.UID).To(Equal(expectedOwner.GetUID()), err)
 	Expect(ownerRef.Name).To(Equal(expectedOwner.GetName()), err)
-	Expect(ownerRef.Kind).To(Equal(clonev1alpha1.VirtualMachineCloneKind.Kind), err)
-	Expect(ownerRef.APIVersion).To(Equal(clonev1alpha1.VirtualMachineCloneKind.GroupVersion().String()), err)
+	Expect(ownerRef.Kind).To(Equal(clone.VirtualMachineCloneKind.Kind), err)
+	Expect(ownerRef.APIVersion).To(Equal(clone.VirtualMachineCloneKind.GroupVersion().String()), err)
 	Expect(ownerRef.BlockOwnerDeletion).ToNot(BeNil(), err)
 	Expect(*ownerRef.BlockOwnerDeletion).To(BeTrue(), err)
 	Expect(ownerRef.Controller).ToNot(BeNil(), err)
@@ -989,8 +1084,8 @@ func createOwnerReference(owner metav1.Object) metav1.OwnerReference {
 	return metav1.OwnerReference{
 		UID:                owner.GetUID(),
 		Name:               owner.GetName(),
-		Kind:               clonev1alpha1.VirtualMachineCloneKind.Kind,
-		APIVersion:         clonev1alpha1.VirtualMachineCloneKind.GroupVersion().String(),
+		Kind:               clone.VirtualMachineCloneKind.Kind,
+		APIVersion:         clone.VirtualMachineCloneKind.GroupVersion().String(),
 		BlockOwnerDeletion: pointer.P(true),
 		Controller:         pointer.P(true),
 	}
