@@ -27,6 +27,7 @@ import (
 	"kubevirt.io/client-go/log"
 	"kubevirt.io/client-go/testing"
 
+	controllertesting "kubevirt.io/kubevirt/pkg/controller/testing"
 	"kubevirt.io/kubevirt/pkg/testutils"
 	watchtesting "kubevirt.io/kubevirt/pkg/virt-controller/watch/testing"
 )
@@ -42,10 +43,10 @@ var _ = Describe("Node controller with", func() {
 	var stop chan struct{}
 	var controller *Controller
 	var recorder *record.FakeRecorder
-	var mockQueue *testutils.MockWorkQueue
+	var mockQueue *testutils.MockWorkQueue[string]
 	var virtClient *kubecli.MockKubevirtClient
 	var kubeClient *fake.Clientset
-	var vmiFeeder *testutils.VirtualMachineFeeder
+	var vmiFeeder *testutils.VirtualMachineFeeder[string]
 
 	syncCaches := func(stop chan struct{}) {
 		go nodeInformer.Run(stop)
@@ -115,6 +116,12 @@ var _ = Describe("Node controller with", func() {
 		Expect(updatedVMI.Status.Reason).To(Equal(NodeUnresponsiveReason))
 	}
 
+	sanityExecute := func() {
+		controllertesting.SanityExecute(controller, []cache.Store{
+			controller.vmiStore, controller.nodeStore,
+		}, Default)
+	}
+
 	Context("pods and vmis given", func() {
 		It("should only select stuck vmis", func() {
 			node := NewHealthyNode("test")
@@ -149,7 +156,7 @@ var _ = Describe("Node controller with", func() {
 
 			addNode(node)
 
-			controller.Execute()
+			sanityExecute()
 		})
 	})
 
@@ -167,7 +174,7 @@ var _ = Describe("Node controller with", func() {
 				return true, nil, nil
 			})
 
-			controller.Execute()
+			sanityExecute()
 			testutils.ExpectEvent(recorder, NodeUnresponsiveReason)
 		})
 		DescribeTable("should set a vmi without a pod to failed state if the vmi is in ", func(phase v1.VirtualMachineInstancePhase) {
@@ -224,7 +231,7 @@ var _ = Describe("Node controller with", func() {
 				return true, &k8sv1.PodList{}, nil
 			})
 
-			controller.Execute()
+			sanityExecute()
 			testutils.ExpectEvent(recorder, NodeUnresponsiveReason)
 			expectVMIToFailedStatus(vmi.Name)
 		})
@@ -257,7 +264,7 @@ var _ = Describe("Node controller with", func() {
 				return true, &k8sv1.PodList{}, nil
 			})
 
-			controller.Execute()
+			sanityExecute()
 			testutils.ExpectEvent(recorder, NodeUnresponsiveReason)
 			expectVMIToFailedStatus(vmi.Name)
 		})
@@ -277,7 +284,7 @@ var _ = Describe("Node controller with", func() {
 				return true, &k8sv1.PodList{}, nil
 			})
 
-			controller.Execute()
+			sanityExecute()
 			testutils.ExpectEvent(recorder, NodeUnresponsiveReason)
 			expectVMIToFailedStatus(vmi.Name)
 		})
@@ -297,7 +304,7 @@ var _ = Describe("Node controller with", func() {
 				return true, &k8sv1.PodList{}, nil
 			})
 
-			controller.Execute()
+			sanityExecute()
 			testutils.ExpectEvent(recorder, NodeUnresponsiveReason)
 			expectVMIToFailedStatus(vmi.Name)
 		})
@@ -317,7 +324,7 @@ var _ = Describe("Node controller with", func() {
 				return true, &k8sv1.PodList{Items: []k8sv1.Pod{*NewUnhealthyPodForVirtualMachine("whatever", vmi)}}, nil
 			})
 
-			controller.Execute()
+			sanityExecute()
 			testutils.ExpectEvent(recorder, NodeUnresponsiveReason)
 			expectVMIToFailedStatus(vmi.Name)
 		})
