@@ -36,9 +36,9 @@ import (
 	v1 "kubevirt.io/api/core/v1"
 	"kubevirt.io/client-go/kubecli"
 	"kubevirt.io/client-go/kubevirt/fake"
-	"kubevirt.io/containerized-data-importer-api/pkg/apis/core/v1beta1"
 	cdiv1 "kubevirt.io/containerized-data-importer-api/pkg/apis/core/v1beta1"
 
+	"kubevirt.io/kubevirt/pkg/libdv"
 	"kubevirt.io/kubevirt/pkg/libvmi"
 	libvmistatus "kubevirt.io/kubevirt/pkg/libvmi/status"
 	"kubevirt.io/kubevirt/pkg/pointer"
@@ -69,8 +69,8 @@ var _ = Describe("Volume Migration", func() {
 			dataVolumeStore = dataVolumeInformer.GetStore()
 			pvcStore = pvcInformer.GetStore()
 
-			dvCSI = newDataVolume(csiDVName, ns, map[string]string{popAnn: "true"})
-			dvNoSCSI = newDataVolume(noCSIDVName, ns, map[string]string{popAnn: "true"})
+			dvCSI = libdv.NewDataVolume(libdv.WithNamespace(ns), libdv.WithName(csiDVName), libdv.WithAnnotation(popAnn, "true"))
+			dvNoSCSI = libdv.NewDataVolume(libdv.WithNamespace(ns), libdv.WithName(noCSIDVName), libdv.WithAnnotation(popAnn, "true"))
 			pvcCSI := &k8sv1.PersistentVolumeClaim{
 				ObjectMeta: metav1.ObjectMeta{
 					Name:      csiDVName,
@@ -149,7 +149,7 @@ var _ = Describe("Volume Migration", func() {
 
 		It("should return an error if the PVC doesn't exist", func() {
 			const dvName = "testdv"
-			dv := newDataVolume(dvName, ns, nil)
+			dv := libdv.NewDataVolume(libdv.WithNamespace(ns), libdv.WithName(dvName))
 			Expect(dataVolumeStore.Add(dv)).To(Succeed())
 			vmi := libvmi.New(libvmi.WithNamespace(ns), libvmi.WithDataVolume("disk0", "vol0"))
 			vm := libvmi.NewVirtualMachine(libvmi.New(libvmi.WithNamespace(ns), libvmi.WithDataVolume("disk0", dvName)))
@@ -159,7 +159,7 @@ var _ = Describe("Volume Migration", func() {
 
 		It("should validate the migrated volume with a DV in succeeded phase", func() {
 			const dvName = "testdv"
-			dv := newDataVolume(dvName, ns, nil)
+			dv := libdv.NewDataVolume(libdv.WithNamespace(ns), libdv.WithName(dvName))
 			dv.Status.Phase = cdiv1.Succeeded
 			pvc := &k8sv1.PersistentVolumeClaim{
 				ObjectMeta: metav1.ObjectMeta{
@@ -631,16 +631,3 @@ func addVMIOptionsForVolumes(vols []string) []libvmi.Option {
 	}
 	return ops
 }
-func newDataVolume(name, ns string, annotations map[string]string) *v1beta1.DataVolume {
-	return &v1beta1.DataVolume{
-		TypeMeta: metav1.TypeMeta{
-			APIVersion: "cdi.kubevirt.io/v1beta1",
-			Kind:       "DataVolume",
-		},
-		ObjectMeta: metav1.ObjectMeta{
-			Name:        name,
-			Namespace:   ns,
-			Annotations: annotations,
-		},
-	}
-}
