@@ -25,6 +25,7 @@ import (
 	"kubevirt.io/client-go/testing"
 
 	virtcontroller "kubevirt.io/kubevirt/pkg/controller"
+	controllertesting "kubevirt.io/kubevirt/pkg/controller/testing"
 	"kubevirt.io/kubevirt/pkg/libvmi"
 	libvmistatus "kubevirt.io/kubevirt/pkg/libvmi/status"
 	metrics "kubevirt.io/kubevirt/pkg/monitoring/metrics/virt-controller"
@@ -62,6 +63,12 @@ var _ = Describe("Workload Updater", func() {
 		})
 	}
 
+	sanityExecute := func() {
+		controllertesting.SanityExecute(controller, []cache.Store{
+			controller.vmiStore, controller.podIndexer, controller.migrationStore, controller.kubeVirtStore,
+		}, Default)
+	}
+
 	BeforeEach(func() {
 
 		expectedImage = "cur-image"
@@ -120,7 +127,7 @@ var _ = Describe("Workload Updater", func() {
 			controller.podIndexer.Add(pod)
 			waitForNumberOfInstancesOnVMIInformerCache(controller, 1)
 
-			controller.Execute()
+			sanityExecute()
 			testutils.ExpectEvent(recorder, SuccessfulCreateVirtualMachineInstanceMigrationReason)
 			migrations, err := fakeVirtClient.KubevirtV1().VirtualMachineInstanceMigrations(k8sv1.NamespaceDefault).List(context.Background(), metav1.ListOptions{})
 			Expect(err).ToNot(HaveOccurred())
@@ -140,7 +147,7 @@ var _ = Describe("Workload Updater", func() {
 			controller.podIndexer.Add(pod)
 			waitForNumberOfInstancesOnVMIInformerCache(controller, 1)
 
-			controller.Execute()
+			sanityExecute()
 			Expect(recorder.Events).To(BeEmpty())
 			Expect(fakeVirtClient.Actions()).To(BeEmpty())
 		})
@@ -192,7 +199,7 @@ var _ = Describe("Workload Updater", func() {
 			evictionCount := 0
 			shouldExpectMultiplePodEvictions(&evictionCount)
 
-			controller.Execute()
+			sanityExecute()
 			testutils.ExpectEvents(recorder, reasons...)
 
 			By("Checking prometheus metric")
@@ -243,7 +250,7 @@ var _ = Describe("Workload Updater", func() {
 			evictionCount := 0
 			shouldExpectMultiplePodEvictions(&evictionCount)
 
-			controller.Execute()
+			sanityExecute()
 			testutils.ExpectEvents(recorder, reasons...)
 
 			Expect(evictionCount).To(Equal(defaultBatchDeletionCount))
@@ -284,7 +291,7 @@ var _ = Describe("Workload Updater", func() {
 
 			waitForNumberOfInstancesOnVMIInformerCache(controller, desiredNumberOfVMs)
 
-			controller.Execute()
+			sanityExecute()
 			testutils.ExpectEvents(recorder, reasons...)
 
 			migrations, err := fakeVirtClient.KubevirtV1().VirtualMachineInstanceMigrations(k8sv1.NamespaceDefault).List(context.Background(), metav1.ListOptions{})
@@ -327,7 +334,7 @@ var _ = Describe("Workload Updater", func() {
 			evictionCount := 0
 			shouldExpectMultiplePodEvictions(&evictionCount)
 
-			controller.Execute()
+			sanityExecute()
 			testutils.ExpectEvents(recorder, reasons...)
 			Expect(evictionCount).To(Equal(1))
 
@@ -356,7 +363,7 @@ var _ = Describe("Workload Updater", func() {
 			waitForNumberOfInstancesOnVMIInformerCache(controller, totalVMs)
 			kv := newKubeVirt(totalVMs)
 			addKubeVirt(kv)
-			controller.Execute()
+			sanityExecute()
 			Expect(fakeVirtClient.Actions()).To(BeEmpty())
 		})
 
@@ -381,7 +388,7 @@ var _ = Describe("Workload Updater", func() {
 			evictionCount := 0
 			shouldExpectMultiplePodEvictions(&evictionCount)
 
-			controller.Execute()
+			sanityExecute()
 			testutils.ExpectEvents(recorder, reasons...)
 			Expect(evictionCount).To(Equal(defaultBatchDeletionCount))
 
@@ -409,7 +416,7 @@ var _ = Describe("Workload Updater", func() {
 
 			waitForNumberOfInstancesOnVMIInformerCache(controller, desiredNumberOfVMs)
 
-			controller.Execute()
+			sanityExecute()
 			Expect(recorder.Events).To(BeEmpty())
 		})
 
@@ -436,7 +443,7 @@ var _ = Describe("Workload Updater", func() {
 			evictionCount := 0
 			shouldExpectMultiplePodEvictions(&evictionCount)
 
-			controller.Execute()
+			sanityExecute()
 			testutils.ExpectEvents(recorder, reasons...)
 			Expect(evictionCount).To(Equal(batchDeletions))
 		})
@@ -467,12 +474,12 @@ var _ = Describe("Workload Updater", func() {
 			shouldExpectMultiplePodEvictions(&evictionCount)
 
 			addKubeVirt(kv)
-			controller.Execute()
+			sanityExecute()
 			testutils.ExpectEvents(recorder, reasons...)
 
 			// Should do nothing this second execute due to interval
 			addKubeVirt(kv)
-			controller.Execute()
+			sanityExecute()
 			Expect(recorder.Events).To(BeEmpty())
 
 			// Shift time for batch interval
@@ -480,7 +487,7 @@ var _ = Describe("Workload Updater", func() {
 
 			// Should execute another batch of deletions after sleep
 			addKubeVirt(kv)
-			controller.Execute()
+			sanityExecute()
 			testutils.ExpectEvents(recorder, reasons...)
 			Expect(evictionCount).To(Equal(batchDeletions * 2))
 		})
@@ -563,7 +570,7 @@ var _ = Describe("Workload Updater", func() {
 			vmi := createVM(withoutAnnotation, withoutMemoryChangeCondition)
 			mig := createMig(vmi.Name, phase)
 
-			controller.Execute()
+			sanityExecute()
 			if mig.IsFinal() {
 				Expect(recorder.Events).To(BeEmpty())
 			} else {
@@ -584,7 +591,7 @@ var _ = Describe("Workload Updater", func() {
 				mig = createMig(vmi.Name, v1.MigrationRunning)
 			}
 			changeAborted := hasMig && !hasCond
-			controller.Execute()
+			sanityExecute()
 			if changeAborted {
 				testutils.ExpectEvent(recorder, SuccessfulChangeAbortionReason)
 				_, err := fakeVirtClient.KubevirtV1().VirtualMachineInstanceMigrations(mig.Namespace).Get(context.Background(), mig.Name, metav1.GetOptions{})
@@ -601,7 +608,7 @@ var _ = Describe("Workload Updater", func() {
 		DescribeTable("should always cancel the migration when the testWorkloadUpdateMigrationAbortion annotation is present", func(hasCond bool) {
 			vmi := createVM(withAnnotation, hasCond)
 			mig := createMig(vmi.Name, v1.MigrationRunning)
-			controller.Execute()
+			sanityExecute()
 			testutils.ExpectEvent(recorder, SuccessfulChangeAbortionReason)
 			_, err := fakeVirtClient.KubevirtV1().VirtualMachineInstanceMigrations(mig.Namespace).Get(context.Background(), mig.Name, metav1.GetOptions{})
 			Expect(err).To(MatchError(k8serrors.IsNotFound, "IsNotFound"))
@@ -617,7 +624,7 @@ var _ = Describe("Workload Updater", func() {
 				return true, nil, fmt.Errorf("some error")
 			})
 
-			controller.Execute()
+			sanityExecute()
 			testutils.ExpectEvent(recorder, FailedChangeAbortionReason)
 			_, err := fakeVirtClient.KubevirtV1().VirtualMachineInstanceMigrations(mig.Namespace).Get(context.Background(), mig.Name, metav1.GetOptions{})
 			Expect(err).ToNot(HaveOccurred())
@@ -643,7 +650,7 @@ var _ = Describe("Workload Updater", func() {
 			)
 			controller.vmiStore.Add(vmi)
 			createMig(vmi.Name, v1.MigrationRunning)
-			controller.Execute()
+			sanityExecute()
 			Expect(recorder.Events).To(BeEmpty())
 			// Ensure that the deletion operation isn't called. The test reproduces the race when the migration operation
 			// was completed, but the migration object was still in running phase and it was accidentally deleted.
