@@ -232,7 +232,7 @@ func (m *mounter) MountAndVerify(vmi *v1.VirtualMachineInstance) (map[string]*co
 			diskName := containerdisk.GetDiskTargetName(i)
 			// If diskName is a symlink it will fail if the target exists.
 			if err := safepath.TouchAtNoFollow(diskTargetDir, diskName, os.ModePerm); err != nil {
-				if err != nil && !os.IsExist(err) {
+				if !os.IsExist(err) {
 					return nil, fmt.Errorf("failed to create mount point target: %v", err)
 				}
 			}
