@@ -122,7 +122,7 @@ var _ = Describe("ContainerDisk", func() {
 			Entry("return false and an error if we are outside the tolerated retry period",
 				func(*v1.VirtualMachineInstance, int) (string, error) { return "", fmt.Errorf("not found") },
 				detectForSocketNotCalled,
-				time.Duration(-2*time.Minute),
+				-2*time.Minute,
 				HaveOccurred(),
 				false,
 			),
@@ -136,7 +136,7 @@ var _ = Describe("ContainerDisk", func() {
 			Entry("return true and no error once everything is ready when we are outside of the tolerated retry period",
 				func(*v1.VirtualMachineInstance, int) (string, error) { return "someting", nil },
 				detectsSocket,
-				time.Duration(-2*time.Minute),
+				-2*time.Minute,
 				Succeed(),
 				true,
 			),
@@ -150,7 +150,7 @@ var _ = Describe("ContainerDisk", func() {
 			Entry("return false and an error if we are outside the tolerated retry period but socket is not there",
 				func(*v1.VirtualMachineInstance, int) (string, error) { return "someting", nil },
 				noSocketDetected,
-				time.Duration(-2*time.Minute),
+				-2*time.Minute,
 				HaveOccurred(),
 				false,
 			),
@@ -198,7 +198,7 @@ var _ = Describe("ContainerDisk", func() {
 				Entry("return false and an error if we are outside the tolerated retry period",
 					func(*v1.VirtualMachineInstance) (string, error) { return "", fmt.Errorf("not found") },
 					detectForSocketNotCalled,
-					time.Duration(-2*time.Minute),
+					-2*time.Minute,
 					HaveOccurred(),
 					false,
 				),
@@ -212,7 +212,7 @@ var _ = Describe("ContainerDisk", func() {
 				Entry("return true and no error once everything is ready when we are outside of the tolerated retry period",
 					func(*v1.VirtualMachineInstance) (string, error) { return "someting", nil },
 					detectsSocket,
-					time.Duration(-2*time.Minute),
+					-2*time.Minute,
 					Succeed(),
 					true,
 				),
@@ -227,7 +227,7 @@ var _ = Describe("ContainerDisk", func() {
 				Entry("return false and an error if we are outside the tolerated retry period but socket is not there",
 					func(*v1.VirtualMachineInstance) (string, error) { return "someting", nil },
 					noSocketDetected,
-					time.Duration(-2*time.Minute),
+					-2*time.Minute,
 					HaveOccurred(),
 					false,
 				),
@@ -403,7 +403,7 @@ var _ = Describe("ContainerDisk", func() {
 					Expect(err).ToNot(HaveOccurred())
 					defer kernelFile.Close()
 
-					_, err = (kernelFile.Write(args.kernel))
+					_, err = kernelFile.Write(args.kernel)
 					Expect(err).ToNot(HaveOccurred())
 
 					kernelBootVMI.Spec.Domain.Firmware.KernelBoot.Container.KernelPath = filepath.Join("/", filepath.Base(kernelFile.Name()))
@@ -414,7 +414,7 @@ var _ = Describe("ContainerDisk", func() {
 					Expect(err).ToNot(HaveOccurred())
 					defer initrdFile.Close()
 
-					_, err = (initrdFile.Write(args.initrd))
+					_, err = initrdFile.Write(args.initrd)
 					Expect(err).ToNot(HaveOccurred())
 
 					kernelBootVMI.Spec.Domain.Firmware.KernelBoot.Container.InitrdPath = filepath.Join("/", filepath.Base(initrdFile.Name()))
