@@ -22,7 +22,6 @@ package device_manager
 import (
 	"bufio"
 	"context"
-	"errors"
 	"fmt"
 	"net"
 	"os"
@@ -71,18 +70,10 @@ func (dev *USBDevice) GetID() string {
 
 // The actual plugin
 type USBDevicePlugin struct {
-	socketPath   string
-	stop         <-chan struct{}
-	update       chan struct{}
-	done         chan struct{}
-	deregistered chan struct{}
-	server       *grpc.Server
-	resourceName string
-	devices      []*PluginDevices
-	logger       *log.FilteredLogger
-
-	initialized bool
-	lock        *sync.Mutex
+	*DevicePluginBase
+	update  chan struct{}
+	devices []*PluginDevices
+	logger  *log.FilteredLogger
 }
 
 type PluginDevices struct {
@@ -99,6 +90,51 @@ func newPluginDevices(resourceName string, index int, usbdevs []*USBDevice) *Plu
 	}
 }
 
+func (plugin *USBDevicePlugin) Start(stop <-chan struct{}) error {
+	plugin.stop = stop
+
+	err := plugin.cleanup()
+	if err != nil {
+		return fmt.Errorf("error on cleanup: %v", err)
+	}
+
+	sock, err := net.Listen("unix", plugin.socketPath)
+	if err != nil {
+		return fmt.Errorf("error creating GRPC server socket: %v", err)
+	}
+
+	plugin.server = grpc.NewServer([]grpc.ServerOption{}...)
+	defer plugin.stopDevicePlugin()
+
+	pluginapi.RegisterDevicePluginServer(plugin.server, plugin)
+
+	errChan := make(chan error, 2)
+
+	go func() {
+		errChan <- plugin.server.Serve(sock)
+	}()
+
+	err = waitForGRPCServer(plugin.socketPath, 5*time.Second)
+	if err != nil {
+		return fmt.Errorf("error starting the GRPC server: %v", err)
+	}
+
+	err = plugin.register()
+	if err != nil {
+		return fmt.Errorf("error registering with device plugin manager: %v", err)
+	}
+
+	go func() {
+		errChan <- plugin.healthCheck()
+	}()
+
+	plugin.setInitialized(true)
+	plugin.logger.Infof("%s device plugin started", plugin.resourceName)
+	err = <-errChan
+
+	return err
+}
+
 func (pd *PluginDevices) toKubeVirtDevicePlugin() *pluginapi.Device {
 	healthStr := pluginapi.Healthy
 	if !pd.isHealthy {
@@ -187,53 +223,6 @@ func (plugin *USBDevicePlugin) stopDevicePlugin() error {
 	return plugin.cleanup()
 }
 
-func (plugin *USBDevicePlugin) Start(stop <-chan struct{}) error {
-	plugin.stop = stop
-	plugin.done = make(chan struct{})
-	plugin.deregistered = make(chan struct{})
-
-	err := plugin.cleanup()
-	if err != nil {
-		return fmt.Errorf("error on cleanup: %v", err)
-	}
-
-	sock, err := net.Listen("unix", plugin.socketPath)
-	if err != nil {
-		return fmt.Errorf("error creating GRPC server socket: %v", err)
-	}
-
-	plugin.server = grpc.NewServer([]grpc.ServerOption{}...)
-	defer plugin.stopDevicePlugin()
-
-	pluginapi.RegisterDevicePluginServer(plugin.server, plugin)
-
-	errChan := make(chan error, 2)
-
-	go func() {
-		errChan <- plugin.server.Serve(sock)
-	}()
-
-	err = waitForGRPCServer(plugin.socketPath, 5*time.Second)
-	if err != nil {
-		return fmt.Errorf("error starting the GRPC server: %v", err)
-	}
-
-	err = plugin.register()
-	if err != nil {
-		return fmt.Errorf("error registering with device plugin manager: %v", err)
-	}
-
-	go func() {
-		errChan <- plugin.healthCheck()
-	}()
-
-	plugin.setInitialized(true)
-	plugin.logger.Infof("%s device plugin started", plugin.resourceName)
-	err = <-errChan
-
-	return err
-}
-
 func (plugin *USBDevicePlugin) healthCheck() error {
 	monitoredDevices := make(map[string]string)
 	watcher, err := fsnotify.NewWatcher()
@@ -295,14 +284,6 @@ func (plugin *USBDevicePlugin) healthCheck() error {
 	}
 }
 
-func (plugin *USBDevicePlugin) cleanup() error {
-	err := os.Remove(plugin.socketPath)
-	if err != nil && !errors.Is(err, os.ErrNotExist) {
-		return err
-	}
-	return nil
-}
-
 func (plugin *USBDevicePlugin) register() error {
 	conn, err := grpc.Dial(pluginapi.KubeletSocket,
 		grpc.WithInsecure(),
@@ -331,12 +312,6 @@ func (plugin *USBDevicePlugin) register() error {
 	return nil
 }
 
-func (plugin *USBDevicePlugin) GetDevicePluginOptions(ctx context.Context, _ *pluginapi.Empty) (*pluginapi.DevicePluginOptions, error) {
-	return &pluginapi.DevicePluginOptions{
-		PreStartRequired: false,
-	}, nil
-}
-
 // Interface to expose Devices: IDs, health and Topology
 func (plugin *USBDevicePlugin) ListAndWatch(_ *pluginapi.Empty, lws pluginapi.DevicePlugin_ListAndWatchServer) error {
 	sendUpdate := func(devices []*pluginapi.Device) error {
@@ -425,10 +400,6 @@ func (plugin *USBDevicePlugin) Allocate(_ context.Context, allocRequest *plugina
 	return allocResponse, nil
 }
 
-func (plugin *USBDevicePlugin) PreStartContainer(context.Context, *pluginapi.PreStartContainerRequest) (*pluginapi.PreStartContainerResponse, error) {
-	return &pluginapi.PreStartContainerResponse{}, nil
-}
-
 func parseSysUeventFile(path string) *USBDevice {
 	// Grab all details we are interested from uevent
 	file, err := os.Open(filepath.Join(path, "uevent"))
@@ -633,12 +604,18 @@ func NewUSBDevicePlugin(resourceName string, pluginDevices []*PluginDevices) *US
 		resourceID = s[1]
 	}
 	resourceID = fmt.Sprintf("usb-%s", resourceID)
-	return &USBDevicePlugin{
-		socketPath:   SocketPath(resourceID),
-		resourceName: resourceName,
-		devices:      pluginDevices,
-		logger:       log.Log.With("subcomponent", resourceID),
-		initialized:  false,
-		lock:         &sync.Mutex{},
+	usb := &USBDevicePlugin{
+		DevicePluginBase: &DevicePluginBase{
+			socketPath:   SocketPath(resourceID),
+			resourceName: resourceName,
+			initialized:  false,
+			lock:         &sync.Mutex{},
+			health:       make(chan deviceHealth),
+			done:         make(chan struct{}),
+			deregistered: make(chan struct{}),
+		},
+		devices: pluginDevices,
+		logger:  log.Log.With("subcomponent", resourceID),
 	}
+	return usb
 }
