@@ -30,9 +30,9 @@ import (
 	v1 "kubevirt.io/api/core/v1"
 )
 
-func getVMI(request *restful.Request, vmiInformer cache.SharedIndexInformer) (*v1.VirtualMachineInstance, int, error) {
+func getVMI(request *restful.Request, vmiStore cache.Store) (*v1.VirtualMachineInstance, int, error) {
 	key := fmt.Sprintf("%s/%s", request.PathParameter("namespace"), request.PathParameter("name"))
-	vmiObj, vmiExists, err := vmiInformer.GetStore().GetByKey(key)
+	vmiObj, vmiExists, err := vmiStore.GetByKey(key)
 	if err != nil {
 		return nil, http.StatusInternalServerError, err
 	}
