@@ -90,12 +90,7 @@ type VirtOperatorApp struct {
 
 	operatorNamespace string
 
-	kubeVirtInformer cache.SharedIndexInformer
-	kubeVirtCache    cache.Store
-
-	crdInformer cache.SharedIndexInformer
-
-	stores    util.Stores
+	config    util.OperatorConfig
 	informers util.Informers
 
 	LeaderElection      leaderelectionconfig.Configuration
@@ -171,18 +166,18 @@ func Execute() {
 		os.Exit(0)
 	}
 
+	app.config = util.OperatorConfig{}
+
 	app.informerFactory = controller.NewKubeInformerFactory(app.restClient, app.clientSet, app.aggregatorClient, app.operatorNamespace)
-
-	app.kubeVirtInformer = app.informerFactory.KubeVirt()
-	app.kubeVirtCache = app.kubeVirtInformer.GetStore()
-
 	app.informers = util.Informers{
+		KubeVirt:                 app.informerFactory.KubeVirt(),
+		CRD:                      app.informerFactory.CRD(),
 		ServiceAccount:           app.informerFactory.OperatorServiceAccount(),
 		ClusterRole:              app.informerFactory.OperatorClusterRole(),
 		ClusterRoleBinding:       app.informerFactory.OperatorClusterRoleBinding(),
 		Role:                     app.informerFactory.OperatorRole(),
 		RoleBinding:              app.informerFactory.OperatorRoleBinding(),
-		Crd:                      app.informerFactory.OperatorCRD(),
+		OperatorCrd:              app.informerFactory.OperatorCRD(),
 		Service:                  app.informerFactory.OperatorService(),
 		Deployment:               app.informerFactory.OperatorDeployment(),
 		DaemonSet:                app.informerFactory.OperatorDaemonSet(),
@@ -200,32 +195,6 @@ func Execute() {
 		ClusterPreference:        app.informerFactory.VirtualMachineClusterPreference(),
 	}
 
-	app.stores = util.Stores{
-		ServiceAccountCache:           app.informerFactory.OperatorServiceAccount().GetStore(),
-		ClusterRoleCache:              app.informerFactory.OperatorClusterRole().GetStore(),
-		ClusterRoleBindingCache:       app.informerFactory.OperatorClusterRoleBinding().GetStore(),
-		RoleCache:                     app.informerFactory.OperatorRole().GetStore(),
-		RoleBindingCache:              app.informerFactory.OperatorRoleBinding().GetStore(),
-		CrdCache:                      app.informerFactory.OperatorCRD().GetStore(),
-		ServiceCache:                  app.informerFactory.OperatorService().GetStore(),
-		DeploymentCache:               app.informerFactory.OperatorDeployment().GetStore(),
-		DaemonSetCache:                app.informerFactory.OperatorDaemonSet().GetStore(),
-		ValidationWebhookCache:        app.informerFactory.OperatorValidationWebhook().GetStore(),
-		MutatingWebhookCache:          app.informerFactory.OperatorMutatingWebhook().GetStore(),
-		APIServiceCache:               app.informerFactory.OperatorAPIService().GetStore(),
-		InstallStrategyConfigMapCache: app.informerFactory.OperatorInstallStrategyConfigMaps().GetStore(),
-		InstallStrategyJobCache:       app.informerFactory.OperatorInstallStrategyJob().GetStore(),
-		InfrastructurePodCache:        app.informerFactory.OperatorPod().GetStore(),
-		PodDisruptionBudgetCache:      app.informerFactory.OperatorPodDisruptionBudget().GetStore(),
-		NamespaceCache:                app.informerFactory.Namespace().GetStore(),
-		SecretCache:                   app.informerFactory.Secrets().GetStore(),
-		ConfigMapCache:                app.informerFactory.OperatorConfigMap().GetStore(),
-		ClusterInstancetype:           app.informerFactory.VirtualMachineClusterInstancetype().GetStore(),
-		ClusterPreference:             app.informerFactory.VirtualMachineClusterPreference().GetStore(),
-	}
-
-	app.crdInformer = app.informerFactory.CRD()
-
 	onOpenShift, err := clusterutil.IsOnOpenShift(app.clientSet)
 	if err != nil {
 		golog.Fatalf("Error determining cluster type: %v", err)
@@ -233,16 +202,12 @@ func Execute() {
 	if onOpenShift {
 		log.Log.Info("we are on openshift")
 		app.informers.SCC = app.informerFactory.OperatorSCC()
-		app.stores.SCCCache = app.informerFactory.OperatorSCC().GetStore()
 		app.informers.Route = app.informerFactory.OperatorRoute()
-		app.stores.RouteCache = app.informerFactory.OperatorRoute().GetStore()
-		app.stores.IsOnOpenshift = true
+		app.config.IsOnOpenshift = true
 	} else {
 		log.Log.Info("we are on kubernetes")
 		app.informers.SCC = app.informerFactory.DummyOperatorSCC()
-		app.stores.SCCCache = app.informerFactory.DummyOperatorSCC().GetStore()
 		app.informers.Route = app.informerFactory.DummyOperatorRoute()
-		app.stores.RouteCache = app.informerFactory.DummyOperatorRoute().GetStore()
 	}
 
 	serviceMonitorEnabled, err := util.IsServiceMonitorEnabled(app.clientSet)
@@ -252,13 +217,11 @@ func Execute() {
 	if serviceMonitorEnabled {
 		log.Log.Info("servicemonitor is defined")
 		app.informers.ServiceMonitor = app.informerFactory.OperatorServiceMonitor()
-		app.stores.ServiceMonitorCache = app.informerFactory.OperatorServiceMonitor().GetStore()
 
-		app.stores.ServiceMonitorEnabled = true
+		app.config.ServiceMonitorEnabled = true
 	} else {
 		log.Log.Info("servicemonitor is not defined")
 		app.informers.ServiceMonitor = app.informerFactory.DummyOperatorServiceMonitor()
-		app.stores.ServiceMonitorCache = app.informerFactory.DummyOperatorServiceMonitor().GetStore()
 	}
 
 	prometheusRuleEnabled, err := util.IsPrometheusRuleEnabled(app.clientSet)
@@ -268,12 +231,10 @@ func Execute() {
 	if prometheusRuleEnabled {
 		log.Log.Info("prometheusrule is defined")
 		app.informers.PrometheusRule = app.informerFactory.OperatorPrometheusRule()
-		app.stores.PrometheusRuleCache = app.informerFactory.OperatorPrometheusRule().GetStore()
-		app.stores.PrometheusRulesEnabled = true
+		app.config.PrometheusRulesEnabled = true
 	} else {
 		log.Log.Info("prometheusrule is not defined")
 		app.informers.PrometheusRule = app.informerFactory.DummyOperatorPrometheusRule()
-		app.stores.PrometheusRuleCache = app.informerFactory.DummyOperatorPrometheusRule().GetStore()
 	}
 
 	validatingAdmissionPolicyBindingEnabled, err := util.IsValidatingAdmissionPolicyBindingEnabled(app.clientSet)
@@ -283,12 +244,10 @@ func Execute() {
 	if validatingAdmissionPolicyBindingEnabled {
 		log.Log.Info("validatingAdmissionPolicyBindingEnabled is defined")
 		app.informers.ValidatingAdmissionPolicyBinding = app.informerFactory.OperatorValidatingAdmissionPolicyBinding()
-		app.stores.ValidatingAdmissionPolicyBindingCache = app.informerFactory.OperatorValidatingAdmissionPolicyBinding().GetStore()
-		app.stores.ValidatingAdmissionPolicyBindingEnabled = true
+		app.config.ValidatingAdmissionPolicyBindingEnabled = true
 	} else {
 		log.Log.Info("validatingAdmissionPolicyBindingEnabled is not defined")
 		app.informers.ValidatingAdmissionPolicyBinding = app.informerFactory.DummyOperatorValidatingAdmissionPolicyBinding()
-		app.stores.ValidatingAdmissionPolicyBindingCache = app.informerFactory.DummyOperatorValidatingAdmissionPolicyBinding().GetStore()
 	}
 
 	validatingAdmissionPolicyEnabled, err := util.IsValidatingAdmissionPolicyEnabled(app.clientSet)
@@ -298,18 +257,16 @@ func Execute() {
 	if validatingAdmissionPolicyEnabled {
 		log.Log.Info("validatingAdmissionPolicyEnabled is defined")
 		app.informers.ValidatingAdmissionPolicy = app.informerFactory.OperatorValidatingAdmissionPolicy()
-		app.stores.ValidatingAdmissionPolicyCache = app.informerFactory.OperatorValidatingAdmissionPolicy().GetStore()
-		app.stores.ValidatingAdmissionPolicyEnabled = true
+		app.config.ValidatingAdmissionPolicyEnabled = true
 	} else {
 		log.Log.Info("validatingAdmissionPolicyEnabled is not defined")
 		app.informers.ValidatingAdmissionPolicy = app.informerFactory.DummyOperatorValidatingAdmissionPolicy()
-		app.stores.ValidatingAdmissionPolicyCache = app.informerFactory.DummyOperatorValidatingAdmissionPolicy().GetStore()
 	}
 
 	app.prepareCertManagers()
 
 	app.kubeVirtRecorder = app.getNewRecorder(k8sv1.NamespaceAll, VirtOperator)
-	app.kubeVirtController, err = NewKubeVirtController(app.clientSet, app.aggregatorClient.ApiregistrationV1().APIServices(), app.kubeVirtInformer, app.kubeVirtRecorder, app.stores, app.informers, app.operatorNamespace)
+	app.kubeVirtController, err = NewKubeVirtController(app.clientSet, app.aggregatorClient.ApiregistrationV1().APIServices(), app.kubeVirtRecorder, app.config, app.informers, app.operatorNamespace)
 	if err != nil {
 		panic(err)
 	}
@@ -403,7 +360,7 @@ func (app *VirtOperatorApp) Run() {
 	app.informerFactory.Start(stop)
 
 	stopChan := app.ctx.Done()
-	cache.WaitForCacheSync(stopChan, app.crdInformer.HasSynced, app.kubeVirtInformer.HasSynced)
+	cache.WaitForCacheSync(stopChan, app.informers.CRD.HasSynced, app.informers.KubeVirt.HasSynced)
 	app.clusterConfig.SetConfigModifiedCallback(app.configModificationCallback)
 
 	cache.WaitForCacheSync(stop, apiAuthConfig.HasSynced)
@@ -420,15 +377,15 @@ func (app *VirtOperatorApp) Run() {
 	}
 
 	var mux http.ServeMux
-	mux.HandleFunc("/kubevirt-validate-delete", http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
+	mux.HandleFunc("/kubevirt-validate-delete", func(w http.ResponseWriter, r *http.Request) {
 		validating_webhooks.Serve(w, r, operator_webhooks.NewKubeVirtDeletionAdmitter(app.clientSet))
-	}))
-	mux.HandleFunc(components.KubeVirtUpdateValidatePath, http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
+	})
+	mux.HandleFunc(components.KubeVirtUpdateValidatePath, func(w http.ResponseWriter, r *http.Request) {
 		validating_webhooks.Serve(w, r, operator_webhooks.NewKubeVirtUpdateAdmitter(app.clientSet, app.clusterConfig))
-	}))
-	mux.HandleFunc(components.KubeVirtCreateValidatePath, http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
+	})
+	mux.HandleFunc(components.KubeVirtCreateValidatePath, func(w http.ResponseWriter, r *http.Request) {
 		validating_webhooks.Serve(w, r, operator_webhooks.NewKubeVirtCreateAdmitter(app.clientSet))
-	}))
+	})
 	webhookServer.Handler = &mux
 	go func() {
 		err := webhookServer.ListenAndServeTLS("", "")
@@ -479,8 +436,8 @@ func (app *VirtOperatorApp) configModificationCallback() {
 	msgf := "Reinitialize virt-operator, %s has been %s"
 
 	smEnabled := app.clusterConfig.HasServiceMonitorAPI()
-	if app.stores.ServiceMonitorEnabled != smEnabled {
-		if !app.stores.ServiceMonitorEnabled && smEnabled {
+	if app.config.ServiceMonitorEnabled != smEnabled {
+		if !app.config.ServiceMonitorEnabled && smEnabled {
 			log.Log.Infof(msgf, "ServiceMonitor", "introduced")
 		} else {
 			log.Log.Infof(msgf, "ServiceMonitor", "removed")
@@ -490,8 +447,8 @@ func (app *VirtOperatorApp) configModificationCallback() {
 	}
 
 	prEnabled := app.clusterConfig.HasPrometheusRuleAPI()
-	if app.stores.PrometheusRulesEnabled != prEnabled {
-		if !app.stores.PrometheusRulesEnabled && prEnabled {
+	if app.config.PrometheusRulesEnabled != prEnabled {
+		if !app.config.PrometheusRulesEnabled && prEnabled {
 			log.Log.Infof(msgf, "PrometheusRule", "introduced")
 		} else {
 			log.Log.Infof(msgf, "PrometheusRule", "removed")
