@@ -122,7 +122,7 @@ var _ = Describe("Apply Apps", func() {
 				Registry:        Registry,
 				KubeVirtVersion: Version,
 			}
-			deployment, err = components.NewApiServerDeployment(
+			deployment = components.NewApiServerDeployment(
 				Namespace,
 				virtApiConfig.GetImageRegistry(),
 				virtApiConfig.GetImagePrefix(),
@@ -135,7 +135,6 @@ var _ = Describe("Apply Apps", func() {
 				virtApiConfig.GetImagePullSecrets(),
 				virtApiConfig.GetVerbosity(),
 				virtApiConfig.GetExtraEnv())
-			Expect(err).ToNot(HaveOccurred())
 
 			cachedPodDisruptionBudget = components.NewPodDisruptionBudgetForDeployment(deployment)
 		})
@@ -328,7 +327,7 @@ var _ = Describe("Apply Apps", func() {
 				Registry:        Registry,
 				KubeVirtVersion: Version,
 			}
-			daemonSet, err = components.NewHandlerDaemonSet(
+			daemonSet = components.NewHandlerDaemonSet(
 				Namespace,
 				virtHandlerConfig.GetImageRegistry(),
 				virtHandlerConfig.GetImagePrefix(),
@@ -349,7 +348,6 @@ var _ = Describe("Apply Apps", func() {
 				virtHandlerConfig.GetVerbosity(),
 				virtHandlerConfig.GetExtraEnv(),
 				false)
-			Expect(err).ToNot(HaveOccurred())
 			markHandlerReady(daemonSet)
 			daemonSet.UID = "random-id"
 		})
@@ -1177,14 +1175,17 @@ var _ = Describe("Apply Apps", func() {
 		var ctrl *gomock.Controller
 		const revisionAnnotation = "deployment.kubernetes.io/revision"
 		const fakeAnnotation = "fakeAnnotation.io/fake"
+		var virtAPIDeployment *appsv1.Deployment
+		var dpClient *fake.Clientset
 
 		BeforeEach(func() {
 			ctrl = gomock.NewController(GinkgoT())
 			kvInterface := kubecli.NewMockKubeVirtInterface(ctrl)
 			clientset = kubecli.NewMockKubevirtClient(ctrl)
-			dpClient := fake.NewSimpleClientset()
+			dpClient = fake.NewSimpleClientset()
 			clientset.EXPECT().KubeVirt(Namespace).Return(kvInterface).AnyTimes()
 			clientset.EXPECT().AppsV1().Return(dpClient.AppsV1()).AnyTimes()
+			clientset.EXPECT().CoreV1().Return(dpClient.CoreV1()).AnyTimes()
 
 			kv = &v1.KubeVirt{ObjectMeta: v12.ObjectMeta{Namespace: Namespace}}
 			virtControllerConfig := &util.KubeVirtDeploymentConfig{
@@ -1192,7 +1193,7 @@ var _ = Describe("Apply Apps", func() {
 				KubeVirtVersion: Version,
 			}
 			var err error
-			strategyDeployment, err = components.NewControllerDeployment(
+			strategyDeployment = components.NewControllerDeployment(
 				Namespace,
 				virtControllerConfig.GetImageRegistry(),
 				virtControllerConfig.GetImagePrefix(),
@@ -1211,7 +1212,6 @@ var _ = Describe("Apply Apps", func() {
 				virtControllerConfig.GetImagePullSecrets(),
 				virtControllerConfig.GetVerbosity(),
 				virtControllerConfig.GetExtraEnv())
-			Expect(err).ToNot(HaveOccurred())
 
 			cachedDeployment = strategyDeployment.DeepCopy()
 			cachedDeployment.Generation = 2
@@ -1223,6 +1223,28 @@ var _ = Describe("Apply Apps", func() {
 			Expect(err).NotTo(HaveOccurred())
 
 			stores = util.Stores{DeploymentCache: &MockStore{get: cachedDeployment}}
+
+			virtAPIDeployment = components.NewApiServerDeployment(
+				Namespace,
+				virtControllerConfig.GetImageRegistry(),
+				virtControllerConfig.GetImagePrefix(),
+				virtControllerConfig.GetApiVersion(),
+				"",
+				"",
+				"",
+				virtControllerConfig.VirtApiImage,
+				virtControllerConfig.GetImagePullPolicy(),
+				virtControllerConfig.GetImagePullSecrets(),
+				virtControllerConfig.GetVerbosity(),
+				virtControllerConfig.GetExtraEnv())
+
+			virtAPIDeployment.Generation = 2
+			virtAPIDeployment.Annotations = map[string]string{
+				revisionAnnotation: "4",
+				fakeAnnotation:     "fake",
+			}
+
+			_, err = dpClient.AppsV1().Deployments(Namespace).Create(context.TODO(), virtAPIDeployment, metav1.CreateOptions{})
 		})
 
 		It("should not remove revision annotation", func() {
@@ -1247,5 +1269,35 @@ var _ = Describe("Apply Apps", func() {
 			Expect(updatedDeploy.Annotations).To(HaveKeyWithValue(revisionAnnotation, "4"))
 			Expect(updatedDeploy.Annotations).ToNot(HaveKey(fakeAnnotation))
 		})
+
+		DescribeTable("should calculate correct replicas for deployments based on node count", func(nodesCount int, expectedReplicas int) {
+			createFakeNodes(dpClient, nodesCount)
+
+			r := &Reconciler{
+				clientset:    clientset,
+				kv:           kv,
+				expectations: &util.Expectations{},
+				stores:       stores,
+			}
+
+			updatedDeployment, err := r.syncDeployment(virtAPIDeployment)
+			Expect(err).ToNot(HaveOccurred())
+			Expect(*updatedDeployment.Spec.Replicas).To(BeEquivalentTo(expectedReplicas))
+		},
+			Entry("Single-node cluster", 1, 1),
+			Entry("Small cluster with 5 nodes", 5, 2),
+			Entry("Medium cluster with 50 nodes", 50, 5),
+		)
 	})
 })
+
+func createFakeNodes(client *fake.Clientset, count int) {
+	for i := range count {
+		_, err := client.CoreV1().Nodes().Create(context.TODO(), &corev1.Node{
+			ObjectMeta: metav1.ObjectMeta{
+				Name: fmt.Sprintf("node-%d", i),
+			},
+		}, metav1.CreateOptions{})
+		Expect(err).ToNot(HaveOccurred())
+	}
+}
