@@ -25,6 +25,7 @@ import (
 	"kubevirt.io/api/clone"
 
 	clonev1alpha1 "kubevirt.io/api/clone/v1alpha1"
+	clonev1beta1 "kubevirt.io/api/clone/v1beta1"
 
 	"kubevirt.io/api/instancetype"
 
@@ -50,10 +51,9 @@ import (
 )
 
 const (
-	creationTimestampJSONPath  = ".metadata.creationTimestamp"
-	errorMessageJSONPath       = ".status.error.message"
-	phaseJSONPath              = ".status.phase"
-	preserveUnknownFieldsFalse = false
+	creationTimestampJSONPath = ".metadata.creationTimestamp"
+	errorMessageJSONPath      = ".status.error.message"
+	phaseJSONPath             = ".status.phase"
 )
 
 var (
@@ -68,8 +68,7 @@ var (
 	VIRTUALMACHINESNAPSHOTCONTENT    = "virtualmachinesnapshotcontents." + snapshotv1beta1.SchemeGroupVersion.Group
 	VIRTUALMACHINEEXPORT             = "virtualmachineexports." + exportv1beta1.SchemeGroupVersion.Group
 	MIGRATIONPOLICY                  = "migrationpolicies." + migrationsv1.MigrationPolicyKind.Group
-	VIRTUALMACHINECLONE              = "virtualmachineclones." + clonev1alpha1.VirtualMachineCloneKind.Group
-	PreserveUnknownFieldsFalse       = false
+	VIRTUALMACHINECLONE              = "virtualmachineclones." + clone.GroupName
 )
 
 func addFieldsToVersion(version *extv1.CustomResourceDefinitionVersion, fields ...interface{}) error {
@@ -99,8 +98,6 @@ func addFieldsToAllVersions(crd *extv1.CustomResourceDefinition, fields ...inter
 
 func patchValidation(crd *extv1.CustomResourceDefinition, version *extv1.CustomResourceDefinitionVersion) error {
 	name := crd.Spec.Names.Singular
-
-	crd.Spec.PreserveUnknownFields = preserveUnknownFieldsFalse
 	validation, ok := CRDsValidation[name]
 	if !ok {
 		return nil
@@ -877,6 +874,11 @@ func NewVirtualMachineCloneCrd() (*extv1.CustomResourceDefinition, error) {
 			{
 				Name:    clonev1alpha1.SchemeGroupVersion.Version,
 				Served:  true,
+				Storage: false,
+			},
+			{
+				Name:    clonev1beta1.SchemeGroupVersion.Version,
+				Served:  true,
 				Storage: true,
 			},
 		},
