@@ -76,6 +76,7 @@ const (
 	apiVMInstancesFreeze                    = "virtualmachineinstances/freeze"
 	apiVMInstancesUnfreeze                  = "virtualmachineinstances/unfreeze"
 	apiVMInstancesSoftReboot                = "virtualmachineinstances/softreboot"
+	apiVMInstancesReset                     = "virtualmachineinstances/reset"
 	apiVMInstancesGuestOSInfo               = "virtualmachineinstances/guestosinfo"
 	apiVMInstancesFileSysList               = "virtualmachineinstances/filesystemlist"
 	apiVMInstancesUserList                  = "virtualmachineinstances/userlist"
@@ -95,6 +96,7 @@ func GetAllCluster() []runtime.Object {
 		newViewClusterRole(),
 		newInstancetypeViewClusterRole(),
 		newInstancetypeViewClusterRoleBinding(),
+		newMigrateClusterRole(),
 	}
 }
 
@@ -218,6 +220,7 @@ func newAdminClusterRole() *rbacv1.ClusterRole {
 					apiVMInstancesFreeze,
 					apiVMInstancesUnfreeze,
 					apiVMInstancesSoftReboot,
+					apiVMInstancesReset,
 					apiVMInstancesSEVSetupSession,
 					apiVMInstancesSEVInjectLaunchSecret,
 				},
@@ -247,7 +250,6 @@ func newAdminClusterRole() *rbacv1.ClusterRole {
 					apiVMRestart,
 					apiVMAddVolume,
 					apiVMRemoveVolume,
-					apiVMMigrate,
 					apiVMMemoryDump,
 				},
 				Verbs: []string{
@@ -274,12 +276,22 @@ func newAdminClusterRole() *rbacv1.ClusterRole {
 					apiVMInstances,
 					apiVMIPresets,
 					apiVMIReplicasets,
-					apiVMIMigrations,
 				},
 				Verbs: []string{
 					"get", "delete", "create", "update", "patch", "list", "watch", "deletecollection",
 				},
 			},
+			{
+				APIGroups: []string{
+					GroupName,
+				},
+				Resources: []string{
+					apiVMIMigrations,
+				},
+				Verbs: []string{
+					"get", "list", "watch",
+				},
+			},
 			{
 				APIGroups: []string{
 					snapshot.GroupName,
@@ -401,6 +413,7 @@ func newEditClusterRole() *rbacv1.ClusterRole {
 					apiVMInstancesFreeze,
 					apiVMInstancesUnfreeze,
 					apiVMInstancesSoftReboot,
+					apiVMInstancesReset,
 					apiVMInstancesSEVSetupSession,
 					apiVMInstancesSEVInjectLaunchSecret,
 				},
@@ -430,7 +443,6 @@ func newEditClusterRole() *rbacv1.ClusterRole {
 					apiVMRestart,
 					apiVMAddVolume,
 					apiVMRemoveVolume,
-					apiVMMigrate,
 					apiVMMemoryDump,
 				},
 				Verbs: []string{
@@ -457,12 +469,22 @@ func newEditClusterRole() *rbacv1.ClusterRole {
 					apiVMInstances,
 					apiVMIPresets,
 					apiVMIReplicasets,
-					apiVMIMigrations,
 				},
 				Verbs: []string{
 					"get", "delete", "create", "update", "patch", "list", "watch",
 				},
 			},
+			{
+				APIGroups: []string{
+					GroupName,
+				},
+				Resources: []string{
+					apiVMIMigrations,
+				},
+				Verbs: []string{
+					"get", "list", "watch",
+				},
+			},
 			{
 				APIGroups: []string{
 					snapshot.GroupName,
@@ -549,6 +571,45 @@ func newEditClusterRole() *rbacv1.ClusterRole {
 	}
 }
 
+func newMigrateClusterRole() *rbacv1.ClusterRole {
+	return &rbacv1.ClusterRole{
+		TypeMeta: metav1.TypeMeta{
+			APIVersion: VersionNamev1,
+			Kind:       "ClusterRole",
+		},
+		ObjectMeta: metav1.ObjectMeta{
+			Name: "kubevirt.io:migrate",
+			Labels: map[string]string{
+				virtv1.AppLabel: "",
+			},
+		},
+		Rules: []rbacv1.PolicyRule{
+			{
+				APIGroups: []string{
+					virtv1.SubresourceGroupName,
+				},
+				Resources: []string{
+					apiVMMigrate,
+				},
+				Verbs: []string{
+					"update",
+				},
+			},
+			{
+				APIGroups: []string{
+					GroupName,
+				},
+				Resources: []string{
+					apiVMIMigrations,
+				},
+				Verbs: []string{
+					"get", "delete", "create", "update", "patch", "list", "watch", "deletecollection",
+				},
+			},
+		},
+	}
+}
+
 func newViewClusterRole() *rbacv1.ClusterRole {
 	return &rbacv1.ClusterRole{
 		TypeMeta: metav1.TypeMeta{
