@@ -3,10 +3,7 @@ package adm
 import (
 	"github.com/spf13/cobra"
 
-	"k8s.io/client-go/tools/clientcmd"
-
 	"kubevirt.io/kubevirt/pkg/virtctl/adm/logverbosity"
-
 	"kubevirt.io/kubevirt/pkg/virtctl/templates"
 )
 
@@ -14,7 +11,7 @@ const (
 	ADM = "adm"
 )
 
-func NewCommand(clientConfig clientcmd.ClientConfig) *cobra.Command {
+func NewCommand() *cobra.Command {
 	cmd := &cobra.Command{
 		Use:   ADM,
 		Short: "Administrate KubeVirt configuration.",
@@ -22,10 +19,7 @@ func NewCommand(clientConfig clientcmd.ClientConfig) *cobra.Command {
 			cmd.Printf(cmd.UsageString())
 		},
 	}
-
-	cmd.AddCommand(logverbosity.NewCommand(clientConfig))
-
+	cmd.AddCommand(logverbosity.NewCommand())
 	cmd.SetUsageTemplate(templates.UsageTemplate())
-
 	return cmd
 }
