@@ -9,23 +9,19 @@ import (
 	"strconv"
 
 	"github.com/spf13/cobra"
-
-	"k8s.io/client-go/tools/clientcmd"
-
 	k8smetav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/types"
+
 	v1 "kubevirt.io/api/core/v1"
 	"kubevirt.io/client-go/kubecli"
 
 	"kubevirt.io/kubevirt/pkg/apimachinery/patch"
 	virtconfig "kubevirt.io/kubevirt/pkg/virt-config"
+	"kubevirt.io/kubevirt/pkg/virtctl/clientconfig"
 	"kubevirt.io/kubevirt/pkg/virtctl/templates"
 )
 
-type Command struct {
-	clientConfig clientcmd.ClientConfig
-	command      string
-}
+type Command struct{}
 
 // for command parsing
 const (
@@ -73,7 +69,8 @@ const (
 	lvPath = "/spec/configuration/developerConfiguration/logVerbosity"
 )
 
-func NewCommand(clientConfig clientcmd.ClientConfig) *cobra.Command {
+func NewCommand() *cobra.Command {
+	c := Command{}
 	cmd := &cobra.Command{
 		Use:   "log-verbosity",
 		Short: "Show, Set or Reset log verbosity. The verbosity value must be 0-9. The default cluster config is normally 2.\n",
@@ -90,10 +87,7 @@ func NewCommand(clientConfig clientcmd.ClientConfig) *cobra.Command {
 - Flag syntax must be "flag=arg" ("flag arg" not supported).`,
 		Example: usage(),
 		Args:    cobra.NoArgs,
-		RunE: func(cmd *cobra.Command, _ []string) error {
-			c := Command{command: "log-verbosity", clientConfig: clientConfig}
-			return c.RunE(cmd)
-		},
+		RunE:    c.RunE,
 	}
 
 	cmd.Flags().UintVar(virtComponents["virt-api"], "virt-api", NoFlag, "show/set virt-api log verbosity (0-9)")
@@ -219,7 +213,7 @@ func hasVerbosityInKV(kv *v1.KubeVirt) (map[string]uint, bool, error) {
 func createOutputLines(verbosityVal map[string]uint) []string {
 	var lines []string
 
-	allIsSet := (*virtComponents[allComponents] != NoFlag)
+	allIsSet := *virtComponents[allComponents] != NoFlag
 
 	for componentName, verbosity := range virtComponents {
 		if componentName == allComponents {
@@ -353,8 +347,8 @@ func findOperation(cmd *cobra.Command) (operation, error) {
 	}
 }
 
-func (c *Command) RunE(cmd *cobra.Command) error {
-	virtClient, err := kubecli.GetKubevirtClientFromClientConfig(c.clientConfig)
+func (c *Command) RunE(cmd *cobra.Command, _ []string) error {
+	virtClient, _, _, err := clientconfig.ClientAndNamespaceFromContext(cmd.Context())
 	if err != nil {
 		return err
 	}
