@@ -24,11 +24,13 @@ import (
 
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
-	"k8s.io/apimachinery/pkg/util/yaml"
-	clonev1alpha1 "kubevirt.io/api/clone/v1alpha1"
 
-	"kubevirt.io/kubevirt/pkg/virtctl/create/clone"
-	"kubevirt.io/kubevirt/tests/clientcmd"
+	"k8s.io/apimachinery/pkg/util/yaml"
+	clone "kubevirt.io/api/clone/v1beta1"
+
+	"kubevirt.io/kubevirt/pkg/virtctl/testing"
+
+	virtctlclone "kubevirt.io/kubevirt/pkg/virtctl/create/clone"
 )
 
 const (
@@ -55,7 +57,7 @@ var _ = Describe("create clone", func() {
 		})
 
 		It("source name is the only required argument", func() {
-			flags := addFlag(nil, clone.SourceNameFlag, "fake-name")
+			flags := addFlag(nil, virtctlclone.SourceNameFlag, "fake-name")
 			_, err := newCommand(flags...)
 			Expect(err).ToNot(HaveOccurred())
 		})
@@ -66,10 +68,10 @@ var _ = Describe("create clone", func() {
 		DescribeTable("supported types", func(sourceType, expectedSourceKind, expectedSourceApiGroup, targetType, expectedTargetKind, expectedTargetApiGroup string) {
 			const sourceName, targetName = "source-name", "target-name"
 
-			flags := addFlag(nil, clone.SourceNameFlag, sourceName)
-			flags = addFlag(flags, clone.TargetNameFlag, targetName)
-			flags = addFlag(flags, clone.SourceTypeFlag, sourceType)
-			flags = addFlag(flags, clone.TargetTypeFlag, targetType)
+			flags := addFlag(nil, virtctlclone.SourceNameFlag, sourceName)
+			flags = addFlag(flags, virtctlclone.TargetNameFlag, targetName)
+			flags = addFlag(flags, virtctlclone.SourceTypeFlag, sourceType)
+			flags = addFlag(flags, virtctlclone.TargetTypeFlag, targetType)
 
 			cloneObj, err := newCommand(flags...)
 			Expect(err).ToNot(HaveOccurred())
@@ -97,9 +99,9 @@ var _ = Describe("create clone", func() {
 		)
 
 		It("snapshot is not supported as a target type", func() {
-			flags := addFlag(nil, clone.SourceNameFlag, "source-name")
-			flags = addFlag(flags, clone.TargetNameFlag, "target-name")
-			flags = addFlag(flags, clone.TargetTypeFlag, "snapshot")
+			flags := addFlag(nil, virtctlclone.SourceNameFlag, "source-name")
+			flags = addFlag(flags, virtctlclone.TargetNameFlag, "target-name")
+			flags = addFlag(flags, virtctlclone.TargetTypeFlag, "snapshot")
 
 			_, err := newCommand(flags...)
 			Expect(err).To(HaveOccurred())
@@ -107,7 +109,7 @@ var _ = Describe("create clone", func() {
 
 		It("unknown source type", func() {
 			flags := getSourceNameFlags()
-			flags = addFlag(flags, clone.SourceTypeFlag, "unknown type")
+			flags = addFlag(flags, virtctlclone.SourceTypeFlag, "unknown type")
 
 			_, err := newCommand(flags...)
 			Expect(err).To(HaveOccurred())
@@ -115,7 +117,7 @@ var _ = Describe("create clone", func() {
 
 		It("unknown target type", func() {
 			flags := getSourceNameFlags()
-			flags = addFlag(flags, clone.TargetTypeFlag, "unknown type")
+			flags = addFlag(flags, virtctlclone.TargetTypeFlag, "unknown type")
 
 			_, err := newCommand(flags...)
 			Expect(err).To(HaveOccurred())
@@ -135,27 +137,27 @@ var _ = Describe("create clone", func() {
 
 			switch filterType {
 			case labelFilters:
-				flags = addFlag(flags, clone.LabelFilterFlag, "*")
-				flags = addFlag(flags, clone.LabelFilterFlag, `"!some/key"`)
+				flags = addFlag(flags, virtctlclone.LabelFilterFlag, "*")
+				flags = addFlag(flags, virtctlclone.LabelFilterFlag, `"!some/key"`)
 			case annotationsFilters:
-				flags = addFlag(flags, clone.AnnotationFilterFlag, "*")
-				flags = addFlag(flags, clone.AnnotationFilterFlag, `"!some/key"`)
+				flags = addFlag(flags, virtctlclone.AnnotationFilterFlag, "*")
+				flags = addFlag(flags, virtctlclone.AnnotationFilterFlag, `"!some/key"`)
 			case labelAndAnnotationsFilters:
-				flags = addFlag(flags, clone.LabelFilterFlag, "*")
-				flags = addFlag(flags, clone.LabelFilterFlag, `"!some/key"`)
-				flags = addFlag(flags, clone.AnnotationFilterFlag, "*")
-				flags = addFlag(flags, clone.AnnotationFilterFlag, `"!some/key"`)
+				flags = addFlag(flags, virtctlclone.LabelFilterFlag, "*")
+				flags = addFlag(flags, virtctlclone.LabelFilterFlag, `"!some/key"`)
+				flags = addFlag(flags, virtctlclone.AnnotationFilterFlag, "*")
+				flags = addFlag(flags, virtctlclone.AnnotationFilterFlag, `"!some/key"`)
 			case templateLabelFilters:
-				flags = addFlag(flags, clone.TemplateLabelFilterFlag, "*")
-				flags = addFlag(flags, clone.TemplateLabelFilterFlag, `"!some/key"`)
+				flags = addFlag(flags, virtctlclone.TemplateLabelFilterFlag, "*")
+				flags = addFlag(flags, virtctlclone.TemplateLabelFilterFlag, `"!some/key"`)
 			case templateAnnotationsFilters:
-				flags = addFlag(flags, clone.TemplateAnnotationFilterFlag, "*")
-				flags = addFlag(flags, clone.TemplateAnnotationFilterFlag, `"!some/key"`)
+				flags = addFlag(flags, virtctlclone.TemplateAnnotationFilterFlag, "*")
+				flags = addFlag(flags, virtctlclone.TemplateAnnotationFilterFlag, `"!some/key"`)
 			case templateLabelAndAnnotationsFilters:
-				flags = addFlag(flags, clone.TemplateLabelFilterFlag, "*")
-				flags = addFlag(flags, clone.TemplateLabelFilterFlag, `"!some/key"`)
-				flags = addFlag(flags, clone.TemplateAnnotationFilterFlag, "*")
-				flags = addFlag(flags, clone.TemplateAnnotationFilterFlag, `"!some/key"`)
+				flags = addFlag(flags, virtctlclone.TemplateLabelFilterFlag, "*")
+				flags = addFlag(flags, virtctlclone.TemplateLabelFilterFlag, `"!some/key"`)
+				flags = addFlag(flags, virtctlclone.TemplateAnnotationFilterFlag, "*")
+				flags = addFlag(flags, virtctlclone.TemplateAnnotationFilterFlag, `"!some/key"`)
 			}
 
 			cloneObj, err := newCommand(flags...)
@@ -201,7 +203,7 @@ var _ = Describe("create clone", func() {
 			}
 
 			for interfaceName, newMacAddress := range newMacAddresses {
-				flags = addFlag(flags, clone.NewMacAddressesFlag, fmt.Sprintf(newMacAddressValueFmt, interfaceName, newMacAddress))
+				flags = addFlag(flags, virtctlclone.NewMacAddressesFlag, fmt.Sprintf(newMacAddressValueFmt, interfaceName, newMacAddress))
 			}
 
 			cloneObj, err := newCommand(flags...)
@@ -216,7 +218,7 @@ var _ = Describe("create clone", func() {
 
 		DescribeTable("with invalid arguments", func(interfaceName, newMacAddress string) {
 			flags := getSourceNameFlags()
-			flags = addFlag(flags, clone.NewMacAddressesFlag, fmt.Sprintf(newMacAddressValueFmt, interfaceName, newMacAddress))
+			flags = addFlag(flags, virtctlclone.NewMacAddressesFlag, fmt.Sprintf(newMacAddressValueFmt, interfaceName, newMacAddress))
 
 			_, err := newCommand(flags...)
 			Expect(err).To(HaveOccurred())
@@ -231,7 +233,7 @@ var _ = Describe("create clone", func() {
 		flags := getSourceNameFlags()
 
 		const newSerial = "newSerial"
-		flags = addFlag(flags, clone.NewSMBiosSerialFlag, newSerial)
+		flags = addFlag(flags, virtctlclone.NewSMBiosSerialFlag, newSerial)
 
 		cloneObj, err := newCommand(flags...)
 		Expect(err).ToNot(HaveOccurred())
@@ -258,16 +260,16 @@ func addFlag(s []string, flag, value string) []string {
 	return append(s, fmt.Sprintf("--%s", flag), value)
 }
 
-func newCommand(createCloneFlags ...string) (*clonev1alpha1.VirtualMachineClone, error) {
-	baseArgs := []string{create, clone.Clone}
+func newCommand(createCloneFlags ...string) (*clone.VirtualMachineClone, error) {
+	baseArgs := []string{create, virtctlclone.Clone}
 	args := append(baseArgs, createCloneFlags...)
 
-	bytes, err := clientcmd.NewRepeatableVirtctlCommandWithOut(args...)()
+	bytes, err := testing.NewRepeatableVirtctlCommandWithOut(args...)()
 	if err != nil {
 		return nil, err
 	}
 
-	cloneObj := clonev1alpha1.VirtualMachineClone{}
+	cloneObj := clone.VirtualMachineClone{}
 	err = yaml.Unmarshal(bytes, &cloneObj)
 	ExpectWithOffset(1, err).ToNot(HaveOccurred())
 
@@ -275,5 +277,5 @@ func newCommand(createCloneFlags ...string) (*clonev1alpha1.VirtualMachineClone,
 }
 
 func getSourceNameFlags() []string {
-	return addFlag(nil, clone.SourceNameFlag, "source-vm")
+	return addFlag(nil, virtctlclone.SourceNameFlag, "source-vm")
 }
