@@ -4,7 +4,7 @@ import (
 	"io"
 	"net"
 
-	"github.com/golang/glog"
+	"kubevirt.io/client-go/log"
 )
 
 func (p *portForwarder) startForwardingTCP(address *net.IPAddr, port forwardedPort) error {
@@ -28,13 +28,13 @@ func (p *portForwarder) waitForConnection(listener net.Listener, port forwardedP
 	for {
 		conn, err := listener.Accept()
 		if err != nil {
-			glog.Errorln("error accepting connection:", err)
+			log.Log.Errorf("error accepting connection: %v", err)
 			return
 		}
-		glog.Infof("opening new tcp tunnel to %d", port.remote)
+		log.Log.Infof("opening new tcp tunnel to %d", port.remote)
 		stream, err := p.resource.PortForward(p.name, port.remote, port.protocol)
 		if err != nil {
-			glog.Errorf("can't access %s/%s.%s: %v", p.kind, p.name, p.namespace, err)
+			log.Log.Errorf("can't access %s/%s.%s: %v", p.kind, p.name, p.namespace, err)
 			return
 		}
 		go p.handleConnection(conn, stream.AsConn(), port)
@@ -44,7 +44,7 @@ func (p *portForwarder) waitForConnection(listener net.Listener, port forwardedP
 // handleConnection copies data between the local connection and the stream to
 // the remote server.
 func (p *portForwarder) handleConnection(local, remote net.Conn, port forwardedPort) {
-	glog.Infof("handling tcp connection for %d", port.local)
+	log.Log.Infof("handling tcp connection for %d", port.local)
 	errs := make(chan error)
 	go func() {
 		_, err := io.Copy(remote, local)
