@@ -1,12 +1,8 @@
 package scp
 
-import (
-	"strings"
+import "strings"
 
-	"kubevirt.io/kubevirt/pkg/virtctl/templates"
-)
-
-func (o *SCP) buildSCPTarget(local templates.LocalSCPArgument, remote templates.RemoteSCPArgument, toRemote bool) (opts []string) {
+func (o *SCP) buildSCPTarget(local *LocalArgument, remote *RemoteArgument, toRemote bool) (opts []string) {
 	if o.recursive {
 		opts = append(opts, "-r")
 	}
