@@ -6,10 +6,7 @@ import (
 	"fmt"
 
 	"github.com/spf13/pflag"
-)
-
-const (
-	wrapLocalSSHDefault = true
+	"kubevirt.io/client-go/kubecli"
 )
 
 func additionalUsage() string {
@@ -21,6 +18,6 @@ func addAdditionalCommandlineArgs(flagset *pflag.FlagSet, opts *SSHOptions) {
 		fmt.Sprintf(`--%s="-o StrictHostKeyChecking=no" : Additional options to be passed to the local ssh`, additionalOpts))
 }
 
-func (o *SSH) nativeSSH(_, _, _ string) error {
+func (o *SSH) nativeSSH(_, _, _ string, _ kubecli.KubevirtClient) error {
 	panic("Native SSH is unsupported in this build!")
 }
