@@ -34,28 +34,26 @@ import (
 	"strings"
 	"time"
 
-	pb "github.com/cheggaaa/pb/v3"
+	"github.com/cheggaaa/pb/v3"
 	"github.com/spf13/cobra"
-
 	k8sv1 "k8s.io/api/core/v1"
 	k8serrors "k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/labels"
 	"k8s.io/apimachinery/pkg/runtime/schema"
-	"k8s.io/apimachinery/pkg/util/wait"
-	"k8s.io/client-go/tools/clientcmd"
 	"k8s.io/client-go/tools/portforward"
 	"k8s.io/client-go/transport/spdy"
 	kubectlutil "k8s.io/kubectl/pkg/util"
 
 	virtv1 "kubevirt.io/api/core/v1"
 	exportv1 "kubevirt.io/api/export/v1beta1"
+	snapshotv1 "kubevirt.io/api/snapshot/v1beta1"
 	"kubevirt.io/client-go/kubecli"
 
-	snapshotv1 "kubevirt.io/api/snapshot/v1beta1"
-
+	virtwait "kubevirt.io/kubevirt/pkg/apimachinery/wait"
 	"kubevirt.io/kubevirt/pkg/pointer"
 	"kubevirt.io/kubevirt/pkg/util"
+	"kubevirt.io/kubevirt/pkg/virtctl/clientconfig"
 	"kubevirt.io/kubevirt/pkg/virtctl/templates"
 )
 
@@ -66,23 +64,26 @@ const (
 	DOWNLOAD = "download"
 
 	// Available vmexport flags
-	OUTPUT_FLAG         = "--output"
-	VOLUME_FLAG         = "--volume"
-	VM_FLAG             = "--vm"
-	SNAPSHOT_FLAG       = "--snapshot"
-	INSECURE_FLAG       = "--insecure"
-	KEEP_FLAG           = "--keep-vme"
-	DELETE_FLAG         = "--delete-vme"
-	FORMAT_FLAG         = "--format"
-	PVC_FLAG            = "--pvc"
-	TTL_FLAG            = "--ttl"
-	MANIFEST_FLAG       = "--manifest"
-	OUTPUT_FORMAT_FLAG  = "--manifest-output-format"
-	SERVICE_URL_FLAG    = "--service-url"
-	INCLUDE_SECRET_FLAG = "--include-secret"
-	PORT_FORWARD_FLAG   = "--port-forward"
-	LOCAL_PORT_FLAG     = "--local-port"
-	RETRY_FLAG          = "--retry"
+	OUTPUT_FLAG            = "--output"
+	VOLUME_FLAG            = "--volume"
+	VM_FLAG                = "--vm"
+	SNAPSHOT_FLAG          = "--snapshot"
+	INSECURE_FLAG          = "--insecure"
+	KEEP_FLAG              = "--keep-vme"
+	DELETE_FLAG            = "--delete-vme"
+	FORMAT_FLAG            = "--format"
+	PVC_FLAG               = "--pvc"
+	TTL_FLAG               = "--ttl"
+	MANIFEST_FLAG          = "--manifest"
+	OUTPUT_FORMAT_FLAG     = "--manifest-output-format"
+	SERVICE_URL_FLAG       = "--service-url"
+	INCLUDE_SECRET_FLAG    = "--include-secret"
+	PORT_FORWARD_FLAG      = "--port-forward"
+	LOCAL_PORT_FLAG        = "--local-port"
+	RETRY_FLAG             = "--retry"
+	LABELS_FLAG            = "--labels"
+	ANNOTATIONS_FLAG       = "--annotations"
+	READINESS_TIMEOUT_FLAG = "--readiness-timeout"
 
 	// Possible output format for manifests
 	OUTPUT_FORMAT_JSON = "json"
@@ -98,15 +99,13 @@ const (
 
 	// processingWaitInterval is the time interval used to wait for a virtualMachineExport to be ready
 	processingWaitInterval = 2 * time.Second
-	// processingWaitTotal is the maximum time used to wait for a virtualMachineExport to be ready
-	processingWaitTotal = 2 * time.Minute
+	// DefaultProcessingWaitTotal is the default maximum time used to wait for a virtualMachineExport to be ready
+	DefaultProcessingWaitTotal = 2 * time.Minute
 
 	// exportTokenHeader is the http header used to download the exported volume using the secret token
 	exportTokenHeader = "x-kubevirt-export-token"
 	// secretTokenKey is the entry used to store the token in the virtualMachineExport secret
 	secretTokenKey = "token"
-	// secretTokenLenght is the lenght of the randomly generated token
-	secretTokenLenght = 20
 
 	// ErrRequiredFlag serves as error message when a mandatory flag is missing
 	ErrRequiredFlag = "need to specify the '%s' flag when using '%s'"
@@ -145,33 +144,38 @@ var (
 	ttl                  string
 	manifestOutputFormat string
 	downloadRetries      int
+	resourceLabels       []string
+	resourceAnnotations  []string
+	readinessTimeout     string
 )
 
 type VMExportInfo struct {
-	ShouldCreate    bool
-	Insecure        bool
-	KeepVme         bool
-	DeleteVme       bool
-	IncludeSecret   bool
-	ExportManifest  bool
-	Decompress      bool
-	PortForward     bool
-	LocalPort       string
-	OutputFile      string
-	OutputWriter    io.Writer
-	VolumeName      string
-	Namespace       string
-	Name            string
-	OutputFormat    string
-	ServiceURL      string
-	ExportSource    k8sv1.TypedLocalObjectReference
-	TTL             metav1.Duration
-	DownloadRetries int
+	ShouldCreate     bool
+	Insecure         bool
+	KeepVme          bool
+	DeleteVme        bool
+	IncludeSecret    bool
+	ExportManifest   bool
+	Decompress       bool
+	PortForward      bool
+	LocalPort        string
+	OutputFile       string
+	OutputWriter     io.Writer
+	VolumeName       string
+	Namespace        string
+	Name             string
+	OutputFormat     string
+	ServiceURL       string
+	ExportSource     k8sv1.TypedLocalObjectReference
+	TTL              metav1.Duration
+	DownloadRetries  int
+	ReadinessTimeout time.Duration
+	Labels           map[string]string
+	Annotations      map[string]string
 }
 
 type command struct {
-	clientConfig clientcmd.ClientConfig
-	cmd          *cobra.Command
+	cmd *cobra.Command
 }
 
 // WaitForVirtualMachineExportFn allows overriding the function to wait for the export object to be ready (useful for unit testing)
@@ -223,16 +227,14 @@ func usage() string {
 }
 
 // NewVirtualMachineExportCommand returns a cobra.Command to handle the export process
-func NewVirtualMachineExportCommand(clientConfig clientcmd.ClientConfig) *cobra.Command {
+func NewVirtualMachineExportCommand() *cobra.Command {
+	c := command{}
 	cmd := &cobra.Command{
 		Use:     "vmexport",
 		Short:   "Export a VM volume.",
 		Example: usage(),
 		Args:    cobra.ExactArgs(2),
-		RunE: func(cmd *cobra.Command, args []string) error {
-			v := command{clientConfig: clientConfig, cmd: cmd}
-			return v.run(args)
-		},
+		RunE:    c.run,
 	}
 
 	shouldCreate = false
@@ -256,13 +258,18 @@ func NewVirtualMachineExportCommand(clientConfig clientcmd.ClientConfig) *cobra.
 	cmd.Flags().IntVar(&downloadRetries, "retry", 0, "When export server returns a transient error, we retry this number of times before giving up")
 	cmd.Flags().BoolVar(&includeSecret, "include-secret", false, "When used with manifest and set to true include a secret that contains proper headers for CDI to import using the manifest")
 	cmd.Flags().BoolVar(&exportManifest, "manifest", false, "Instead of downloading a volume, retrieve the VM manifest")
+	cmd.Flags().StringSliceVar(&resourceLabels, "labels", nil, "Specify custom labels to VM export object and its associated pod")
+	cmd.Flags().StringSliceVar(&resourceAnnotations, "annotations", nil, "Specify custom annotations to VM export object and its associated pod")
+	cmd.Flags().StringVar(&readinessTimeout, "readiness-timeout", "", "Specify maximum wait for VM export object to be ready")
 	cmd.SetUsageTemplate(templates.UsageTemplate())
 
 	return cmd
 }
 
 // run serves as entrypoint for the vmexport command
-func (c *command) run(args []string) error {
+func (c *command) run(cmd *cobra.Command, args []string) error {
+	c.cmd = cmd
+
 	var vmeInfo VMExportInfo
 	if err := c.parseExportArguments(args, &vmeInfo); err != nil {
 		return err
@@ -272,17 +279,12 @@ func (c *command) run(args []string) error {
 		defer util.CloseIOAndCheckErr(closer, nil)
 	}
 
-	namespace, _, err := c.clientConfig.Namespace()
+	virtClient, namespace, _, err := clientconfig.ClientAndNamespaceFromContext(cmd.Context())
 	if err != nil {
 		return err
 	}
 	vmeInfo.Namespace = namespace
 
-	virtClient, err := kubecli.GetKubevirtClientFromClientConfig(c.clientConfig)
-	if err != nil {
-		return fmt.Errorf("cannot obtain KubeVirt client: %v", err)
-	}
-
 	// Finally, run the vmexport function (create|delete|download)
 	if err := exportFunction(virtClient, &vmeInfo); err != nil {
 		return err
@@ -379,9 +381,33 @@ func (c *command) initVMExportInfo(vmeInfo *VMExportInfo) error {
 		}
 		vmeInfo.TTL = metav1.Duration{Duration: duration}
 	}
+	vmeInfo.ReadinessTimeout = DefaultProcessingWaitTotal
+	if readinessTimeout != "" {
+		duration, err := time.ParseDuration(readinessTimeout)
+		if err != nil {
+			return err
+		}
+		vmeInfo.ReadinessTimeout = duration
+	}
+
+	vmeInfo.Labels = convertSliceToMap(resourceLabels)
+	vmeInfo.Annotations = convertSliceToMap(resourceAnnotations)
+
 	return nil
 }
 
+// Convert a slice of "key=value" strings to a map
+func convertSliceToMap(slice []string) map[string]string {
+	mapResult := make(map[string]string)
+	for _, item := range slice {
+		parts := strings.SplitN(item, "=", 2)
+		if len(parts) == 2 {
+			mapResult[parts[0]] = parts[1]
+		}
+	}
+	return mapResult
+}
+
 // getVirtualMachineExport serves as a wrapper to get the VirtualMachineExport object
 func getVirtualMachineExport(client kubecli.KubevirtClient, vmeInfo *VMExportInfo) (*exportv1.VirtualMachineExport, error) {
 	vmexport, err := client.VirtualMachineExport(vmeInfo.Namespace).Get(context.TODO(), vmeInfo.Name, metav1.GetOptions{})
@@ -408,8 +434,10 @@ func CreateVirtualMachineExport(client kubecli.KubevirtClient, vmeInfo *VMExport
 	secretRef := getExportSecretName(vmeInfo.Name)
 	vmexport = &exportv1.VirtualMachineExport{
 		ObjectMeta: metav1.ObjectMeta{
-			Name:      vmeInfo.Name,
-			Namespace: vmeInfo.Namespace,
+			Name:        vmeInfo.Name,
+			Namespace:   vmeInfo.Namespace,
+			Labels:      vmeInfo.Labels,
+			Annotations: vmeInfo.Annotations,
 		},
 		Spec: exportv1.VirtualMachineExportSpec{
 			TokenSecretRef: &secretRef,
@@ -492,7 +520,7 @@ func downloadVirtualMachineExport(client kubecli.KubevirtClient, vmeInfo *VMExpo
 	}
 
 	// Wait for the vmexport object to be ready
-	if err := WaitForVirtualMachineExportFn(client, vmeInfo, processingWaitInterval, processingWaitTotal); err != nil {
+	if err := WaitForVirtualMachineExportFn(client, vmeInfo, processingWaitInterval, vmeInfo.ReadinessTimeout); err != nil {
 		return false, err
 	}
 
@@ -684,7 +712,7 @@ func GetManifestUrlsFromVirtualMachineExport(vmexport *exportv1.VirtualMachineEx
 
 // WaitForVirtualMachineExport waits for the VirtualMachineExport status and external links to be ready
 func WaitForVirtualMachineExport(client kubecli.KubevirtClient, vmeInfo *VMExportInfo, interval, timeout time.Duration) error {
-	err := wait.PollImmediate(interval, timeout, func() (bool, error) {
+	err := virtwait.PollImmediately(interval, timeout, func(_ context.Context) (bool, error) {
 		vmexport, err := getVirtualMachineExport(client, vmeInfo)
 		if err != nil {
 			return false, err
@@ -796,7 +824,7 @@ func copyFileWithProgressBar(output io.Writer, resp *http.Response, decompress b
 // getOrCreateTokenSecret obtains a token secret to be used along with the virtualMachineExport
 func getOrCreateTokenSecret(client kubecli.KubevirtClient, vmexport *exportv1.VirtualMachineExport) (*k8sv1.Secret, error) {
 	// Securely randomize a 20 char string to be used as a token
-	token, err := util.GenerateSecureRandomString(secretTokenLenght)
+	token, err := util.GenerateVMExportToken()
 	if err != nil {
 		return nil, err
 	}
@@ -950,6 +978,15 @@ func handleDeleteFlags() error {
 	if downloadRetries != 0 {
 		return fmt.Errorf(ErrIncompatibleFlag, RETRY_FLAG, DELETE)
 	}
+	if readinessTimeout != "" {
+		return fmt.Errorf(ErrIncompatibleFlag, READINESS_TIMEOUT_FLAG, DELETE)
+	}
+	if len(resourceLabels) > 0 {
+		return fmt.Errorf(ErrIncompatibleFlag, LABELS_FLAG, DELETE)
+	}
+	if len(resourceAnnotations) > 0 {
+		return fmt.Errorf(ErrIncompatibleFlag, ANNOTATIONS_FLAG, DELETE)
+	}
 
 	return nil
 }
@@ -1035,7 +1072,7 @@ func translateServicePortToTargetPort(localPort string, remotePort string, svc k
 func waitForExportServiceToBeReady(client kubecli.KubevirtClient, vmeInfo *VMExportInfo, interval, timeout time.Duration) (*k8sv1.Service, error) {
 	service := &k8sv1.Service{}
 	serviceName := fmt.Sprintf("virt-export-%s", vmeInfo.Name)
-	err := wait.PollImmediate(interval, timeout, func() (bool, error) {
+	err := virtwait.PollImmediately(interval, timeout, func(ctx context.Context) (bool, error) {
 		vmexport, err := getVirtualMachineExport(client, vmeInfo)
 		if err != nil || vmexport == nil {
 			return false, err
@@ -1046,7 +1083,7 @@ func waitForExportServiceToBeReady(client kubecli.KubevirtClient, vmeInfo *VMExp
 			return false, nil
 		}
 
-		service, err = client.CoreV1().Services(vmeInfo.Namespace).Get(context.TODO(), serviceName, metav1.GetOptions{})
+		service, err = client.CoreV1().Services(vmeInfo.Namespace).Get(ctx, serviceName, metav1.GetOptions{})
 		if err != nil {
 			if k8serrors.IsNotFound(err) {
 				printToOutput("waiting for service %s to be ready before port-forwarding...\n", serviceName)
@@ -1063,7 +1100,7 @@ func waitForExportServiceToBeReady(client kubecli.KubevirtClient, vmeInfo *VMExp
 // setupPortForward runs a port-forward after initializing all required arguments
 func setupPortForward(client kubecli.KubevirtClient, vmeInfo *VMExportInfo) (chan struct{}, error) {
 	// Wait for the vmexport object to be ready
-	service, err := waitForExportServiceToBeReady(client, vmeInfo, processingWaitInterval, processingWaitTotal)
+	service, err := waitForExportServiceToBeReady(client, vmeInfo, processingWaitInterval, vmeInfo.ReadinessTimeout)
 	if err != nil {
 		return nil, err
 	}
