@@ -13,25 +13,25 @@ import (
 	"strings"
 	"time"
 
+	"github.com/golang/mock/gomock"
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
-
-	"github.com/golang/mock/gomock"
 	"github.com/onsi/gomega/gstruct"
+
 	k8sv1 "k8s.io/api/core/v1"
 	k8serrors "k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
 	fakek8sclient "k8s.io/client-go/kubernetes/fake"
-	"k8s.io/client-go/testing"
+	k8stesting "k8s.io/client-go/testing"
 
 	v1 "kubevirt.io/api/core/v1"
 	exportv1 "kubevirt.io/api/export/v1beta1"
 	"kubevirt.io/client-go/kubecli"
 	kubevirtfake "kubevirt.io/client-go/kubevirt/fake"
 
+	"kubevirt.io/kubevirt/pkg/virtctl/testing"
 	"kubevirt.io/kubevirt/pkg/virtctl/vmexport"
-	"kubevirt.io/kubevirt/tests/clientcmd"
 )
 
 const vmeName = "test-vme"
@@ -267,6 +267,23 @@ var _ = Describe("vmexport", func() {
 			Expect(err).To(MatchError(ContainSubstring("secrets \"%s\" not found", secret.Name)))
 		})
 
+		It("VirtualMachineExport download fails when readiness timeout", func() {
+			vme.Status = &exportv1.VirtualMachineExportStatus{
+				Phase: exportv1.Pending,
+			}
+			vmexport.WaitForVirtualMachineExportFn = vmexport.WaitForVirtualMachineExport
+
+			_, err := virtClient.ExportV1beta1().VirtualMachineExports(metav1.NamespaceDefault).Create(context.Background(), vme, metav1.CreateOptions{})
+			Expect(err).ToNot(HaveOccurred())
+
+			err = runDownloadCmd(
+				setFlag(vmexport.PVC_FLAG, pvcName),
+				setFlag(vmexport.OUTPUT_FLAG, outputPath),
+				setFlag(vmexport.READINESS_TIMEOUT_FLAG, "1ns"),
+			)
+			Expect(err).To(MatchError("context deadline exceeded"))
+		})
+
 		It("VirtualMachineExport retries until failure if the server returns a bad status", func() {
 			server.Config.Handler = http.HandlerFunc(func(w http.ResponseWriter, _ *http.Request) {
 				w.WriteHeader(http.StatusInternalServerError)
@@ -453,8 +470,8 @@ var _ = Describe("vmexport", func() {
 
 		Context("Successfully create and download", func() {
 			updateVMEStatusOnCreate := func(format exportv1.ExportVolumeFormat) {
-				virtClient.Fake.PrependReactor("create", "virtualmachineexports", func(action testing.Action) (bool, runtime.Object, error) {
-					create, ok := action.(testing.CreateAction)
+				virtClient.Fake.PrependReactor("create", "virtualmachineexports", func(action k8stesting.Action) (bool, runtime.Object, error) {
+					create, ok := action.(k8stesting.CreateAction)
 					Expect(ok).To(BeTrue())
 					vme, ok := create.GetObject().(*exportv1.VirtualMachineExport)
 					Expect(ok).To(BeTrue())
@@ -620,6 +637,27 @@ var _ = Describe("vmexport", func() {
 			Expect(err).ToNot(HaveOccurred())
 			Expect(*vme.Spec.TTLDuration).To(Equal(ttl))
 		})
+
+		It("Succesfully create VirtualMachineExport with custom labels and annotations", func() {
+			const (
+				labelKey        = "label-key"
+				labelValue      = "label-value"
+				annotationKey   = "annotation-key"
+				annotationValue = "annotation-key"
+			)
+
+			err := runCreateCmd(
+				setFlag(vmexport.PVC_FLAG, pvcName),
+				setFlag(vmexport.LABELS_FLAG, fmt.Sprintf("%s=%s", labelKey, labelValue)),
+				setFlag(vmexport.ANNOTATIONS_FLAG, fmt.Sprintf("%s=%s", annotationKey, annotationValue)),
+			)
+			Expect(err).ToNot(HaveOccurred())
+
+			vme, err := virtClient.ExportV1beta1().VirtualMachineExports(metav1.NamespaceDefault).Get(context.Background(), vme.Name, metav1.GetOptions{})
+			Expect(err).ToNot(HaveOccurred())
+			Expect(vme.Labels).To(HaveKeyWithValue(labelKey, labelValue))
+			Expect(vme.Annotations).To(HaveKeyWithValue(annotationKey, annotationValue))
+		})
 	})
 
 	Context("Manifest", func() {
@@ -940,20 +978,20 @@ func setFlag(flag, parameter string) string {
 
 func runCmd(args ...string) error {
 	_args := append([]string{"vmexport"}, args...)
-	return clientcmd.NewRepeatableVirtctlCommand(_args...)()
+	return testing.NewRepeatableVirtctlCommand(_args...)()
 }
 
 func runCreateCmd(args ...string) error {
 	_args := append([]string{"vmexport", vmexport.CREATE, vmeName}, args...)
-	return clientcmd.NewRepeatableVirtctlCommand(_args...)()
+	return testing.NewRepeatableVirtctlCommand(_args...)()
 }
 
 func runDeleteCmd(args ...string) error {
 	_args := append([]string{"vmexport", vmexport.DELETE, vmeName}, args...)
-	return clientcmd.NewRepeatableVirtctlCommand(_args...)()
+	return testing.NewRepeatableVirtctlCommand(_args...)()
 }
 
 func runDownloadCmd(args ...string) error {
 	_args := append([]string{"vmexport", vmexport.DOWNLOAD, vmeName}, args...)
-	return clientcmd.NewRepeatableVirtctlCommand(_args...)()
+	return testing.NewRepeatableVirtctlCommand(_args...)()
 }
