@@ -201,7 +201,7 @@ type DomainSpec struct {
 	Devices Devices `json:"devices"`
 	// Controls whether or not disks will share IOThreads.
 	// Omitting IOThreadsPolicy disables use of IOThreads.
-	// One of: shared, auto
+	// One of: shared, auto, supplementalPool
 	// +optional
 	IOThreadsPolicy *IOThreadsPolicy `json:"ioThreadsPolicy,omitempty"`
 	// IOThreads specifies the IOThreads options.
@@ -547,6 +547,9 @@ type SoundDevice struct {
 }
 
 type TPMDevice struct {
+	// Enabled allows a user to explictly disable the vTPM even when one is enabled by a preference referenced by the VirtualMachine
+	// Defaults to True
+	Enabled *bool `json:"enabled,omitempty"`
 	// Persistent indicates the state of the TPM device should be kept accross reboots
 	// Defaults to false
 	Persistent *bool `json:"persistent,omitempty"`
@@ -1230,6 +1233,10 @@ type WatchdogDevice struct {
 	// i6300esb watchdog device.
 	// +optional
 	I6300ESB *I6300ESBWatchdog `json:"i6300esb,omitempty"`
+
+	// diag288 watchdog device (specific to s390x architecture).
+	// +optional
+	Diag288 *Diag288Watchdog `json:"diag288,omitempty"`
 }
 
 // i6300esb watchdog device.
@@ -1239,6 +1246,13 @@ type I6300ESBWatchdog struct {
 	Action WatchdogAction `json:"action,omitempty"`
 }
 
+// diag288 watchdog device.
+type Diag288Watchdog struct {
+	// The action to take. Valid values are poweroff, reset, shutdown.
+	// Defaults to reset.
+	Action WatchdogAction `json:"action,omitempty"`
+}
+
 type Interface struct {
 	// Logical name of the interface as well as a reference to the associated networks.
 	// Must match the Name of a Network.
