@@ -27,10 +27,10 @@ import (
 	"k8s.io/client-go/rest"
 
 	v1 "kubevirt.io/api/core/v1"
-	kvcorev1 "kubevirt.io/client-go/generated/kubevirt/clientset/versioned/typed/core/v1"
+	kvcorev1 "kubevirt.io/client-go/kubevirt/typed/core/v1"
 )
 
-func (k *kubevirt) VirtualMachineInstancePreset(namespace string) VirtualMachineInstancePresetInterface {
+func (k *kubevirtClient) VirtualMachineInstancePreset(namespace string) VirtualMachineInstancePresetInterface {
 	return &vmiPresets{
 		k.GeneratedKubeVirtClient().KubevirtV1().VirtualMachineInstancePresets(namespace),
 		k.restClient,
