@@ -159,13 +159,14 @@ func (r rights) list() (e []rightsEntry) {
 	return
 }
 
-var _ = Describe("[rfe_id:500][crit:high][arm64][vendor:cnv-qe@redhat.com][level:component][sig-compute]User Access", decorators.SigCompute, decorators.WgS390x, func() {
+var _ = Describe("[rfe_id:500][crit:high][vendor:cnv-qe@redhat.com][level:component][sig-compute]User Access", decorators.SigCompute, decorators.WgS390x, decorators.WgArm64, func() {
 
 	var k8sClient string
 	var authClient *authClientV1.AuthorizationV1Client
 
 	doSarRequest := func(group string, resource string, subresource string, namespace string, role string, verb string, expected, clusterWide bool) {
 		roleToUser := map[string]string{
+			"migrate":           testsuite.MigrateServiceAccountName,
 			"view":              testsuite.ViewServiceAccountName,
 			"instancetype:view": testsuite.ViewInstancetypeServiceAccountName,
 			"edit":              testsuite.EditServiceAccountName,
@@ -278,8 +279,9 @@ var _ = Describe("[rfe_id:500][crit:high][arm64][vendor:cnv-qe@redhat.com][level
 				core.GroupName,
 				"virtualmachineinstancemigrations",
 				false,
-				allowAllFor("admin"),
-				denyDeleteCollectionFor("edit"),
+				allowAllFor("migrate"),
+				denyModificationsFor("admin"),
+				denyModificationsFor("edit"),
 				denyModificationsFor("view"),
 				denyAllFor("instancetype:view"),
 				denyAllFor("default")),
@@ -354,7 +356,7 @@ var _ = Describe("[rfe_id:500][crit:high][arm64][vendor:cnv-qe@redhat.com][level
 				denyModificationsFor("default")),
 		)
 
-		DescribeTable("should verify permissions on subresources are correct for view, edit, admin and default", func(resource string, subresource string, accessRights ...rights) {
+		DescribeTable("should verify permissions on subresources are correct for view, edit, admin, migrate and default", func(resource string, subresource string, accessRights ...rights) {
 			namespace := testsuite.GetTestNamespace(nil)
 			for _, accessRight := range accessRights {
 				for _, entry := range accessRight.list() {
@@ -366,86 +368,94 @@ var _ = Describe("[rfe_id:500][crit:high][arm64][vendor:cnv-qe@redhat.com][level
 			Entry("[test_id:3232]on vm start",
 				"virtualmachines", "start",
 				allowUpdateFor("admin", "edit"),
-				denyAllFor("view", "default")),
+				denyAllFor("view", "migrate", "default")),
 			Entry("[test_id:3233]on vm stop",
 				"virtualmachines", "stop",
 				allowUpdateFor("admin", "edit"),
-				denyAllFor("view", "default")),
+				denyAllFor("view", "migrate", "default")),
 			Entry("[test_id:3234]on vm restart",
 				"virtualmachines", "restart",
 				allowUpdateFor("admin", "edit"),
-				denyAllFor("view", "default")),
+				denyAllFor("view", "migrate", "default")),
 			Entry("on vm expand-spec",
 				"virtualmachines", "expand-spec",
 				allowGetFor("admin", "edit", "view"),
-				denyAllFor("default")),
+				denyAllFor("migrate", "default")),
 			Entry("on vm portforward",
 				"virtualmachines", "portforward",
 				allowGetFor("admin", "edit"),
-				denyAllFor("view", "default")),
+				denyAllFor("view", "migrate", "default")),
+			Entry("on vm migrate",
+				"virtualmachines", "migrate",
+				allowUpdateFor("migrate"),
+				denyAllFor("admin", "edit", "view", "default")),
 			Entry("on vmi guestosinfo",
 				"virtualmachineinstances", "guestosinfo",
 				allowGetFor("admin", "edit", "view"),
-				denyAllFor("default")),
+				denyAllFor("migrate", "default")),
 			Entry("on vmi userlist",
 				"virtualmachineinstances", "userlist",
 				allowGetFor("admin", "edit", "view"),
-				denyAllFor("default")),
+				denyAllFor("migrate", "default")),
 			Entry("on vmi filesystemlist",
 				"virtualmachineinstances", "filesystemlist",
 				allowGetFor("admin", "edit", "view"),
-				denyAllFor("default")),
+				denyAllFor("migrate", "default")),
 			Entry("on vmi addvolume",
 				"virtualmachineinstances", "addvolume",
 				allowUpdateFor("admin", "edit"),
-				denyAllFor("view", "default")),
+				denyAllFor("view", "migrate", "default")),
 			Entry("on vmi removevolume",
 				"virtualmachineinstances", "removevolume",
 				allowUpdateFor("admin", "edit"),
-				denyAllFor("view", "default")),
+				denyAllFor("view", "migrate", "default")),
 			Entry("on vmi freeze",
 				"virtualmachineinstances", "freeze",
 				allowUpdateFor("admin", "edit"),
-				denyAllFor("view", "default")),
+				denyAllFor("view", "migrate", "default")),
 			Entry("on vmi unfreeze",
 				"virtualmachineinstances", "unfreeze",
 				allowUpdateFor("admin", "edit"),
+				denyAllFor("view", "migrate", "default")),
+			Entry("on vmi reset",
+				"virtualmachineinstances", "reset",
+				allowUpdateFor("admin", "edit"),
 				denyAllFor("view", "default")),
 			Entry("on vmi softreboot",
 				"virtualmachineinstances", "softreboot",
 				allowUpdateFor("admin", "edit"),
-				denyAllFor("view", "default")),
+				denyAllFor("view", "migrate", "default")),
 			Entry("on vmi portforward",
 				"virtualmachineinstances", "portforward",
 				allowGetFor("admin", "edit"),
-				denyAllFor("view", "default")),
+				denyAllFor("view", "migrate", "default")),
 			Entry("on vmi vsock",
 				"virtualmachineinstances", "vsock",
-				denyAllFor("admin", "edit", "view", "default")),
+				denyAllFor("admin", "edit", "view", "migrate", "default")),
 			Entry("on expand-vm-spec",
 				"expand-vm-spec", "",
 				allowUpdateFor("admin", "edit", "view"),
-				denyAllFor("default")),
+				denyAllFor("migrate", "default")),
 			Entry("on vmi sev/fetchcertchain",
 				"virtualmachineinstances", "sev/fetchcertchain",
 				allowGetFor("admin", "edit", "view"),
-				denyAllFor("default")),
+				denyAllFor("migrate", "default")),
 			Entry("on vmi sev/querylaunchmeasurement",
 				"virtualmachineinstances", "sev/querylaunchmeasurement",
 				allowGetFor("admin", "edit", "view"),
-				denyAllFor("default")),
+				denyAllFor("migrate", "default")),
 			Entry("on vmi sev/setupsession",
 				"virtualmachineinstances", "sev/setupsession",
 				allowUpdateFor("admin", "edit"),
-				denyAllFor("default")),
+				denyAllFor("migrate", "default")),
 			Entry("on vmi sev/injectlaunchsecret",
 				"virtualmachineinstances", "sev/injectlaunchsecret",
 				allowUpdateFor("admin", "edit"),
-				denyAllFor("default")),
+				denyAllFor("migrate", "default")),
 			Entry("on vmi usbredir",
 				"virtualmachineinstances", "usbredir",
 				allowGetFor("admin", "edit"),
-				denyAllFor("view", "default")),
+				denyAllFor("view", "migrate", "default")),
 		)
 	})
 })
