@@ -10,15 +10,18 @@ import (
 	"k8s.io/apimachinery/pkg/types"
 
 	"kubevirt.io/kubevirt/pkg/apimachinery/patch"
+	"kubevirt.io/kubevirt/pkg/libdv"
 	"kubevirt.io/kubevirt/pkg/libvmi"
 	"kubevirt.io/kubevirt/pkg/pointer"
+	"kubevirt.io/kubevirt/pkg/virt-config/featuregate"
 
 	"kubevirt.io/kubevirt/tests/decorators"
-	"kubevirt.io/kubevirt/tests/libdv"
+	"kubevirt.io/kubevirt/tests/events"
 	"kubevirt.io/kubevirt/tests/libkubevirt/config"
 	"kubevirt.io/kubevirt/tests/testsuite"
 
 	"kubevirt.io/kubevirt/tests/framework/kubevirt"
+	"kubevirt.io/kubevirt/tests/framework/matcher"
 
 	virtsnapshot "kubevirt.io/api/snapshot"
 	snapshotv1 "kubevirt.io/api/snapshot/v1beta1"
@@ -31,12 +34,11 @@ import (
 	"k8s.io/apimachinery/pkg/api/resource"
 	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 
-	clonev1alpha1 "kubevirt.io/api/clone/v1alpha1"
+	clone "kubevirt.io/api/clone/v1beta1"
 	virtv1 "kubevirt.io/api/core/v1"
 	instancetypev1beta1 "kubevirt.io/api/instancetype/v1beta1"
 	"kubevirt.io/client-go/kubecli"
 
-	virtconfig "kubevirt.io/kubevirt/pkg/virt-config"
 	"kubevirt.io/kubevirt/tests/console"
 	cd "kubevirt.io/kubevirt/tests/containerdisk"
 	. "kubevirt.io/kubevirt/tests/framework/matcher"
@@ -49,34 +51,18 @@ const (
 	vmAPIGroup = "kubevirt.io"
 )
 
-var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
+var _ = Describe("VirtualMachineClone Tests", Serial, func() {
 	var err error
 	var virtClient kubecli.KubevirtClient
 
 	BeforeEach(func() {
 		virtClient = kubevirt.Client()
 
-		config.EnableFeatureGate(virtconfig.SnapshotGate)
+		config.EnableFeatureGate(featuregate.SnapshotGate)
 
 		format.MaxLength = 0
 	})
 
-	createVM := func(options ...libvmi.Option) (vm *virtv1.VirtualMachine) {
-		vmi := libvmifact.NewCirros(options...)
-		vmi.Namespace = testsuite.GetTestNamespace(nil)
-		vm = libvmi.NewVirtualMachine(vmi)
-		vm.Annotations = vmi.Annotations
-		vm.Labels = vmi.Labels
-		vm.Spec.Template.ObjectMeta.Annotations = vmi.Annotations
-		vm.Spec.Template.ObjectMeta.Labels = vmi.Labels
-
-		By(fmt.Sprintf("Creating VM %s", vm.Name))
-		vm, err := virtClient.VirtualMachine(vm.Namespace).Create(context.Background(), vm, v1.CreateOptions{})
-		Expect(err).ShouldNot(HaveOccurred())
-
-		return
-	}
-
 	createSnapshot := func(vm *virtv1.VirtualMachine) *snapshotv1.VirtualMachineSnapshot {
 		var err error
 
@@ -138,7 +124,7 @@ var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
 		return snapshot
 	}
 
-	generateCloneFromVMWithParams := func(sourceVM *virtv1.VirtualMachine, targetVMName string) *clonev1alpha1.VirtualMachineClone {
+	generateCloneFromVMWithParams := func(sourceVM *virtv1.VirtualMachine, targetVMName string) *clone.VirtualMachineClone {
 		vmClone := kubecli.NewMinimalCloneWithNS("testclone", sourceVM.Namespace)
 
 		cloneSourceRef := &k8sv1.TypedLocalObjectReference{
@@ -156,7 +142,7 @@ var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
 		return vmClone
 	}
 
-	generateCloneFromSnapshot := func(snapshot *snapshotv1.VirtualMachineSnapshot, targetVMName string) *clonev1alpha1.VirtualMachineClone {
+	generateCloneFromSnapshot := func(snapshot *snapshotv1.VirtualMachineSnapshot, targetVMName string) *clone.VirtualMachineClone {
 		vmClone := kubecli.NewMinimalCloneWithNS("testclone", snapshot.Namespace)
 
 		cloneSourceRef := &k8sv1.TypedLocalObjectReference{
@@ -177,18 +163,25 @@ var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
 		return vmClone
 	}
 
-	createCloneAndWaitForFinish := func(vmClone *clonev1alpha1.VirtualMachineClone) {
+	createClone := func(vmClone *clone.VirtualMachineClone) *clone.VirtualMachineClone {
 		By(fmt.Sprintf("Creating clone object %s", vmClone.Name))
 		vmClone, err = virtClient.VirtualMachineClone(vmClone.Namespace).Create(context.Background(), vmClone, v1.CreateOptions{})
 		Expect(err).ShouldNot(HaveOccurred())
-
+		return vmClone
+	}
+	waitCloneSucceeded := func(vmClone *clone.VirtualMachineClone) {
 		By(fmt.Sprintf("Waiting for the clone %s to finish", vmClone.Name))
-		Eventually(func() clonev1alpha1.VirtualMachineClonePhase {
+		Eventually(func() clone.VirtualMachineClonePhase {
 			vmClone, err = virtClient.VirtualMachineClone(vmClone.Namespace).Get(context.Background(), vmClone.Name, v1.GetOptions{})
 			Expect(err).ShouldNot(HaveOccurred())
 
 			return vmClone.Status.Phase
-		}, 3*time.Minute, 3*time.Second).Should(Equal(clonev1alpha1.Succeeded), "clone should finish successfully")
+		}, 3*time.Minute, 3*time.Second).Should(Equal(clone.Succeeded), "clone should finish successfully")
+	}
+
+	createCloneAndWaitForCompletion := func(vmClone *clone.VirtualMachineClone) {
+		vmClone = createClone(vmClone)
+		waitCloneSucceeded(vmClone)
 	}
 
 	expectVMRunnable := func(vm *virtv1.VirtualMachine, login console.LoginToFunction) *virtv1.VirtualMachine {
@@ -236,7 +229,13 @@ var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
 
 		var (
 			sourceVM, targetVM *virtv1.VirtualMachine
-			vmClone            *clonev1alpha1.VirtualMachineClone
+			vmClone            *clone.VirtualMachineClone
+			defaultVMIOptions  = []libvmi.Option{
+				libvmi.WithLabel(key1, value1),
+				libvmi.WithLabel(key2, value2),
+				libvmi.WithAnnotation(key1, value1),
+				libvmi.WithAnnotation(key2, value2),
+			}
 		)
 
 		expectEqualStrMap := func(actual, expected map[string]string, expectationMsg string, keysToExclude ...string) {
@@ -277,19 +276,7 @@ var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
 			Expect(vm1Spec).To(Equal(vm2Spec), fmt.Sprintf(cloneShouldEqualSourceMsgPattern, "spec not including mac adresses"))
 		}
 
-		createVM := func(options ...libvmi.Option) (vm *virtv1.VirtualMachine) {
-			defaultOptions := []libvmi.Option{
-				libvmi.WithLabel(key1, value1),
-				libvmi.WithLabel(key2, value2),
-				libvmi.WithAnnotation(key1, value1),
-				libvmi.WithAnnotation(key2, value2),
-			}
-
-			options = append(options, defaultOptions...)
-			return createVM(options...)
-		}
-
-		generateCloneFromVM := func() *clonev1alpha1.VirtualMachineClone {
+		generateCloneFromVM := func() *clone.VirtualMachineClone {
 			return generateCloneFromVMWithParams(sourceVM, targetVMName)
 		}
 
@@ -300,10 +287,11 @@ var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
 			}
 
 			It("simple default clone", func() {
-				sourceVM = createVM()
+				sourceVM, err = createSourceVM(defaultVMIOptions...)
+				Expect(err).ShouldNot(HaveOccurred())
 				vmClone = generateCloneFromVM()
 
-				createCloneAndWaitForFinish(vmClone)
+				createCloneAndWaitForCompletion(vmClone)
 
 				By(fmt.Sprintf("Getting the target VM %s", targetVMName))
 				targetVM, err = virtClient.VirtualMachine(sourceVM.Namespace).Get(context.Background(), targetVMName, v1.GetOptions{})
@@ -333,7 +321,8 @@ var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
 
 			It("simple clone with snapshot source", func() {
 				By("Creating a VM")
-				sourceVM = createVM()
+				sourceVM, err = createSourceVM(defaultVMIOptions...)
+				Expect(err).ShouldNot(HaveOccurred())
 				Eventually(func() virtv1.VirtualMachinePrintableStatus {
 					sourceVM, err = virtClient.VirtualMachine(sourceVM.Namespace).Get(context.Background(), sourceVM.Name, v1.GetOptions{})
 					Expect(err).ToNot(HaveOccurred())
@@ -356,7 +345,7 @@ var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
 
 				By("Creating a clone with a snapshot source")
 				vmClone = generateCloneFromSnapshot(snapshot, targetVMName)
-				createCloneAndWaitForFinish(vmClone)
+				createCloneAndWaitForCompletion(vmClone)
 
 				By(fmt.Sprintf("Getting the target VM %s", targetVMName))
 				targetVM, err = virtClient.VirtualMachine(sourceVM.Namespace).Get(context.Background(), targetVMName, v1.GetOptions{})
@@ -371,7 +360,8 @@ var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
 			})
 
 			It("clone with only some of labels/annotations", func() {
-				sourceVM = createVM()
+				sourceVM, err = createSourceVM(defaultVMIOptions...)
+				Expect(err).ShouldNot(HaveOccurred())
 				vmClone = generateCloneFromVM()
 
 				vmClone.Spec.LabelFilters = []string{
@@ -381,7 +371,7 @@ var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
 				vmClone.Spec.AnnotationFilters = []string{
 					key1,
 				}
-				createCloneAndWaitForFinish(vmClone)
+				createCloneAndWaitForCompletion(vmClone)
 
 				By(fmt.Sprintf("Getting the target VM %s", targetVMName))
 				targetVM, err = virtClient.VirtualMachine(sourceVM.Namespace).Get(context.Background(), targetVMName, v1.GetOptions{})
@@ -396,7 +386,8 @@ var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
 			})
 
 			It("clone with only some of template.labels/template.annotations", func() {
-				sourceVM = createVM()
+				sourceVM, err = createSourceVM(defaultVMIOptions...)
+				Expect(err).ShouldNot(HaveOccurred())
 				vmClone = generateCloneFromVM()
 
 				vmClone.Spec.Template.LabelFilters = []string{
@@ -406,7 +397,7 @@ var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
 				vmClone.Spec.Template.AnnotationFilters = []string{
 					key1,
 				}
-				createCloneAndWaitForFinish(vmClone)
+				createCloneAndWaitForCompletion(vmClone)
 
 				By(fmt.Sprintf("Getting the target VM %s", targetVMName))
 				targetVM, err = virtClient.VirtualMachine(sourceVM.Namespace).Get(context.Background(), targetVMName, v1.GetOptions{})
@@ -421,10 +412,13 @@ var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
 
 			It("clone with changed MAC address", func() {
 				const newMacAddress = "BE-AD-00-00-BE-04"
-				sourceVM = createVM(
+				options := append(
+					defaultVMIOptions,
 					libvmi.WithInterface(libvmi.InterfaceDeviceWithMasqueradeBinding()),
 					libvmi.WithNetwork(virtv1.DefaultPodNetwork()),
 				)
+				sourceVM, err = createSourceVM(options...)
+				Expect(err).ShouldNot(HaveOccurred())
 
 				srcInterfaces := sourceVM.Spec.Template.Spec.Domain.Devices.Interfaces
 				Expect(srcInterfaces).ToNot(BeEmpty())
@@ -435,7 +429,7 @@ var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
 					srcInterface.Name: newMacAddress,
 				}
 
-				createCloneAndWaitForFinish(vmClone)
+				createCloneAndWaitForCompletion(vmClone)
 
 				By(fmt.Sprintf("Getting the target VM %s", targetVMName))
 				targetVM, err = virtClient.VirtualMachine(sourceVM.Namespace).Get(context.Background(), targetVMName, v1.GetOptions{})
@@ -470,16 +464,17 @@ var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
 					const sourceSerial = "source-serial"
 					const targetSerial = "target-serial"
 
-					sourceVM = createVM(
-						func(vmi *virtv1.VirtualMachineInstance) {
-							vmi.Spec.Domain.Firmware = &virtv1.Firmware{Serial: sourceSerial}
-						},
+					options := append(
+						defaultVMIOptions,
+						withFirmware(&virtv1.Firmware{Serial: sourceSerial}),
 					)
+					sourceVM, err = createSourceVM(options...)
+					Expect(err).ShouldNot(HaveOccurred())
 
 					vmClone = generateCloneFromVM()
 					vmClone.Spec.NewSMBiosSerial = pointer.P(targetSerial)
 
-					createCloneAndWaitForFinish(vmClone)
+					createCloneAndWaitForCompletion(vmClone)
 
 					By(fmt.Sprintf("Getting the target VM %s", targetVMName))
 					targetVM, err = virtClient.VirtualMachine(sourceVM.Namespace).Get(context.Background(), targetVMName, v1.GetOptions{})
@@ -502,14 +497,15 @@ var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
 				It("should strip firmware UUID", func() {
 					const fakeFirmwareUUID = "fake-uuid"
 
-					sourceVM = createVM(
-						func(vmi *virtv1.VirtualMachineInstance) {
-							vmi.Spec.Domain.Firmware = &virtv1.Firmware{UUID: fakeFirmwareUUID}
-						},
+					options := append(
+						defaultVMIOptions,
+						withFirmware(&virtv1.Firmware{UUID: fakeFirmwareUUID}),
 					)
+					sourceVM, err = createSourceVM(options...)
+					Expect(err).ShouldNot(HaveOccurred())
 					vmClone = generateCloneFromVM()
 
-					createCloneAndWaitForFinish(vmClone)
+					createCloneAndWaitForCompletion(vmClone)
 
 					By(fmt.Sprintf("Getting the target VM %s", targetVMName))
 					targetVM, err = virtClient.VirtualMachine(sourceVM.Namespace).Get(context.Background(), targetVMName, v1.GetOptions{})
@@ -533,7 +529,7 @@ var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
 				return expectVMRunnable(vm, console.LoginToAlpine)
 			}
 
-			createVMWithStorageClass := func(storageClass string, runStrategy virtv1.VirtualMachineRunStrategy) *virtv1.VirtualMachine {
+			generateVMWithStorageClass := func(storageClass string, runStrategy virtv1.VirtualMachineRunStrategy) *virtv1.VirtualMachine {
 				dv := libdv.NewDataVolume(
 					libdv.WithRegistryURLSource(cd.DataVolumeImportUrlForContainerDisk(cd.ContainerDiskAlpine)),
 					libdv.WithNamespace(testsuite.GetTestNamespace(nil)),
@@ -544,6 +540,10 @@ var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
 				)
 				vm := libstorage.RenderVMWithDataVolumeTemplate(dv)
 				vm.Spec.RunStrategy = &runStrategy
+				return vm
+			}
+
+			createVM := func(vm *virtv1.VirtualMachine, storageClass string, runStrategy virtv1.VirtualMachineRunStrategy) *virtv1.VirtualMachine {
 				vm, err := virtClient.VirtualMachine(vm.Namespace).Create(context.Background(), vm, v1.CreateOptions{})
 				Expect(err).ToNot(HaveOccurred())
 
@@ -558,6 +558,11 @@ var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
 				return vm
 			}
 
+			createVMWithStorageClass := func(storageClass string, runStrategy virtv1.VirtualMachineRunStrategy) *virtv1.VirtualMachine {
+				vm := generateVMWithStorageClass(storageClass, runStrategy)
+				return createVM(vm, storageClass, runStrategy)
+			}
+
 			Context("and no snapshot storage class", decorators.RequiresNoSnapshotStorageClass, func() {
 				var (
 					noSnapshotStorageClass string
@@ -578,13 +583,6 @@ var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
 						Eventually(ThisVM(sourceVM), 300*time.Second, 1*time.Second).Should(Not(BeReady()))
 					})
 
-					It("with VM source", func() {
-						vmClone = generateCloneFromVM()
-						vmClone, err = virtClient.VirtualMachineClone(vmClone.Namespace).Create(context.Background(), vmClone, v1.CreateOptions{})
-						Expect(err).To(HaveOccurred())
-						Expect(err.Error()).Should(ContainSubstring("does not support snapshots"))
-					})
-
 					It("with snapshot source", func() {
 						By("Snapshotting VM")
 						snapshot := createSnapshot(sourceVM)
@@ -614,17 +612,21 @@ var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
 					Expect(snapshotStorageClass).ToNot(BeEmpty(), "no storage class with snapshot support")
 				})
 
-				It("with a simple clone", func() {
+				It("with a simple clone, create clone before VM", func() {
 					runStrategy := virtv1.RunStrategyHalted
 					if libstorage.IsStorageClassBindingModeWaitForFirstConsumer(snapshotStorageClass) {
 						// with wffc need to start the virtual machine
 						// in order for the pvc to be populated
 						runStrategy = virtv1.RunStrategyAlways
 					}
-					sourceVM = createVMWithStorageClass(snapshotStorageClass, runStrategy)
+					sourceVM = generateVMWithStorageClass(snapshotStorageClass, runStrategy)
 					vmClone = generateCloneFromVM()
+					vmClone = createClone(vmClone)
 
-					createCloneAndWaitForFinish(vmClone)
+					events.ExpectEvent(vmClone, k8sv1.EventTypeNormal, "SourceDoesNotExist")
+					createVM(sourceVM, snapshotStorageClass, runStrategy)
+
+					waitCloneSucceeded(vmClone)
 
 					By(fmt.Sprintf("Getting the target VM %s", targetVMName))
 					targetVM, err = virtClient.VirtualMachine(sourceVM.Namespace).Get(context.Background(), targetVMName, v1.GetOptions{})
@@ -708,13 +710,13 @@ var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
 							libstorage.EventuallyDVWith(sourceVM.Namespace, dvt.Name, 180, HaveSucceeded())
 						}
 						By("Waiting until the source VM has instancetype and preference RevisionNames")
-						libinstancetype.WaitForVMInstanceTypeRevisionNames(sourceVM.Name, virtClient)
+						Eventually(matcher.ThisVM(sourceVM)).WithTimeout(300 * time.Second).WithPolling(time.Second).Should(matcher.HaveControllerRevisionRefs())
 
 						vmClone = generateCloneFromVM()
-						createCloneAndWaitForFinish(vmClone)
+						createCloneAndWaitForCompletion(vmClone)
 
 						By("Waiting until the targetVM has instancetype and preference RevisionNames")
-						libinstancetype.WaitForVMInstanceTypeRevisionNames(targetVMName, virtClient)
+						Eventually(matcher.ThisVMWith(testsuite.GetTestNamespace(sourceVM), targetVMName)).WithTimeout(300 * time.Second).WithPolling(time.Second).Should(matcher.HaveControllerRevisionRefs())
 
 						By("Asserting that the targetVM has new instancetype and preference controllerRevisions")
 						sourceVM, err := virtClient.VirtualMachine(testsuite.GetTestNamespace(sourceVM)).Get(context.Background(), sourceVM.Name, v1.GetOptions{})
@@ -722,12 +724,12 @@ var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
 						targetVM, err := virtClient.VirtualMachine(testsuite.GetTestNamespace(sourceVM)).Get(context.Background(), targetVMName, v1.GetOptions{})
 						Expect(err).ToNot(HaveOccurred())
 
-						Expect(targetVM.Spec.Instancetype.RevisionName).ToNot(Equal(sourceVM.Spec.Instancetype.RevisionName), "source and target instancetype revision names should not be equal")
-						Expect(targetVM.Spec.Preference.RevisionName).ToNot(Equal(sourceVM.Spec.Preference.RevisionName), "source and target preference revision names should not be equal")
+						Expect(targetVM.Status.InstancetypeRef.ControllerRevisionRef.Name).ToNot(Equal(sourceVM.Status.InstancetypeRef.ControllerRevisionRef.Name), "source and target instancetype revision names should not be equal")
+						Expect(targetVM.Status.PreferenceRef.ControllerRevisionRef.Name).ToNot(Equal(sourceVM.Status.PreferenceRef.ControllerRevisionRef.Name), "source and target preference revision names should not be equal")
 
 						By("Asserting that the source and target ControllerRevisions contain the same Object")
-						Expect(libinstancetype.EnsureControllerRevisionObjectsEqual(sourceVM.Spec.Instancetype.RevisionName, targetVM.Spec.Instancetype.RevisionName, virtClient)).To(BeTrue(), "source and target instance type controller revisions are expected to be equal")
-						Expect(libinstancetype.EnsureControllerRevisionObjectsEqual(sourceVM.Spec.Preference.RevisionName, targetVM.Spec.Preference.RevisionName, virtClient)).To(BeTrue(), "source and target preference controller revisions are expected to be equal")
+						Expect(libinstancetype.EnsureControllerRevisionObjectsEqual(sourceVM.Status.InstancetypeRef.ControllerRevisionRef.Name, targetVM.Status.InstancetypeRef.ControllerRevisionRef.Name, virtClient)).To(BeTrue(), "source and target instance type controller revisions are expected to be equal")
+						Expect(libinstancetype.EnsureControllerRevisionObjectsEqual(sourceVM.Status.PreferenceRef.ControllerRevisionRef.Name, targetVM.Status.PreferenceRef.ControllerRevisionRef.Name, virtClient)).To(BeTrue(), "source and target preference controller revisions are expected to be equal")
 					},
 						Entry("with a running VM", virtv1.RunStrategyAlways),
 						Entry("with a stopped VM", virtv1.RunStrategyHalted),
@@ -735,14 +737,14 @@ var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
 				})
 
 				It("double cloning: clone target as a clone source", func() {
-					addCloneAnnotationAndLabelFilters := func(vmClone *clonev1alpha1.VirtualMachineClone) {
+					addCloneAnnotationAndLabelFilters := func(vmClone *clone.VirtualMachineClone) {
 						filters := []string{"somekey/*"}
 						vmClone.Spec.LabelFilters = filters
 						vmClone.Spec.AnnotationFilters = filters
 						vmClone.Spec.Template.LabelFilters = filters
 						vmClone.Spec.Template.AnnotationFilters = filters
 					}
-					generateCloneWithFilters := func(sourceVM *virtv1.VirtualMachine, targetVMName string) *clonev1alpha1.VirtualMachineClone {
+					generateCloneWithFilters := func(sourceVM *virtv1.VirtualMachine, targetVMName string) *clone.VirtualMachineClone {
 						vmclone := generateCloneFromVMWithParams(sourceVM, targetVMName)
 						addCloneAnnotationAndLabelFilters(vmclone)
 						return vmclone
@@ -758,7 +760,7 @@ var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
 					sourceVM = createVMWithStorageClass(snapshotStorageClass, runStrategy)
 					vmClone = generateCloneWithFilters(sourceVM, targetVMName)
 
-					createCloneAndWaitForFinish(vmClone)
+					createCloneAndWaitForCompletion(vmClone)
 
 					By(fmt.Sprintf("Getting the target VM %s", targetVMName))
 					targetVM, err = virtClient.VirtualMachine(sourceVM.Namespace).Get(context.Background(), targetVMName, v1.GetOptions{})
@@ -772,7 +774,7 @@ var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
 					const cloneFromCloneName = "vm-clone-from-clone"
 					vmCloneFromClone := generateCloneWithFilters(targetVM, cloneFromCloneName)
 					vmCloneFromClone.Name = "test-clone-from-clone"
-					createCloneAndWaitForFinish(vmCloneFromClone)
+					createCloneAndWaitForCompletion(vmCloneFromClone)
 
 					By(fmt.Sprintf("Getting the target VM %s from clone", cloneFromCloneName))
 					targetVMCloneFromClone, err := virtClient.VirtualMachine(sourceVM.Namespace).Get(context.Background(), cloneFromCloneName, v1.GetOptions{})
@@ -793,14 +795,14 @@ var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
 					})
 
 					It("should not delete the vmsnapshot and vmrestore until all the pvc(s) are bound", func() {
-						addCloneAnnotationAndLabelFilters := func(vmClone *clonev1alpha1.VirtualMachineClone) {
+						addCloneAnnotationAndLabelFilters := func(vmClone *clone.VirtualMachineClone) {
 							filters := []string{"somekey/*"}
 							vmClone.Spec.LabelFilters = filters
 							vmClone.Spec.AnnotationFilters = filters
 							vmClone.Spec.Template.LabelFilters = filters
 							vmClone.Spec.Template.AnnotationFilters = filters
 						}
-						generateCloneWithFilters := func(sourceVM *virtv1.VirtualMachine, targetVMName string) *clonev1alpha1.VirtualMachineClone {
+						generateCloneWithFilters := func(sourceVM *virtv1.VirtualMachine, targetVMName string) *clone.VirtualMachineClone {
 							vmclone := generateCloneFromVMWithParams(sourceVM, targetVMName)
 							addCloneAnnotationAndLabelFilters(vmclone)
 							return vmclone
@@ -813,7 +815,7 @@ var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
 						Eventually(ThisVMIWith(sourceVM.Namespace, sourceVM.Name), 300*time.Second, 1*time.Second).ShouldNot(Exist())
 						Eventually(ThisVM(sourceVM), 300*time.Second, 1*time.Second).Should(Not(BeReady()))
 
-						createCloneAndWaitForFinish(vmClone)
+						createCloneAndWaitForCompletion(vmClone)
 
 						By(fmt.Sprintf("Getting the target VM %s", targetVMName))
 						targetVM, err = virtClient.VirtualMachine(sourceVM.Namespace).Get(context.Background(), targetVMName, v1.GetOptions{})
@@ -869,3 +871,21 @@ func stopCloneVM(virtClient kubecli.KubevirtClient, vm *virtv1.VirtualMachine) (
 
 	return virtClient.VirtualMachine(vm.Namespace).Patch(context.Background(), vm.Name, types.JSONPatchType, patch, v1.PatchOptions{})
 }
+
+func withFirmware(firmware *virtv1.Firmware) libvmi.Option {
+	return func(vmi *virtv1.VirtualMachineInstance) {
+		vmi.Spec.Domain.Firmware = firmware
+	}
+}
+
+func createSourceVM(options ...libvmi.Option) (*virtv1.VirtualMachine, error) {
+	vmi := libvmifact.NewCirros(options...)
+	vmi.Namespace = testsuite.GetTestNamespace(nil)
+	vm := libvmi.NewVirtualMachine(vmi,
+		libvmi.WithAnnotations(vmi.Annotations),
+		libvmi.WithLabels(vmi.Labels))
+
+	By(fmt.Sprintf("Creating VM %s", vm.Name))
+	virtClient := kubevirt.Client()
+	return virtClient.VirtualMachine(vm.Namespace).Create(context.Background(), vm, v1.CreateOptions{})
+}
