@@ -63,7 +63,6 @@ var DNSServiceNamespace = ""
 
 var MigrationNetworkNIC = "eth1"
 var MigrationNetworkName string
-var DisableCustomSELinuxPolicy bool
 
 func init() {
 	kubecli.Init()
@@ -102,7 +101,6 @@ func init() {
 	flag.StringVar(&DNSServiceNamespace, "dns-service-namespace", "kube-system", "cluster DNS service namespace")
 	flag.StringVar(&MigrationNetworkNIC, "migration-network-nic", "eth1", "NIC to use on cluster nodes to access the dedicated migration network")
 	flag.StringVar(&MigrationNetworkName, "migration-network-name", "", "name of the NetworkAttachmentDefinition CR to be used for dedicated migration network tests")
-	flag.BoolVar(&DisableCustomSELinuxPolicy, "disable-custom-selinux-policy", false, "disables the installation and use of the custom SELinux policy for virt-launcher")
 }
 
 func NormalizeFlags() {
