@@ -20,6 +20,7 @@
 package infrastructure
 
 import (
+	"kubevirt.io/kubevirt/tests/decorators"
 	"kubevirt.io/kubevirt/tests/framework/kubevirt"
 	"kubevirt.io/kubevirt/tests/libkubevirt/config"
 
@@ -29,10 +30,8 @@ import (
 	"kubevirt.io/client-go/kubecli"
 )
 
-var _ = DescribeInfra("cluster profiler for pprof data aggregation", func() {
-	var (
-		virtClient kubecli.KubevirtClient
-	)
+var _ = DescribeSerialInfra("cluster profiler for pprof data aggregation", func() {
+	var virtClient kubecli.KubevirtClient
 	BeforeEach(func() {
 		virtClient = kubevirt.Client()
 	})
@@ -50,7 +49,7 @@ var _ = DescribeInfra("cluster profiler for pprof data aggregation", func() {
 			_, err = virtClient.ClusterProfiler().Dump(&v1.ClusterProfilerRequest{})
 			Expect(err).To(HaveOccurred())
 		})
-		It("is enabled it should allow subresource access", func() {
+		It("[QUARANTINE]is enabled it should allow subresource access", decorators.Quarantine, func() {
 			config.EnableFeatureGate("ClusterProfiler")
 
 			err := virtClient.ClusterProfiler().Start()
