@@ -25,6 +25,10 @@ import (
 	"kubevirt.io/kubevirt/tests/decorators"
 )
 
+func DescribeSerialInfra(text string, args ...interface{}) bool {
+	return Describe("[sig-compute]Infrastructure "+text, Serial, decorators.SigCompute, args)
+}
+
 func DescribeInfra(text string, args ...interface{}) bool {
-	return Describe("[Serial][sig-compute]Infrastructure "+text, Serial, decorators.SigCompute, args)
+	return Describe("[sig-compute]Infrastructure "+text, decorators.SigCompute, args)
 }
