@@ -49,11 +49,11 @@ import (
 	"kubevirt.io/kubevirt/tests/testsuite"
 )
 
-var _ = DescribeInfra("Node-labeller", func() {
+var _ = DescribeSerialInfra("Node-labeller", func() {
+	const trueStr = "true"
 
 	var (
 		virtClient               kubecli.KubevirtClient
-		err                      error
 		nodesWithKVM             []*k8sv1.Node
 		nonExistingCPUModelLabel = v1.CPUModelLabel + "someNonExistingCPUModel"
 	)
@@ -77,14 +77,14 @@ var _ = DescribeInfra("Node-labeller", func() {
 
 		for _, node := range nodesWithKVM {
 			Eventually(func() error {
-				node, err = virtClient.CoreV1().Nodes().Get(context.Background(), node.Name, metav1.GetOptions{})
+				nodeObj, err := virtClient.CoreV1().Nodes().Get(context.Background(), node.Name, metav1.GetOptions{})
 				Expect(err).ToNot(HaveOccurred())
 
-				if _, exists := node.Labels[nonExistingCPUModelLabel]; exists {
+				if _, exists := nodeObj.Labels[nonExistingCPUModelLabel]; exists {
 					return fmt.Errorf("node %s is expected to not have label key %s", node.Name, nonExistingCPUModelLabel)
 				}
 
-				if _, exists := node.Annotations[v1.LabellerSkipNodeAnnotation]; exists {
+				if _, exists := nodeObj.Annotations[v1.LabellerSkipNodeAnnotation]; exists {
 					return fmt.Errorf("node %s is expected to not have annotation key %s", node.Name, v1.LabellerSkipNodeAnnotation)
 				}
 
@@ -106,8 +106,7 @@ var _ = DescribeInfra("Node-labeller", func() {
 		}, 30*time.Second, 2*time.Second).Should(BeTrue(), errorMsg)
 	}
 
-	Context("basic labelling", func() {
-
+	Context("basic labeling", func() {
 		type patch struct {
 			Op    string            `json:"op"`
 			Path  string            `json:"path"`
@@ -115,9 +114,8 @@ var _ = DescribeInfra("Node-labeller", func() {
 		}
 
 		It("skip node reconciliation when node has skip annotation", func() {
-
 			for i, node := range nodesWithKVM {
-				node.Labels[nonExistingCPUModelLabel] = "true"
+				node.Labels[nonExistingCPUModelLabel] = trueStr
 				p := []patch{
 					{
 						Op:    "add",
@@ -126,7 +124,7 @@ var _ = DescribeInfra("Node-labeller", func() {
 					},
 				}
 				if i == 0 {
-					node.Annotations[v1.LabellerSkipNodeAnnotation] = "true"
+					node.Annotations[v1.LabellerSkipNodeAnnotation] = trueStr
 
 					p = append(p, patch{
 						Op:    "add",
@@ -160,12 +158,11 @@ var _ = DescribeInfra("Node-labeller", func() {
 
 		It("[test_id:6246] label nodes with cpu model, cpu features and host cpu model", func() {
 			for _, node := range nodesWithKVM {
-				Expect(err).ToNot(HaveOccurred())
 				cpuModelLabelPresent := false
 				cpuFeatureLabelPresent := false
 				hyperVLabelPresent := false
-				hostCpuModelPresent := false
-				hostCpuRequiredFeaturesPresent := false
+				hostCPUModelPresent := false
+				hostCPURequiredFeaturesPresent := false
 				for key := range node.Labels {
 					if strings.Contains(key, v1.CPUModelLabel) {
 						cpuModelLabelPresent = true
@@ -177,14 +174,14 @@ var _ = DescribeInfra("Node-labeller", func() {
 						hyperVLabelPresent = true
 					}
 					if strings.Contains(key, v1.HostModelCPULabel) {
-						hostCpuModelPresent = true
+						hostCPUModelPresent = true
 					}
 					if strings.Contains(key, v1.HostModelRequiredFeaturesLabel) {
-						hostCpuRequiredFeaturesPresent = true
+						hostCPURequiredFeaturesPresent = true
 					}
 
-					if cpuModelLabelPresent && cpuFeatureLabelPresent && hyperVLabelPresent && hostCpuModelPresent &&
-						hostCpuRequiredFeaturesPresent {
+					if cpuModelLabelPresent && cpuFeatureLabelPresent && hyperVLabelPresent && hostCPUModelPresent &&
+						hostCPURequiredFeaturesPresent {
 						break
 					}
 				}
@@ -193,8 +190,8 @@ var _ = DescribeInfra("Node-labeller", func() {
 				Expect(cpuModelLabelPresent).To(BeTrue(), fmt.Sprintf(errorMessageTemplate, "cpu"))
 				Expect(cpuFeatureLabelPresent).To(BeTrue(), fmt.Sprintf(errorMessageTemplate, "feature"))
 				Expect(hyperVLabelPresent).To(BeTrue(), fmt.Sprintf(errorMessageTemplate, "hyperV"))
-				Expect(hostCpuModelPresent).To(BeTrue(), fmt.Sprintf(errorMessageTemplate, "host cpu model"))
-				Expect(hostCpuRequiredFeaturesPresent).To(BeTrue(), fmt.Sprintf(errorMessageTemplate, "host cpu required featuers"))
+				Expect(hostCPUModelPresent).To(BeTrue(), fmt.Sprintf(errorMessageTemplate, "host cpu model"))
+				Expect(hostCPURequiredFeaturesPresent).To(BeTrue(), fmt.Sprintf(errorMessageTemplate, "host cpu required featuers"))
 			}
 		})
 
@@ -203,10 +200,11 @@ var _ = DescribeInfra("Node-labeller", func() {
 			kvConfig.Spec.Configuration.ObsoleteCPUModels = nil
 			config.UpdateKubeVirtConfigValueAndWait(kvConfig.Spec.Configuration)
 			node := nodesWithKVM[0]
+			timeout := 30 * time.Second
 			Eventually(func() error {
-				node, err = virtClient.CoreV1().Nodes().Get(context.Background(), node.Name, metav1.GetOptions{})
+				nodeObj, err := virtClient.CoreV1().Nodes().Get(context.Background(), node.Name, metav1.GetOptions{})
 				Expect(err).ToNot(HaveOccurred())
-				for key := range node.Labels {
+				for key := range nodeObj.Labels {
 					if strings.Contains(key, v1.CPUModelLabel) {
 						model := strings.TrimPrefix(key, v1.CPUModelLabel)
 						if _, ok := nodelabellerutil.DefaultObsoleteCPUModels[model]; ok {
@@ -215,21 +213,21 @@ var _ = DescribeInfra("Node-labeller", func() {
 					}
 				}
 				return nil
-			}).WithTimeout(30 * time.Second).WithPolling(1 * time.Second).ShouldNot(HaveOccurred())
+			}).WithTimeout(timeout).WithPolling(1 * time.Second).ShouldNot(HaveOccurred())
 		})
 
 		It("[test_id:6995]should expose tsc frequency and tsc scalability", func() {
 			node := nodesWithKVM[0]
 			Expect(node.Labels).To(HaveKey("cpu-timer.node.kubevirt.io/tsc-frequency"))
 			Expect(node.Labels).To(HaveKey("cpu-timer.node.kubevirt.io/tsc-scalable"))
-			Expect(node.Labels["cpu-timer.node.kubevirt.io/tsc-scalable"]).To(Or(Equal("true"), Equal("false")))
+			Expect(node.Labels["cpu-timer.node.kubevirt.io/tsc-scalable"]).To(Or(Equal(trueStr), Equal("false")))
 			val, err := strconv.ParseInt(node.Labels["cpu-timer.node.kubevirt.io/tsc-frequency"], 10, 64)
 			Expect(err).ToNot(HaveOccurred())
 			Expect(val).To(BeNumerically(">", 0))
 		})
 	})
 
-	Context("advanced labelling", func() {
+	Context("advanced labeling", func() {
 		var originalKubeVirt *v1.KubeVirt
 
 		BeforeEach(func() {
@@ -315,8 +313,7 @@ var _ = DescribeInfra("Node-labeller", func() {
 		})
 	})
 
-	Context("[Serial]node with obsolete host-model cpuModel", Serial, func() {
-
+	Context("node with obsolete host-model cpuModel", Serial, func() {
 		var node *k8sv1.Node
 		var obsoleteModel string
 		var kvConfig *v1.KubeVirtConfiguration
@@ -334,23 +331,25 @@ var _ = DescribeInfra("Node-labeller", func() {
 			config.UpdateKubeVirtConfigValueAndWait(*kvConfig)
 
 			Eventually(func() error {
-				node, err = virtClient.CoreV1().Nodes().Get(context.Background(), node.Name, metav1.GetOptions{})
+				nodeObj, err := virtClient.CoreV1().Nodes().Get(context.Background(), node.Name, metav1.GetOptions{})
 				Expect(err).ShouldNot(HaveOccurred())
 
-				_, exists := node.Annotations[v1.LabellerSkipNodeAnnotation]
+				_, exists := nodeObj.Annotations[v1.LabellerSkipNodeAnnotation]
 				if exists {
 					return fmt.Errorf("node %s is expected to not have annotation %s", node.Name, v1.LabellerSkipNodeAnnotation)
 				}
 
 				obsoleteModelLabelFound := false
-				for labelKey := range node.Labels {
+				for labelKey := range nodeObj.Labels {
 					if strings.Contains(labelKey, v1.NodeHostModelIsObsoleteLabel) {
 						obsoleteModelLabelFound = true
 						break
 					}
 				}
 				if !obsoleteModelLabelFound {
-					return fmt.Errorf("node %s is expected to have a label with %s substring. this means node-labeller is not enabled for the node", node.Name, v1.NodeHostModelIsObsoleteLabel)
+					return fmt.Errorf(
+						"node %s is expected to have a label with %s substring. node-labeller is not enabled for the node",
+						node.Name, v1.NodeHostModelIsObsoleteLabel)
 				}
 
 				return nil
@@ -362,25 +361,27 @@ var _ = DescribeInfra("Node-labeller", func() {
 			config.UpdateKubeVirtConfigValueAndWait(*kvConfig)
 
 			Eventually(func() error {
-				node, err = virtClient.CoreV1().Nodes().Get(context.Background(), node.Name, metav1.GetOptions{})
+				nodeObj, err := virtClient.CoreV1().Nodes().Get(context.Background(), node.Name, metav1.GetOptions{})
 				Expect(err).ShouldNot(HaveOccurred())
 
 				obsoleteHostModelLabel := false
-				for labelKey := range node.Labels {
+				for labelKey := range nodeObj.Labels {
 					if strings.HasPrefix(labelKey, v1.NodeHostModelIsObsoleteLabel) {
 						obsoleteHostModelLabel = true
 						break
 					}
 				}
 				if obsoleteHostModelLabel {
-					return fmt.Errorf("node %s is expected to have a label with %s prefix. this means node-labeller is not enabled for the node", node.Name, v1.HostModelCPULabel)
+					return fmt.Errorf(
+						"node %s is expected to have a label with %s prefix. node-labeller is not enabled for the node",
+						node.Name, v1.HostModelCPULabel)
 				}
 
 				return nil
 			}, 30*time.Second, time.Second).ShouldNot(HaveOccurred())
 		})
 
-		It("[Serial]should not schedule vmi with host-model cpuModel to node with obsolete host-model cpuModel", func() {
+		It("should not schedule vmi with host-model cpuModel to node with obsolete host-model cpuModel", func() {
 			vmi := libvmifact.NewFedora(
 				libvmi.WithInterface(libvmi.InterfaceDeviceWithMasqueradeBinding()),
 				libvmi.WithNetwork(v1.DefaultPodNetwork()),
@@ -394,9 +395,10 @@ var _ = DescribeInfra("Node-labeller", func() {
 
 			By("Checking that the VMI failed")
 			Eventually(func() bool {
-				vmi, err := virtClient.VirtualMachineInstance(testsuite.GetTestNamespace(vmi)).Get(context.Background(), vmi.Name, metav1.GetOptions{})
+				vmiObj, err := virtClient.VirtualMachineInstance(
+					testsuite.GetTestNamespace(vmi)).Get(context.Background(), vmi.Name, metav1.GetOptions{})
 				Expect(err).ToNot(HaveOccurred())
-				for _, condition := range vmi.Status.Conditions {
+				for _, condition := range vmiObj.Status.Conditions {
 					if condition.Type == v1.VirtualMachineInstanceConditionType(k8sv1.PodScheduled) && condition.Status == k8sv1.ConditionFalse {
 						return strings.Contains(condition.Message, "didn't match Pod's node affinity/selector")
 					}
@@ -408,6 +410,5 @@ var _ = DescribeInfra("Node-labeller", func() {
 			// Remove as Node is persistent
 			events.DeleteEvents(node, k8sv1.EventTypeWarning, "HostModelIsObsolete")
 		})
-
 	})
 })
