@@ -21,8 +21,6 @@ package libinstancetype
 
 import (
 	"context"
-	"fmt"
-	"time"
 
 	. "github.com/onsi/gomega"
 
@@ -34,27 +32,6 @@ import (
 	"kubevirt.io/kubevirt/tests/testsuite"
 )
 
-func CheckForVMInstancetypeRevisionNames(vmName string, virtClient kubecli.KubevirtClient) func() error {
-	return func() error {
-		vm, err := virtClient.VirtualMachine(testsuite.GetTestNamespace(nil)).Get(context.Background(), vmName, metav1.GetOptions{})
-		if err != nil {
-			return err
-		}
-		if vm.Spec.Instancetype.RevisionName == "" {
-			return fmt.Errorf("instancetype revision name is expected to not be empty")
-		}
-
-		if vm.Spec.Preference.RevisionName == "" {
-			return fmt.Errorf("preference revision name is expected to not be empty")
-		}
-		return nil
-	}
-}
-
-func WaitForVMInstanceTypeRevisionNames(vmName string, virtClient kubecli.KubevirtClient) {
-	Eventually(CheckForVMInstancetypeRevisionNames(vmName, virtClient), 300*time.Second, 1*time.Second).ShouldNot(HaveOccurred())
-}
-
 func EnsureControllerRevisionObjectsEqual(crNameA, crNameB string, virtClient kubecli.KubevirtClient) bool {
 	crA, err := virtClient.AppsV1().ControllerRevisions(testsuite.GetTestNamespace(nil)).Get(context.Background(), crNameA, metav1.GetOptions{})
 	Expect(err).ToNot(HaveOccurred())
