@@ -444,6 +444,7 @@ func RunMigrationAndCollectMigrationMetrics(vmi *v1.VirtualMachineInstance, migr
 	var pod *k8sv1.Pod
 	var metricsIPs []string
 	var migrationMetrics = []string{
+		"kubevirt_vmi_migration_data_total_bytes",
 		"kubevirt_vmi_migration_data_remaining_bytes",
 		"kubevirt_vmi_migration_data_processed_bytes",
 		"kubevirt_vmi_migration_dirty_memory_rate_bytes",
@@ -503,3 +504,16 @@ func ConfirmMigrationMode(virtClient kubecli.KubevirtClient, vmi *v1.VirtualMach
 	By("Verifying the VMI's migration mode")
 	ExpectWithOffset(1, vmi.Status.MigrationState.Mode).To(Equal(expectedMode), fmt.Sprintf("expected migration state: %v got :%v \n", vmi.Status.MigrationState.Mode, expectedMode))
 }
+
+func WaitUntilMigrationMode(virtClient kubecli.KubevirtClient, vmi *v1.VirtualMachineInstance, expectedMode v1.MigrationMode, timeout time.Duration) {
+	By("Waiting until migration status")
+	EventuallyWithOffset(1, func() v1.MigrationMode {
+		By("Retrieving the VMI to check its migration mode")
+		newVMI, err := virtClient.VirtualMachineInstance(vmi.Namespace).Get(context.Background(), vmi.Name, metav1.GetOptions{})
+		Expect(err).ToNot(HaveOccurred())
+		if newVMI.Status.MigrationState != nil {
+			return newVMI.Status.MigrationState.Mode
+		}
+		return ""
+	}, timeout, 1*time.Second).Should(Equal(expectedMode))
+}
