@@ -8,14 +8,6 @@ import (
 	"kubevirt.io/kubevirt/tests/libnet/cluster"
 )
 
-func SkipWhenNotDualStackCluster() {
-	isClusterDualStack, err := cluster.DualStack()
-	ExpectWithOffset(1, err).NotTo(HaveOccurred(), "should have been able to infer if the cluster is dual stack")
-	if !isClusterDualStack {
-		Skip("This test requires a dual stack network config.")
-	}
-}
-
 func SkipWhenClusterNotSupportIpv4() {
 	clusterSupportsIpv4, err := cluster.SupportsIpv4()
 	ExpectWithOffset(1, err).NotTo(HaveOccurred(), "should have been able to infer if the cluster supports ipv4")
