@@ -25,22 +25,18 @@ import (
 
 	"kubevirt.io/kubevirt/tests/framework/kubevirt"
 
-	"github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 	gomegatypes "github.com/onsi/gomega/types"
 
 	rbacv1 "k8s.io/api/rbac/v1"
 	"k8s.io/apiextensions-apiserver/pkg/client/clientset/clientset"
-	"k8s.io/apimachinery/pkg/api/errors"
 	v12 "k8s.io/apimachinery/pkg/apis/meta/v1"
-	"k8s.io/apimachinery/pkg/types"
 	"k8s.io/apimachinery/pkg/util/rand"
 
 	v1 "kubevirt.io/api/core/v1"
 	"kubevirt.io/client-go/kubecli"
 	"kubevirt.io/containerized-data-importer-api/pkg/apis/core/v1beta1"
 
-	"kubevirt.io/kubevirt/pkg/apimachinery/patch"
 	"kubevirt.io/kubevirt/pkg/libvmi"
 	. "kubevirt.io/kubevirt/tests/framework/matcher"
 	"kubevirt.io/kubevirt/tests/util"
@@ -80,77 +76,7 @@ func EventuallyDV(dv *v1beta1.DataVolume, timeoutSec int, matcher gomegatypes.Go
 }
 
 func EventuallyDVWith(namespace, name string, timeoutSec int, matcher gomegatypes.GomegaMatcher) {
-	virtCli := kubevirt.Client()
-
-	if !IsDataVolumeGC(virtCli) {
-		Eventually(ThisDVWith(namespace, name), timeoutSec, time.Second).Should(matcher)
-		return
-	}
-
-	ginkgo.By("Verifying DataVolume garbage collection")
-	var dv *v1beta1.DataVolume
-	Eventually(func() *v1beta1.DataVolume {
-		var err error
-		dv, err = ThisDVWith(namespace, name)()
-		Expect(err).ToNot(HaveOccurred())
-		return dv
-	}, timeoutSec, time.Second).Should(Or(BeNil(), matcher))
-
-	if dv != nil {
-		if dv.Status.Phase != v1beta1.Succeeded {
-			return
-		}
-		if dv.Annotations["cdi.kubevirt.io/storage.deleteAfterCompletion"] == "true" {
-			Eventually(ThisDV(dv), timeoutSec).Should(BeNil())
-		}
-	}
-
-	Eventually(func() bool {
-		pvc, err := ThisPVCWith(namespace, name)()
-		Expect(err).ToNot(HaveOccurred())
-		return pvc != nil && pvc.Spec.VolumeName != ""
-	}, timeoutSec, time.Second).Should(BeTrue())
-}
-
-func DeleteDataVolume(dv **v1beta1.DataVolume) {
-	Expect(dv).ToNot(BeNil())
-	if *dv == nil {
-		return
-	}
-	ginkgo.By("Deleting DataVolume")
-	virtCli := kubevirt.Client()
-
-	err := virtCli.CdiClient().CdiV1beta1().DataVolumes((*dv).Namespace).Delete(context.Background(), (*dv).Name, v12.DeleteOptions{})
-	if !IsDataVolumeGC(virtCli) {
-		Expect(err).ToNot(HaveOccurred())
-		*dv = nil
-		return
-	}
-	if err != nil {
-		Expect(err).To(MatchError(errors.IsNotFound, "k8serrors.IsNotFound"))
-	}
-	if err = virtCli.CoreV1().PersistentVolumeClaims((*dv).Namespace).Delete(context.Background(), (*dv).Name, v12.DeleteOptions{}); err != nil {
-		Expect(err).To(MatchError(errors.IsNotFound, "k8serrors.IsNotFound"))
-	}
-	*dv = nil
-}
-
-func SetDataVolumeGC(virtCli kubecli.KubevirtClient, ttlSec *int32) {
-	cdi := GetCDI(virtCli)
-	if cdi.Spec.Config.DataVolumeTTLSeconds == ttlSec {
-		return
-	}
-
-	p, err := patch.New(patch.WithReplace("/spec/config/dataVolumeTTLSeconds", ttlSec)).GeneratePayload()
-	Expect(err).NotTo(HaveOccurred())
-	_, err = virtCli.CdiClient().CdiV1beta1().CDIs().Patch(context.Background(), cdi.Name, types.JSONPatchType, p, v12.PatchOptions{})
-	Expect(err).ToNot(HaveOccurred())
-}
-
-func IsDataVolumeGC(virtCli kubecli.KubevirtClient) bool {
-	config, err := virtCli.CdiClient().CdiV1beta1().CDIConfigs().Get(context.TODO(), "config", v12.GetOptions{})
-	Expect(err).ToNot(HaveOccurred())
-	return config.Spec.DataVolumeTTLSeconds != nil && *config.Spec.DataVolumeTTLSeconds >= 0
+	Eventually(ThisDVWith(namespace, name), timeoutSec, time.Second).Should(matcher)
 }
 
 func GetCDI(virtCli kubecli.KubevirtClient) *v1beta1.CDI {
@@ -172,10 +98,7 @@ func HasDataVolumeCRD() bool {
 
 	_, err = ext.ApiextensionsV1().CustomResourceDefinitions().Get(context.Background(), "datavolumes.cdi.kubevirt.io", v12.GetOptions{})
 
-	if err != nil {
-		return false
-	}
-	return true
+	return err == nil
 }
 
 func HasCDI() bool {
