@@ -24,7 +24,6 @@ import (
 	"kubevirt.io/client-go/kubecli"
 
 	"kubevirt.io/kubevirt/tests/console"
-	"kubevirt.io/kubevirt/tests/decorators"
 	"kubevirt.io/kubevirt/tests/libnet"
 	"kubevirt.io/kubevirt/tests/libnet/vmnetserver"
 	"kubevirt.io/kubevirt/tests/libvmifact"
@@ -85,7 +84,6 @@ var _ = SIGDescribe("[rfe_id:150][crit:high][vendor:cnv-qe@redhat.com][level:com
 				assertHTTPPingFailed(clientVMI, serverVMI, 80)
 				assertHTTPPingFailed(clientVMI, serverVMI, 81)
 			})
-
 		})
 
 		Context("and vms limited by allow same namespace networkpolicy", func() {
@@ -112,7 +110,6 @@ var _ = SIGDescribe("[rfe_id:150][crit:high][vendor:cnv-qe@redhat.com][level:com
 			})
 
 			When("client vmi is on default namespace", func() {
-
 				BeforeEach(func() {
 					var err error
 					clientVMI, err = createClientVmi(testsuite.NamespaceTestDefault, virtClient)
@@ -120,7 +117,7 @@ var _ = SIGDescribe("[rfe_id:150][crit:high][vendor:cnv-qe@redhat.com][level:com
 					assertIPsNotEmptyForVMI(clientVMI)
 				})
 
-				It("[test_id:1513] should succeed pinging between two VMI/s in the same namespace", decorators.Conformance, func() {
+				It("[Conformance][test_id:1513] should succeed pinging between two VMI/s in the same namespace", func() {
 					assertPingSucceed(clientVMI, serverVMI)
 				})
 			})
@@ -135,7 +132,7 @@ var _ = SIGDescribe("[rfe_id:150][crit:high][vendor:cnv-qe@redhat.com][level:com
 					assertIPsNotEmptyForVMI(clientVMIAlternativeNamespace)
 				})
 
-				It("[test_id:1514] should fail pinging between two VMI/s each on different namespaces", decorators.Conformance, func() {
+				It("[Conformance][test_id:1514] should fail pinging between two VMI/s each on different namespaces", func() {
 					assertPingFail(clientVMIAlternativeNamespace, serverVMI)
 				})
 			})
@@ -273,7 +270,6 @@ var _ = SIGDescribe("[rfe_id:150][crit:high][vendor:cnv-qe@redhat.com][level:com
 				assertHTTPPingFailed(clientVMI, serverVMI, 81)
 			})
 		})
-
 	})
 })
 
@@ -289,7 +285,6 @@ func assertPingSucceed(fromVmi, toVmi *v1.VirtualMachineInstance) {
 }
 
 func assertPingFail(fromVmi, toVmi *v1.VirtualMachineInstance) {
-
 	EventuallyWithOffset(1, func() error {
 		var err error
 		for _, toIp := range toVmi.Status.Interfaces[0].IPs {
