@@ -35,7 +35,6 @@ import (
 	libvmici "kubevirt.io/kubevirt/pkg/libvmi/cloudinit"
 
 	"kubevirt.io/kubevirt/tests/console"
-	"kubevirt.io/kubevirt/tests/decorators"
 	"kubevirt.io/kubevirt/tests/framework/kubevirt"
 	"kubevirt.io/kubevirt/tests/framework/matcher"
 	"kubevirt.io/kubevirt/tests/libnet"
@@ -62,16 +61,6 @@ var _ = SIGDescribe("Primary Pod Network", func() {
 			Expect(libnet.ValidateVMIandPodIPMatch(vmi, vmiPod)).To(Succeed(), "Should have matching IP/s between pod and vmi")
 		}
 
-		Context("VMI connected to the pod network using the default (implicit) binding", func() {
-			var vmi *v1.VirtualMachineInstance
-
-			BeforeEach(func() {
-				vmi = setupVMI(virtClient, libvmifact.NewAlpine())
-			})
-
-			It("should report PodIP as its own on interface status", func() { AssertReportedIP(vmi) })
-		})
-
 		Context("VMI connected to the pod network using bridge binding", func() {
 			When("Guest Agent exists", func() {
 				var (
@@ -116,21 +105,6 @@ var _ = SIGDescribe("Primary Pod Network", func() {
 					Eventually(vmiIPs, 2*time.Minute, 5*time.Second).Should(Equal(podIPs), "should contain VMI Status IP as Pod status IPs")
 				})
 			})
-			When("no Guest Agent exists", func() {
-				var vmi *v1.VirtualMachineInstance
-
-				BeforeEach(func() {
-					vmi = setupVMI(
-						virtClient,
-						libvmifact.NewAlpine(
-							libvmi.WithInterface(*v1.DefaultBridgeNetworkInterface()),
-							libvmi.WithNetwork(v1.DefaultPodNetwork()),
-						),
-					)
-				})
-
-				It("should report PodIP as its own on interface status", func() { AssertReportedIP(vmi) })
-			})
 		})
 
 		Context("VMI connected to the pod network using masquerade binding", func() {
@@ -160,7 +134,6 @@ var _ = SIGDescribe("Primary Pod Network", func() {
 						return libnet.ValidateVMIandPodIPMatch(vmi, vmiPod)
 					}, 5*time.Second, time.Second).Should(Succeed())
 				})
-
 			})
 
 			When("no Guest Agent exists", func() {
@@ -176,7 +149,7 @@ var _ = SIGDescribe("Primary Pod Network", func() {
 					)
 				})
 
-				It("should report PodIP as its own on interface status", decorators.Conformance, func() { AssertReportedIP(vmi) })
+				It("[Conformance] should report PodIP as its own on interface status", func() { AssertReportedIP(vmi) })
 			})
 		})
 	})
