@@ -27,7 +27,6 @@ import (
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 
-	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/errors"
 	k8smetav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -41,13 +40,13 @@ import (
 	cdiv1 "kubevirt.io/containerized-data-importer-api/pkg/apis/core/v1beta1"
 
 	"kubevirt.io/kubevirt/pkg/apimachinery/patch"
+	"kubevirt.io/kubevirt/pkg/libdv"
 	"kubevirt.io/kubevirt/pkg/libvmi"
 	"kubevirt.io/kubevirt/pkg/pointer"
 	cd "kubevirt.io/kubevirt/tests/containerdisk"
 	"kubevirt.io/kubevirt/tests/decorators"
 	"kubevirt.io/kubevirt/tests/framework/kubevirt"
 	"kubevirt.io/kubevirt/tests/framework/matcher"
-	"kubevirt.io/kubevirt/tests/libdv"
 	"kubevirt.io/kubevirt/tests/libstorage"
 	"kubevirt.io/kubevirt/tests/libvmifact"
 	"kubevirt.io/kubevirt/tests/testsuite"
@@ -66,9 +65,11 @@ var _ = Describe("[sig-compute]VirtualMachinePool", decorators.SigCompute, func(
 		virtClient = kubevirt.Client()
 	})
 
-	waitForVMIs := func(namespace string, expectedCount int) {
+	waitForVMIs := func(namespace string, labelSelector *metav1.LabelSelector, expectedCount int) {
 		Eventually(func() error {
-			vmis, err := virtClient.VirtualMachineInstance(namespace).List(context.Background(), metav1.ListOptions{})
+			vmis, err := virtClient.VirtualMachineInstance(namespace).List(context.Background(), metav1.ListOptions{
+				LabelSelector: labelSelectorToString(labelSelector),
+			})
 			Expect(err).ToNot(HaveOccurred())
 			if len(vmis.Items) != expectedCount {
 				return fmt.Errorf("Only %d vmis exist, expected %d", len(vmis.Items), expectedCount)
@@ -102,7 +103,9 @@ var _ = Describe("[sig-compute]VirtualMachinePool", decorators.SigCompute, func(
 			return pool.Status.Replicas
 		}, 90*time.Second, time.Second).Should(Equal(int32(scale)))
 
-		vms, err := virtClient.VirtualMachine(testsuite.NamespaceTestDefault).List(context.Background(), metav1.ListOptions{})
+		vms, err := virtClient.VirtualMachine(testsuite.NamespaceTestDefault).List(context.Background(), metav1.ListOptions{
+			LabelSelector: labelSelectorToString(pool.Spec.Selector),
+		})
 		Expect(err).ToNot(HaveOccurred())
 		Expect(filterNotDeletedVMsOwnedByPool(pool.Name, vms)).To(HaveLen(int(scale)))
 	}
@@ -207,7 +210,9 @@ var _ = Describe("[sig-compute]VirtualMachinePool", decorators.SigCompute, func(
 		// Wait until VMs are gone
 		By("Waiting until all VMs are gone")
 		Eventually(func() int {
-			vms, err := virtClient.VirtualMachine(newPool.ObjectMeta.Namespace).List(context.Background(), metav1.ListOptions{})
+			vms, err := virtClient.VirtualMachine(newPool.ObjectMeta.Namespace).List(context.Background(), metav1.ListOptions{
+				LabelSelector: labelSelectorToString(newPool.Spec.Selector),
+			})
 			Expect(err).ToNot(HaveOccurred())
 			return len(vms.Items)
 		}, 120*time.Second, 1*time.Second).Should(BeZero())
@@ -221,19 +226,20 @@ var _ = Describe("[sig-compute]VirtualMachinePool", decorators.SigCompute, func(
 			err       error
 			vms       *v1.VirtualMachineList
 			dvs       *cdiv1.DataVolumeList
-			pvcs      *corev1.PersistentVolumeClaimList
 			dvOrigUID types.UID
 		)
 
 		By("Waiting until all VMs are created")
 		Eventually(func() int {
-			vms, err = virtClient.VirtualMachine(newPool.ObjectMeta.Namespace).List(context.Background(), metav1.ListOptions{})
+			vms, err = virtClient.VirtualMachine(newPool.ObjectMeta.Namespace).List(context.Background(), metav1.ListOptions{
+				LabelSelector: labelSelectorToString(newPool.Spec.Selector),
+			})
 			Expect(err).ToNot(HaveOccurred())
 			return len(vms.Items)
 		}, 60*time.Second, 1*time.Second).Should(Equal(2))
 
 		By("Waiting until all VMIs are created and online")
-		waitForVMIs(newPool.Namespace, 2)
+		waitForVMIs(newPool.Namespace, newPool.Spec.Selector, 2)
 
 		// Select a VM to delete, and record the VM and DV/PVC UIDs associated with the VM.
 		origUID := vms.Items[0].UID
@@ -242,30 +248,15 @@ var _ = Describe("[sig-compute]VirtualMachinePool", decorators.SigCompute, func(
 		dvName1 := vms.Items[1].Spec.DataVolumeTemplates[0].ObjectMeta.Name
 		Expect(dvName).ToNot(Equal(dvName1))
 
-		isGC := libstorage.IsDataVolumeGC(virtClient)
-		if isGC {
-			By("Ensure PVCs are created")
-			pvcs, err = virtClient.CoreV1().PersistentVolumeClaims(newPool.Namespace).List(context.Background(), metav1.ListOptions{})
-			Expect(err).ToNot(HaveOccurred())
-			pvcCount := 0
-			for _, pvc := range pvcs.Items {
-				if pvc.Name == dvName || pvc.Name == dvName1 {
-					pvcCount++
-					if pvc.Name == dvName {
-						dvOrigUID = pvc.UID
-					}
-				}
-			}
-			Expect(pvcCount).To(Equal(2))
-		} else {
-			By("Ensure DataVolumes are created")
-			dvs, err = virtClient.CdiClient().CdiV1beta1().DataVolumes(newPool.Namespace).List(context.Background(), metav1.ListOptions{})
-			Expect(err).ToNot(HaveOccurred())
-			Expect(dvs.Items).To(HaveLen(2))
-			for _, dv := range dvs.Items {
-				if dv.Name == dvName {
-					dvOrigUID = dv.UID
-				}
+		By("Ensure DataVolumes are created")
+		dvs, err = virtClient.CdiClient().CdiV1beta1().DataVolumes(newPool.Namespace).List(context.Background(), metav1.ListOptions{
+			LabelSelector: labelSelectorToString(labelSelectorFromVMs(vms)),
+		})
+		Expect(err).ToNot(HaveOccurred())
+		Expect(dvs.Items).To(HaveLen(2))
+		for _, dv := range dvs.Items {
+			if dv.Name == dvName {
+				dvOrigUID = dv.UID
 			}
 		}
 
@@ -277,7 +268,9 @@ var _ = Describe("[sig-compute]VirtualMachinePool", decorators.SigCompute, func(
 
 		By("Waiting for deleted VM to be replaced")
 		Eventually(func() error {
-			vms, err = virtClient.VirtualMachine(newPool.ObjectMeta.Namespace).List(context.Background(), metav1.ListOptions{})
+			vms, err = virtClient.VirtualMachine(newPool.ObjectMeta.Namespace).List(context.Background(), metav1.ListOptions{
+				LabelSelector: labelSelectorToString(newPool.Spec.Selector),
+			})
 			if err != nil {
 				return err
 			}
@@ -301,31 +294,17 @@ var _ = Describe("[sig-compute]VirtualMachinePool", decorators.SigCompute, func(
 		}, 120*time.Second, 1*time.Second).Should(BeNil())
 
 		By("Waiting until all VMIs are created and online again")
-		waitForVMIs(newPool.Namespace, 2)
+		waitForVMIs(newPool.Namespace, newPool.Spec.Selector, 2)
 
-		if isGC {
-			pvcs, err = virtClient.CoreV1().PersistentVolumeClaims(newPool.Namespace).List(context.Background(), metav1.ListOptions{})
-			Expect(err).ToNot(HaveOccurred())
+		By("Verify datavolume count after VM replacement")
+		dvs, err = virtClient.CdiClient().CdiV1beta1().DataVolumes(newPool.Namespace).List(context.Background(), metav1.ListOptions{
+			LabelSelector: labelSelectorToString(labelSelectorFromVMs(vms)),
+		})
+		Expect(dvs.Items).To(HaveLen(2))
 
-			By("Verify pvc for deleted VM is replaced")
-			pvcCount := 0
-			for _, pvc := range pvcs.Items {
-				if pvc.Name == dvName || pvc.Name == dvName1 {
-					Expect(pvc.UID).ToNot(Equal(dvOrigUID))
-					pvcCount++
-				}
-			}
-			By("Verify pvc count after VM replacement")
-			Expect(pvcCount).To(Equal(2))
-		} else {
-			By("Verify datavolume count after VM replacement")
-			dvs, err = virtClient.CdiClient().CdiV1beta1().DataVolumes(newPool.Namespace).List(context.Background(), metav1.ListOptions{})
-			Expect(dvs.Items).To(HaveLen(2))
-
-			By("Verify datavolume for deleted VM is replaced")
-			for _, dv := range dvs.Items {
-				Expect(dv.UID).ToNot(Equal(dvOrigUID))
-			}
+		By("Verify datavolume for deleted VM is replaced")
+		for _, dv := range dvs.Items {
+			Expect(dv.UID).ToNot(Equal(dvOrigUID))
 		}
 	})
 
@@ -338,7 +317,9 @@ var _ = Describe("[sig-compute]VirtualMachinePool", decorators.SigCompute, func(
 
 		By("Waiting until all VMs are created")
 		Eventually(func() int {
-			vms, err = virtClient.VirtualMachine(newPool.ObjectMeta.Namespace).List(context.Background(), metav1.ListOptions{})
+			vms, err = virtClient.VirtualMachine(newPool.ObjectMeta.Namespace).List(context.Background(), metav1.ListOptions{
+				LabelSelector: labelSelectorToString(newPool.Spec.Selector),
+			})
 			Expect(err).ToNot(HaveOccurred())
 			return len(vms.Items)
 		}, 120*time.Second, 1*time.Second).Should(Equal(3))
@@ -351,7 +332,9 @@ var _ = Describe("[sig-compute]VirtualMachinePool", decorators.SigCompute, func(
 
 		By("Waiting for deleted VM to be replaced")
 		Eventually(func() error {
-			vms, err = virtClient.VirtualMachine(newPool.ObjectMeta.Namespace).List(context.Background(), metav1.ListOptions{})
+			vms, err = virtClient.VirtualMachine(newPool.ObjectMeta.Namespace).List(context.Background(), metav1.ListOptions{
+				LabelSelector: labelSelectorToString(newPool.Spec.Selector),
+			})
 			if err != nil {
 				return err
 			}
@@ -379,9 +362,11 @@ var _ = Describe("[sig-compute]VirtualMachinePool", decorators.SigCompute, func(
 	It("should roll out VM template changes without impacting VMI", func() {
 		newPool := newVirtualMachinePool()
 		doScale(newPool.ObjectMeta.Name, 1)
-		waitForVMIs(newPool.Namespace, 1)
+		waitForVMIs(newPool.Namespace, newPool.Spec.Selector, 1)
 
-		vms, err := virtClient.VirtualMachine(newPool.ObjectMeta.Namespace).List(context.Background(), metav1.ListOptions{})
+		vms, err := virtClient.VirtualMachine(newPool.ObjectMeta.Namespace).List(context.Background(), metav1.ListOptions{
+			LabelSelector: labelSelectorToString(newPool.Spec.Selector),
+		})
 
 		Expect(err).ToNot(HaveOccurred())
 		Expect(vms.Items).To(HaveLen(1))
@@ -435,9 +420,11 @@ var _ = Describe("[sig-compute]VirtualMachinePool", decorators.SigCompute, func(
 	It("should roll out VMI template changes and proactively roll out new VMIs", func() {
 		newPool := newVirtualMachinePool()
 		doScale(newPool.ObjectMeta.Name, 1)
-		waitForVMIs(newPool.Namespace, 1)
+		waitForVMIs(newPool.Namespace, newPool.Spec.Selector, 1)
 
-		vms, err := virtClient.VirtualMachine(newPool.ObjectMeta.Namespace).List(context.Background(), metav1.ListOptions{})
+		vms, err := virtClient.VirtualMachine(newPool.ObjectMeta.Namespace).List(context.Background(), metav1.ListOptions{
+			LabelSelector: labelSelectorToString(newPool.Spec.Selector),
+		})
 
 		Expect(err).ToNot(HaveOccurred())
 		Expect(vms.Items).To(HaveLen(1))
@@ -499,7 +486,9 @@ var _ = Describe("[sig-compute]VirtualMachinePool", decorators.SigCompute, func(
 		doScale(newPool.ObjectMeta.Name, 2)
 
 		// Check for owner reference
-		vms, err := virtClient.VirtualMachine(newPool.ObjectMeta.Namespace).List(context.Background(), metav1.ListOptions{})
+		vms, err := virtClient.VirtualMachine(newPool.ObjectMeta.Namespace).List(context.Background(), metav1.ListOptions{
+			LabelSelector: labelSelectorToString(newPool.Spec.Selector),
+		})
 		Expect(vms.Items).To(HaveLen(2))
 		Expect(err).ToNot(HaveOccurred())
 		for _, vm := range vms.Items {
@@ -518,7 +507,9 @@ var _ = Describe("[sig-compute]VirtualMachinePool", decorators.SigCompute, func(
 		}, 60*time.Second, 1*time.Second).Should(MatchError(errors.IsNotFound, "k8serrors.IsNotFound"))
 
 		By("Checking if two VMs are orphaned and still exist")
-		vms, err = virtClient.VirtualMachine(newPool.ObjectMeta.Namespace).List(context.Background(), metav1.ListOptions{})
+		vms, err = virtClient.VirtualMachine(newPool.ObjectMeta.Namespace).List(context.Background(), metav1.ListOptions{
+			LabelSelector: labelSelectorToString(newPool.Spec.Selector),
+		})
 		Expect(vms.Items).To(HaveLen(2))
 
 		By("Checking a VirtualMachine owner references")
@@ -579,6 +570,46 @@ var _ = Describe("[sig-compute]VirtualMachinePool", decorators.SigCompute, func(
 			return pool.Status.Replicas
 		}, 10*time.Second, 1*time.Second).Should(Equal(int32(1)))
 	})
+
+	DescribeTable("should respect name generation settings", func(appendIndex *bool) {
+		const (
+			cmName     = "configmap"
+			secretName = "secret"
+		)
+
+		newPool := newPoolFromVMI(libvmi.New(
+			libvmi.WithConfigMapDisk(cmName, cmName),
+			libvmi.WithSecretDisk(secretName, secretName),
+		))
+		newPool.Spec.NameGeneration = &poolv1.VirtualMachinePoolNameGeneration{
+			AppendIndexToConfigMapRefs: appendIndex,
+			AppendIndexToSecretRefs:    appendIndex,
+		}
+		createVirtualMachinePool(newPool)
+		doScale(newPool.Name, 2)
+
+		vms, err := virtClient.VirtualMachine(newPool.ObjectMeta.Namespace).List(context.Background(), metav1.ListOptions{
+			LabelSelector: labelSelectorToString(newPool.Spec.Selector),
+		})
+		Expect(vms.Items).To(HaveLen(2))
+		Expect(err).ToNot(HaveOccurred())
+		for _, vm := range vms.Items {
+			Expect(vm.Spec.Template.Spec.Volumes).To(HaveLen(2))
+			Expect(vm.Spec.Template.Spec.Volumes[0].Name).To(Equal(cmName))
+			Expect(vm.Spec.Template.Spec.Volumes[1].Name).To(Equal(secretName))
+			if appendIndex != nil && *appendIndex {
+				Expect(vm.Spec.Template.Spec.Volumes[0].VolumeSource.ConfigMap.Name).To(MatchRegexp(fmt.Sprintf("%s-\\d", cmName)))
+				Expect(vm.Spec.Template.Spec.Volumes[1].VolumeSource.Secret.SecretName).To(MatchRegexp(fmt.Sprintf("%s-\\d", secretName)))
+			} else {
+				Expect(vm.Spec.Template.Spec.Volumes[0].VolumeSource.ConfigMap.Name).To(Equal(cmName))
+				Expect(vm.Spec.Template.Spec.Volumes[1].VolumeSource.Secret.SecretName).To(Equal(secretName))
+			}
+		}
+	},
+		Entry("do not append index by default", nil),
+		Entry("do not append index if set to false", pointer.P(false)),
+		Entry("append index if set to true", pointer.P(true)),
+	)
 })
 
 func newPoolFromVMI(vmi *v1.VirtualMachineInstance) *poolv1.VirtualMachinePool {
@@ -624,3 +655,25 @@ func filterNotDeletedVMsOwnedByPool(poolName string, vms *v1.VirtualMachineList)
 	}
 	return result
 }
+
+func labelSelectorToString(labelSelector *metav1.LabelSelector) string {
+	selector, err := metav1.LabelSelectorAsSelector(labelSelector)
+	Expect(err).ToNot(HaveOccurred())
+	return selector.String()
+}
+
+func labelSelectorFromVMs(vms *v1.VirtualMachineList) *metav1.LabelSelector {
+	var values []string
+	for _, vm := range vms.Items {
+		values = append(values, string(vm.UID))
+	}
+	return &metav1.LabelSelector{
+		MatchExpressions: []metav1.LabelSelectorRequirement{
+			{
+				Key:      v1.CreatedByLabel,
+				Operator: metav1.LabelSelectorOpIn,
+				Values:   values,
+			},
+		},
+	}
+}
