@@ -35,23 +35,20 @@ import (
 	"kubevirt.io/kubevirt/pkg/libvmi"
 	"kubevirt.io/kubevirt/pkg/pointer"
 
-	"kubevirt.io/kubevirt/tests"
 	"kubevirt.io/kubevirt/tests/events"
 	"kubevirt.io/kubevirt/tests/flags"
 	"kubevirt.io/kubevirt/tests/framework/kubevirt"
 	"kubevirt.io/kubevirt/tests/framework/matcher"
+	"kubevirt.io/kubevirt/tests/libnode"
 	"kubevirt.io/kubevirt/tests/libwait"
 	"kubevirt.io/kubevirt/tests/testsuite"
 )
 
 const (
-	ioerrorPV  = "ioerror-pv"
-	ioerrorPVC = "ioerror-pvc"
 	deviceName = "errdev0"
-	diskName   = "disk0"
 )
 
-var _ = SIGDescribe("[Serial]K8s IO events", Serial, func() {
+var _ = SIGDescribe("K8s IO events", Serial, func() {
 	var (
 		nodeName   string
 		virtClient kubecli.KubevirtClient
@@ -62,10 +59,10 @@ var _ = SIGDescribe("[Serial]K8s IO events", Serial, func() {
 	BeforeEach(func() {
 		virtClient = kubevirt.Client()
 
-		nodeName = tests.NodeNameWithHandler()
+		nodeName = libnode.GetNodeNameWithHandler()
 		createFaultyDisk(nodeName, deviceName)
 		var err error
-		pv, pvc, err = tests.CreatePVandPVCwithFaultyDisk(nodeName, "/dev/mapper/"+deviceName, testsuite.GetTestNamespace(nil))
+		pv, pvc, err = CreatePVandPVCwithFaultyDisk(nodeName, "/dev/mapper/"+deviceName, testsuite.GetTestNamespace(nil))
 		Expect(err).NotTo(HaveOccurred(), "Failed to create PV and PVC for faulty disk")
 	})
 	AfterEach(func() {
