@@ -55,6 +55,7 @@ import (
 	"kubevirt.io/kubevirt/pkg/util"
 	"kubevirt.io/kubevirt/pkg/virt-config/featuregate"
 
+	"kubevirt.io/kubevirt/tests/console"
 	cd "kubevirt.io/kubevirt/tests/containerdisk"
 	"kubevirt.io/kubevirt/tests/decorators"
 	"kubevirt.io/kubevirt/tests/flags"
@@ -91,6 +92,7 @@ var _ = SIGDescribe("Volumes update with migration", decorators.RequiresTwoSched
 		Expect(err).ToNot(HaveOccurred())
 		return dv
 	}
+
 	BeforeEach(func() {
 		virtClient = kubevirt.Client()
 		originalKv := libkubevirt.GetCurrentKv(virtClient)
@@ -168,6 +170,7 @@ var _ = SIGDescribe("Volumes update with migration", decorators.RequiresTwoSched
 			}, 120*time.Second, time.Second).Should(BeTrue())
 		}
 		waitVMIToHaveVolumeChangeCond := func(vmiName, ns string) {
+
 			Eventually(func() bool {
 				vmi, err := virtClient.VirtualMachineInstance(ns).Get(context.Background(), vmiName,
 					metav1.GetOptions{})
@@ -192,6 +195,7 @@ var _ = SIGDescribe("Volumes update with migration", decorators.RequiresTwoSched
 			Expect(err).ToNot(HaveOccurred())
 			return dv
 		}
+
 		createVMWithDV := func(dv *cdiv1.DataVolume, volName string) *virtv1.VirtualMachine {
 			vmi := libvmi.New(
 				libvmi.WithNamespace(ns),
@@ -212,7 +216,6 @@ var _ = SIGDescribe("Volumes update with migration", decorators.RequiresTwoSched
 
 			return vm
 		}
-
 		updateVMWithPVC := func(vm *virtv1.VirtualMachine, volName, claim string) {
 			// Replace dst pvc
 			i := slices.IndexFunc(vm.Spec.Template.Spec.Volumes, func(volume virtv1.Volume) bool {
@@ -332,8 +335,9 @@ var _ = SIGDescribe("Volumes update with migration", decorators.RequiresTwoSched
 
 		It("should migrate the source volume from a source DV to a destination DV", func() {
 			volName := "disk0"
-			vm := createVMWithDV(createDV(), volName)
-			destDV := createBlankDV(virtClient, ns, size)
+			srcDV := createDV()
+			vm := createVMWithDV(srcDV, volName)
+			destDV := createBlankDV(virtClient, ns, "2Gi")
 			By("Update volumes")
 			updateVMWithDV(vm, volName, destDV.Name)
 			Eventually(func() bool {
@@ -344,6 +348,10 @@ var _ = SIGDescribe("Volumes update with migration", decorators.RequiresTwoSched
 				return claim == destDV.Name
 			}, 120*time.Second, time.Second).Should(BeTrue())
 			waitForMigrationToSucceed(virtClient, vm.Name, ns)
+
+			By("Rollback to the original volumes")
+			updateVMWithDV(vm, volName, srcDV.Name)
+			waitForMigrationToSucceed(virtClient, vm.Name, ns)
 		})
 
 		It("should migrate the source volume from a source and destination block RWX DVs", decorators.StorageCritical, decorators.RequiresRWXBlock, func() {
@@ -744,12 +752,9 @@ var _ = SIGDescribe("Volumes update with migration", decorators.RequiresTwoSched
 		})
 	})
 
-	Describe("Hotplug volumes", func() {
+	Context("Hotplug volumes", func() {
 		var fgDisabled bool
 		BeforeEach(func() {
-			var err error
-			virtClient, err = kubecli.GetKubevirtClient()
-			Expect(err).ToNot(HaveOccurred())
 			fgDisabled = !checks.HasFeature(featuregate.HotplugVolumesGate)
 			if fgDisabled {
 				config.EnableFeatureGate(featuregate.HotplugVolumesGate)
@@ -849,65 +854,214 @@ var _ = SIGDescribe("Volumes update with migration", decorators.RequiresTwoSched
 			Entry("with an ephemeral volume", false),
 		)
 
-		It("should be able to migrate an hotplugged volume", func() {
-			const volName = "vol0"
-			ns := testsuite.GetTestNamespace(nil)
-			dv := createBlankDV(virtClient, ns, "2G")
-			vmi := libvmifact.NewCirros(
-				libvmi.WithNamespace(ns),
-				libvmi.WithInterface(libvmi.InterfaceDeviceWithMasqueradeBinding()),
-				libvmi.WithNetwork(virtv1.DefaultPodNetwork()),
-			)
-			vm := libvmi.NewVirtualMachine(vmi,
-				libvmi.WithRunStrategy(virtv1.RunStrategyAlways),
-			)
-			vm, err := virtClient.VirtualMachine(ns).Create(context.Background(), vm, metav1.CreateOptions{})
-			Expect(err).ToNot(HaveOccurred())
-			Eventually(matcher.ThisVM(vm), 360*time.Second, 1*time.Second).Should(matcher.BeReady())
-			libwait.WaitForSuccessfulVMIStart(vmi)
-
-			volumeSource := &v1.HotplugVolumeSource{
-				DataVolume: &v1.DataVolumeSource{
-					Name: dv.Name,
-				},
-			}
-
-			// Add the volume
-			addOpts := &v1.AddVolumeOptions{
-				Name: volName,
-				Disk: &v1.Disk{
-					DiskDevice: v1.DiskDevice{
-						Disk: &v1.DiskTarget{Bus: v1.DiskBusSCSI},
+		Context("should be able to volume migrate a VM", func() {
+			addVolume := func(vmName, ns, volName, dvName string) {
+				volumeSource := &v1.HotplugVolumeSource{
+					DataVolume: &v1.DataVolumeSource{
+						Name: dvName,
 					},
-					//					Serial: volName,
-				},
-				VolumeSource: volumeSource,
-			}
-			Expect(virtClient.VirtualMachine(ns).AddVolume(context.Background(), vm.Name, addOpts)).ToNot(HaveOccurred())
-			waitForHotplugVol(vm.Name, vm.Namespace, volName)
-
-			dvDst := createBlankDV(virtClient, vm.Namespace, "2Gi")
-			By("Update volumes")
-			var index int
-			Eventually(func() int {
-				vm, err := virtClient.VirtualMachine(vm.Namespace).Get(context.Background(), vm.Name, metav1.GetOptions{})
-				Expect(err).ToNot(HaveOccurred())
-				for i, v := range vm.Spec.Template.Spec.Volumes {
-					if v.Name == volName {
-						index = i
-						return i
-					}
 				}
-				return -1
-			}).WithTimeout(120 * time.Second).WithPolling(2 * time.Second).Should(BeNumerically(">", -1))
-			p, err := patch.New(
-				patch.WithReplace(fmt.Sprintf("/spec/template/spec/volumes/%d/dataVolume/name", index), dvDst.Name),
-				patch.WithReplace("/spec/updateVolumesStrategy", virtv1.UpdateVolumesStrategyMigration),
-			).GeneratePayload()
-			Expect(err).ToNot(HaveOccurred())
-			vm, err = virtClient.VirtualMachine(vm.Namespace).Patch(context.Background(), vm.Name, types.JSONPatchType, p, metav1.PatchOptions{})
-			Expect(err).ToNot(HaveOccurred())
-			waitForMigrationToSucceed(virtClient, vm.Name, vm.Namespace)
+				// Add the volume
+				addOpts := &v1.AddVolumeOptions{
+					Name: volName,
+					Disk: &v1.Disk{
+						DiskDevice: v1.DiskDevice{
+							Disk: &v1.DiskTarget{Bus: v1.DiskBusSCSI},
+						},
+					},
+					VolumeSource: volumeSource,
+				}
+				Expect(virtClient.VirtualMachine(ns).AddVolume(context.Background(), vmName, addOpts)).ToNot(HaveOccurred())
+				waitForHotplugVol(vmName, ns, volName)
+			}
+			getIndexVol := func(vmName, ns, volName string) int {
+				var index int
+				// Loop if the hotplug volume has been added with the imperative API it might be still not present on the VM
+				Eventually(func() int {
+					vm, err := virtClient.VirtualMachine(ns).Get(context.Background(), vmName, metav1.GetOptions{})
+					Expect(err).ToNot(HaveOccurred())
+					for i, v := range vm.Spec.Template.Spec.Volumes {
+						if v.Name == volName {
+							index = i
+							return i
+						}
+					}
+					return -1
+				}).WithTimeout(60 * time.Second).WithPolling(2 * time.Second).Should(BeNumerically(">", -1))
+				return index
+			}
+
+			createFileOnHotpluggedVol := func(vmi *v1.VirtualMachineInstance, volName string) {
+				var device string
+				Eventually(func() string {
+					vmi, err := virtClient.VirtualMachineInstance(vmi.Namespace).Get(context.Background(), vmi.Name, metav1.GetOptions{})
+					Expect(err).ToNot(HaveOccurred())
+					for _, v := range vmi.Status.VolumeStatus {
+						if v.HotplugVolume == nil {
+							continue
+						}
+						if v.Name == volName {
+							device = v.Target
+							return v.Target
+						}
+					}
+					return ""
+				}).WithTimeout(60 * time.Second).WithPolling(2 * time.Second).ShouldNot(BeEmpty())
+
+				Expect(console.LoginToCirros(vmi)).To(Succeed())
+				Expect(console.RunCommand(vmi, "sudo mkfs.ext3 /dev/sda", 30*time.Second)).To(Succeed())
+				Expect(console.RunCommand(vmi, "mkdir test", 30*time.Second)).To(Succeed())
+				Expect(console.RunCommand(vmi, fmt.Sprintf("sudo mount -t ext3 /dev/%s /home/cirros/test", device), 30*time.Second)).To(Succeed())
+				Expect(console.RunCommand(vmi, "sudo chmod 777 /home/cirros/test", 30*time.Second)).To(Succeed())
+				Expect(console.RunCommand(vmi, "sudo chown cirros:cirros /home/cirros/test", 30*time.Second)).To(Succeed())
+				Expect(console.RunCommand(vmi, "printf 'test' &> /home/cirros/test/test", 30*time.Second)).To(Succeed())
+			}
+			checkFileOnHotpluggedVol := func(vmi *v1.VirtualMachineInstance) {
+				Expect(console.LoginToCirros(vmi)).To(Succeed())
+				Expect(console.RunCommand(vmi, "cat /home/cirros/test/test |grep test", 60*time.Second)).To(Succeed())
+			}
+
+			It("with a containerdisk and a hotplugged volume", func() {
+				const volName = "vol0"
+				ns := testsuite.GetTestNamespace(nil)
+				dv := createBlankDV(virtClient, ns, "2G")
+				vmi := libvmifact.NewCirros(
+					libvmi.WithNamespace(ns),
+					libvmi.WithInterface(libvmi.InterfaceDeviceWithMasqueradeBinding()),
+					libvmi.WithNetwork(virtv1.DefaultPodNetwork()),
+				)
+				vm := libvmi.NewVirtualMachine(vmi,
+					libvmi.WithRunStrategy(virtv1.RunStrategyAlways),
+				)
+				vm, err := virtClient.VirtualMachine(ns).Create(context.Background(), vm, metav1.CreateOptions{})
+				Expect(err).ToNot(HaveOccurred())
+				Eventually(matcher.ThisVM(vm), 360*time.Second, 1*time.Second).Should(matcher.BeReady())
+				libwait.WaitForSuccessfulVMIStart(vmi)
+
+				addVolume(vm.Name, vm.Namespace, volName, dv.Name)
+				createFileOnHotpluggedVol(vmi, volName)
+
+				dvDst := createBlankDV(virtClient, vm.Namespace, "2Gi")
+				By("Update volumes")
+				index := getIndexVol(vm.Name, vm.Namespace, volName)
+				p, err := patch.New(
+					patch.WithReplace(fmt.Sprintf("/spec/template/spec/volumes/%d/dataVolume/name", index), dvDst.Name),
+					patch.WithReplace("/spec/updateVolumesStrategy", virtv1.UpdateVolumesStrategyMigration),
+				).GeneratePayload()
+				Expect(err).ToNot(HaveOccurred())
+				vm, err = virtClient.VirtualMachine(vm.Namespace).Patch(context.Background(), vm.Name, types.JSONPatchType, p, metav1.PatchOptions{})
+				Expect(err).ToNot(HaveOccurred())
+				waitForMigrationToSucceed(virtClient, vm.Name, vm.Namespace)
+				checkFileOnHotpluggedVol(vmi)
+			})
+
+			DescribeTable("with a datavolume and an hotplugged datavolume migrating", func(srcBlock, dstBlock bool) {
+				ns := testsuite.GetTestNamespace(nil)
+				rootVolName := "root"
+				hpVolName := "hp"
+				var sc string
+				var exist bool
+				var volumeMode k8sv1.PersistentVolumeMode
+				if srcBlock {
+					sc, exist = libstorage.GetRWOBlockStorageClass()
+					volumeMode = k8sv1.PersistentVolumeBlock
+				} else {
+					sc, exist = libstorage.GetRWOFileSystemStorageClass()
+					volumeMode = k8sv1.PersistentVolumeFilesystem
+				}
+				Expect(exist).To(BeTrue())
+				rootDV := libdv.NewDataVolume(
+					libdv.WithRegistryURLSource(cd.DataVolumeImportUrlForContainerDisk(cd.ContainerDiskCirros)),
+					libdv.WithStorage(libdv.StorageWithStorageClass(sc),
+						libdv.StorageWithVolumeSize("1Gi"),
+						libdv.StorageWithVolumeMode(volumeMode),
+						libdv.StorageWithAccessMode(k8sv1.ReadWriteOnce),
+					),
+				)
+				vmi := libvmi.New(
+					libvmi.WithNamespace(ns),
+					libvmi.WithInterface(libvmi.InterfaceDeviceWithMasqueradeBinding()),
+					libvmi.WithNetwork(virtv1.DefaultPodNetwork()),
+					libvmi.WithResourceMemory("128Mi"),
+					libvmi.WithDataVolume(rootVolName, rootDV.Name),
+					libvmi.WithCloudInitNoCloud(libvmifact.WithDummyCloudForFastBoot()),
+				)
+				vm := libvmi.NewVirtualMachine(vmi,
+					libvmi.WithRunStrategy(virtv1.RunStrategyAlways),
+					libvmi.WithDataVolumeTemplate(rootDV),
+				)
+				vm, err := virtClient.VirtualMachine(ns).Create(context.Background(), vm, metav1.CreateOptions{})
+				Expect(err).ToNot(HaveOccurred())
+				Eventually(matcher.ThisVM(vm), 360*time.Second, 1*time.Second).Should(matcher.BeReady())
+				libwait.WaitForSuccessfulVMIStart(vmi)
+
+				hpDV := libdv.NewDataVolume(
+					libdv.WithBlankImageSource(),
+					libdv.WithStorage(libdv.StorageWithStorageClass(sc),
+						libdv.StorageWithVolumeSize("1G"),
+						libdv.StorageWithVolumeMode(volumeMode),
+						libdv.StorageWithAccessMode(k8sv1.ReadWriteOnce),
+					),
+				)
+				_, err = virtClient.CdiClient().CdiV1beta1().DataVolumes(ns).Create(context.Background(),
+					hpDV, metav1.CreateOptions{})
+				Expect(err).ToNot(HaveOccurred())
+				addVolume(vm.Name, vm.Namespace, hpVolName, hpDV.Name)
+				createFileOnHotpluggedVol(vmi, hpVolName)
+
+				indexRoot := getIndexVol(vm.Name, vm.Namespace, rootVolName)
+				indexHp := getIndexVol(vm.Name, vm.Namespace, hpVolName)
+
+				if dstBlock {
+					sc, exist = libstorage.GetRWOBlockStorageClass()
+					volumeMode = k8sv1.PersistentVolumeBlock
+					Expect(exist).To(BeTrue())
+				} else {
+					sc = testSc
+					volumeMode = k8sv1.PersistentVolumeFilesystem
+				}
+				dvRootDst := libdv.NewDataVolume(
+					libdv.WithBlankImageSource(),
+					libdv.WithStorage(libdv.StorageWithStorageClass(sc),
+						libdv.StorageWithVolumeSize("2Gi"),
+						libdv.StorageWithVolumeMode(volumeMode),
+						libdv.StorageWithAccessMode(k8sv1.ReadWriteOnce),
+					),
+				)
+				_, err = virtClient.CdiClient().CdiV1beta1().DataVolumes(ns).Create(context.Background(),
+					dvRootDst, metav1.CreateOptions{})
+				Expect(err).ToNot(HaveOccurred())
+				dvHpDst := libdv.NewDataVolume(
+					libdv.WithBlankImageSource(),
+					libdv.WithStorage(libdv.StorageWithStorageClass(sc),
+						libdv.StorageWithVolumeSize("2Gi"),
+						libdv.StorageWithVolumeMode(volumeMode),
+						libdv.StorageWithAccessMode(k8sv1.ReadWriteOnce),
+					),
+				)
+				_, err = virtClient.CdiClient().CdiV1beta1().DataVolumes(ns).Create(context.Background(),
+					dvHpDst, metav1.CreateOptions{})
+				Expect(err).ToNot(HaveOccurred())
+
+				p, err := patch.New(
+					patch.WithReplace("/spec/dataVolumeTemplates", []virtv1.DataVolumeTemplateSpec{}),
+					patch.WithReplace(fmt.Sprintf("/spec/template/spec/volumes/%d/dataVolume/name", indexRoot), dvRootDst.Name),
+					patch.WithReplace(fmt.Sprintf("/spec/template/spec/volumes/%d/dataVolume/name", indexHp), dvHpDst.Name),
+					patch.WithReplace("/spec/updateVolumesStrategy", virtv1.UpdateVolumesStrategyMigration),
+				).GeneratePayload()
+				Expect(err).ToNot(HaveOccurred())
+
+				By(fmt.Sprintf("Update root DV %s with %s and hotplug dv %s with %s", rootDV.Name, dvRootDst.Name, hpDV.Name, dvHpDst.Name))
+				vm, err = virtClient.VirtualMachine(vm.Namespace).Patch(context.Background(), vm.Name, types.JSONPatchType, p, metav1.PatchOptions{})
+				Expect(err).ToNot(HaveOccurred())
+				waitForMigrationToSucceed(virtClient, vm.Name, vm.Namespace)
+				checkFileOnHotpluggedVol(vmi)
+			},
+				Entry("from filesystem to filesystem", false, false),
+				Entry("from filesystem to block", false, true),
+				Entry("from block to filesystem", true, false),
+				Entry("from block to block", true, true),
+			)
 		})
 	})
 
@@ -1034,6 +1188,7 @@ func waitForMigrationToSucceed(virtClient kubecli.KubevirtClient, vmiName, ns st
 			return false
 		}
 
+		Expect(vmi.Status.MigrationState.Failed).To(BeFalse())
 		return true
 	}, 120*time.Second, time.Second).Should(BeTrue())
 }
