@@ -15,14 +15,16 @@ import (
 	"kubevirt.io/client-go/kubecli"
 
 	pkgUtil "kubevirt.io/kubevirt/pkg/util"
-	virtconfig "kubevirt.io/kubevirt/pkg/virt-config"
+	"kubevirt.io/kubevirt/pkg/virt-config/featuregate"
 	"kubevirt.io/kubevirt/pkg/virt-launcher/virtwrap/api"
+
 	"kubevirt.io/kubevirt/tests"
 	"kubevirt.io/kubevirt/tests/console"
 	"kubevirt.io/kubevirt/tests/decorators"
 	"kubevirt.io/kubevirt/tests/framework/kubevirt"
 	"kubevirt.io/kubevirt/tests/libkubevirt"
 	kvconfig "kubevirt.io/kubevirt/tests/libkubevirt/config"
+	"kubevirt.io/kubevirt/tests/libnode"
 	"kubevirt.io/kubevirt/tests/libvmifact"
 	"kubevirt.io/kubevirt/tests/libwait"
 	"kubevirt.io/kubevirt/tests/testsuite"
@@ -33,7 +35,7 @@ const (
 	cmdNumberUSBs   = "dmesg | grep -c idVendor=46f4"
 )
 
-var _ = Describe("[Serial][sig-compute][USB] host USB Passthrough", Serial, decorators.SigCompute, decorators.USB, func() {
+var _ = Describe("[sig-compute][USB] host USB Passthrough", Serial, decorators.SigCompute, decorators.USB, func() {
 	var virtClient kubecli.KubevirtClient
 	var config v1.KubeVirtConfiguration
 	var vmi *v1.VirtualMachineInstance
@@ -43,13 +45,13 @@ var _ = Describe("[Serial][sig-compute][USB] host USB Passthrough", Serial, deco
 		kv := libkubevirt.GetCurrentKv(virtClient)
 		config = kv.Spec.Configuration
 
-		nodeName := tests.NodeNameWithHandler()
+		nodeName := libnode.GetNodeNameWithHandler()
 		Expect(nodeName).ToNot(BeEmpty())
 
 		// Emulated USB devices only on c9s providers. Remove this when sig-compute 1.26 is the
 		// oldest sig-compute with test with.
 		// See: https://github.com/kubevirt/project-infra/pull/2922
-		stdout, err := tests.ExecuteCommandInVirtHandlerPod(nodeName, []string{"dmesg"})
+		stdout, err := libnode.ExecuteCommandInVirtHandlerPod(nodeName, []string{"dmesg"})
 		Expect(err).ToNot(HaveOccurred())
 		if strings.Count(stdout, "idVendor=46f4") == 0 {
 			Skip("No emulated USB devices present for functional test.")
@@ -60,9 +62,12 @@ var _ = Describe("[Serial][sig-compute][USB] host USB Passthrough", Serial, deco
 
 	AfterEach(func() {
 		// Make sure to delete the VMI before ending the test otherwise a device could still be taken
-		err := virtClient.VirtualMachineInstance(testsuite.NamespaceTestDefault).Delete(context.Background(), vmi.ObjectMeta.Name, metav1.DeleteOptions{})
+		const deleteTimeout = 180
+		err := virtClient.VirtualMachineInstance(
+			testsuite.NamespaceTestDefault).Delete(context.Background(), vmi.ObjectMeta.Name, metav1.DeleteOptions{})
 		Expect(err).ToNot(HaveOccurred(), failedDeleteVMI)
-		libwait.WaitForVirtualMachineToDisappearWithTimeout(vmi, 180)
+
+		libwait.WaitForVirtualMachineToDisappearWithTimeout(vmi, deleteTimeout)
 	})
 
 	Context("with usb storage", func() {
@@ -71,7 +76,7 @@ var _ = Describe("[Serial][sig-compute][USB] host USB Passthrough", Serial, deco
 
 			By("Adding the emulated USB device to the permitted host devices")
 			config.DeveloperConfiguration = &v1.DeveloperConfiguration{
-				FeatureGates: []string{virtconfig.HostDevicesGate},
+				FeatureGates: []string{featuregate.HostDevicesGate},
 			}
 			config.PermittedHostDevices = &v1.PermittedHostDevices{
 				USB: []v1.USBHostDevice{
@@ -81,8 +86,10 @@ var _ = Describe("[Serial][sig-compute][USB] host USB Passthrough", Serial, deco
 							{
 								Vendor:  "46f4",
 								Product: "0001",
-							}},
-					}},
+							},
+						},
+					},
+				},
 			}
 			kvconfig.UpdateKubeVirtConfigValueAndWait(config)
 
@@ -103,23 +110,24 @@ var _ = Describe("[Serial][sig-compute][USB] host USB Passthrough", Serial, deco
 			Expect(console.LoginToCirros(vmi)).To(Succeed())
 
 			By("Making sure the usb is present inside the VMI")
+			const expectTimeout = 15
 			Expect(console.SafeExpectBatch(vmi, []expect.Batcher{
 				&expect.BSnd{S: fmt.Sprintf("%s\n", cmdNumberUSBs)},
 				&expect.BExp{R: console.RetValue(fmt.Sprintf("%d", len(deviceNames)))},
-			}, 15)).To(Succeed(), "Device not found")
+			}, expectTimeout)).To(Succeed(), "Device not found")
 
 			By("Verifying ownership is properly set in the host")
-			domainXml, err := tests.GetRunningVMIDomainSpec(vmi)
+			domainXML, err := tests.GetRunningVMIDomainSpec(vmi)
 			Expect(err).ToNot(HaveOccurred())
 
-			for _, hostDevice := range domainXml.Devices.HostDevices {
+			for _, hostDevice := range domainXML.Devices.HostDevices {
 				if hostDevice.Type != api.HostDeviceUSB {
 					continue
 				}
 				addr := hostDevice.Source.Address
 				path := fmt.Sprintf("%sdev/bus/usb/00%s/00%s", pkgUtil.HostRootMount, addr.Bus, addr.Device)
 				cmd := []string{"stat", "--printf", `"%u %g"`, path}
-				stdout, err := tests.ExecuteCommandInVirtHandlerPod(vmi.Status.NodeName, cmd)
+				stdout, err := libnode.ExecuteCommandInVirtHandlerPod(vmi.Status.NodeName, cmd)
 				Expect(err).ToNot(HaveOccurred())
 				Expect(stdout).Should(Equal(`"107 107"`))
 			}
