@@ -23,7 +23,9 @@ package tests_test
 
 import (
 	"context"
+	"errors"
 	"net"
+	"syscall"
 	"time"
 
 	"kubevirt.io/kubevirt/pkg/virtctl/usbredir"
@@ -37,6 +39,7 @@ import (
 	v1 "kubevirt.io/api/core/v1"
 	"kubevirt.io/client-go/kubecli"
 	kvcorev1 "kubevirt.io/client-go/kubevirt/typed/core/v1"
+	"kubevirt.io/client-go/log"
 
 	"kubevirt.io/kubevirt/pkg/libvmi"
 
@@ -84,7 +87,7 @@ var _ = Describe("[crit:medium][vendor:cnv-qe@redhat.com][level:component][sig-c
 		})
 	})
 
-	Describe("[crit:medium][vendor:cnv-qe@redhat.com][level:component][QUARANTINE] A VirtualMachineInstance with usbredir support", decorators.Quarantine, func() {
+	Describe("[crit:medium][vendor:cnv-qe@redhat.com][level:component] A VirtualMachineInstance with usbredir support", func() {
 
 		var vmi *v1.VirtualMachineInstance
 		var name, namespace string
@@ -98,65 +101,86 @@ var _ = Describe("[crit:medium][vendor:cnv-qe@redhat.com][level:component][sig-c
 		})
 
 		It("Should fail when limit is reached", func() {
-			cancelFns := make([]context.CancelFunc, v1.UsbClientPassthroughMaxNumberOf+1)
-			errors := make([]chan error, v1.UsbClientPassthroughMaxNumberOf+1)
+			type session struct {
+				cancel  context.CancelFunc
+				connect chan struct{}
+				err     chan error
+			}
+
+			var tests []session
 			for i := 0; i <= v1.UsbClientPassthroughMaxNumberOf; i++ {
-				ctx, cancelFn := context.WithCancel(context.Background())
-				cancelFns[i] = cancelFn
-				errors[i] = make(chan error)
-				go runConnectGoroutine(virtClient, name, namespace, ctx, errors[i])
-				// avoid too fast requests which might get denied by server (to avoid flakyness)
-				time.Sleep(100 * time.Millisecond)
+			retry_loop:
+				for try := 0; try < 3; try++ {
+					ctx, cancelFn := context.WithCancel(context.Background())
+					test := session{
+						cancel:  cancelFn,
+						connect: make(chan struct{}),
+						err:     make(chan error),
+					}
+					ctx = context.WithValue(ctx, "connected", test.connect)
+					go runConnectGoroutine(virtClient, name, namespace, ctx, test.err)
+
+					if i == v1.UsbClientPassthroughMaxNumberOf {
+						// Last test is meant to fail.
+						tests = append(tests, test)
+						break
+					}
+
+					// Till the last test, all sockets must be connected
+					select {
+					case <-test.connect:
+						tests = append(tests, test)
+						break retry_loop
+					case err := <-test.err:
+						if !errors.Is(err, syscall.ECONNRESET) {
+							log.Log.Reason(err).Info("Failed early. Unexpected error.")
+							Fail("Improve error handling or fix underlying issue")
+						}
+						log.Log.Reason(err).Infof("Failed early. Try again (%d)", try)
+					case <-time.After(time.Second):
+						log.Log.Infof("Took too long. Try again (%d)", try)
+						test.cancel()
+					}
+
+				}
 			}
 
 			numOfErrors := 0
 			for i := 0; i <= v1.UsbClientPassthroughMaxNumberOf; i++ {
 				select {
-				case err := <-errors[i]:
+				case err := <-tests[i].err:
 					Expect(err).To(MatchError(ContainSubstring("websocket: bad handshake")))
 					numOfErrors++
 				case <-time.After(time.Second):
-					cancelFns[i]()
+					tests[i].cancel()
 				}
 			}
 			Expect(numOfErrors).To(Equal(1), "Only one connection should fail")
 		})
 
-		It("Should work in parallel", func() {
-			cancelFns := make([]context.CancelFunc, v1.UsbClientPassthroughMaxNumberOf)
-			errors := make([]chan error, v1.UsbClientPassthroughMaxNumberOf)
-			for i := 0; i < v1.UsbClientPassthroughMaxNumberOf; i++ {
-				errors[i] = make(chan error)
-				ctx, cancelFn := context.WithCancel(context.Background())
-				cancelFns[i] = cancelFn
-				go runConnectGoroutine(virtClient, name, namespace, ctx, errors[i])
-				// avoid too fast requests which might get denied by server (to avoid flakyness)
-				time.Sleep(100 * time.Millisecond)
-			}
-
-			for i := 0; i < v1.UsbClientPassthroughMaxNumberOf; i++ {
-				select {
-				case err := <-errors[i]:
-					Expect(err).ToNot(HaveOccurred())
-				case <-time.After(time.Second):
-					cancelFns[i]()
-				}
-			}
-		})
-
 		It("Should work several times", func() {
 			for i := 0; i < 4*v1.UsbClientPassthroughMaxNumberOf; i++ {
-				ctx, cancelFn := context.WithCancel(context.Background())
-				errch := make(chan error)
-				go runConnectGoroutine(virtClient, name, namespace, ctx, errch)
+			retry_loop:
+				for try := 0; try < 3; try++ {
+					ctx, cancelFn := context.WithCancel(context.Background())
+					errch := make(chan error)
+					go runConnectGoroutine(virtClient, name, namespace, ctx, errch)
 
-				select {
-				case err := <-errch:
-					Expect(err).ToNot(HaveOccurred())
-				case <-time.After(time.Second):
+					select {
+					case err := <-errch:
+						cancelFn()
+						time.Sleep(100 * time.Millisecond)
+						if try < 3 {
+							log.Log.Reason(err).Infof("Failed. Try again (%d)", try)
+						} else {
+							Fail("Tried 3 times. Something is wrong")
+						}
+					case <-time.After(time.Second):
+						cancelFn()
+						time.Sleep(100 * time.Millisecond)
+						break retry_loop
+					}
 				}
-				cancelFn()
-				time.Sleep(time.Second)
 			}
 		})
 	})
@@ -196,15 +220,25 @@ func usbredirConnect(
 		buf := make([]byte, 1024, 1024)
 
 		// write hello message to remote (VMI)
-		nw, err := conn.Write([]byte(helloMessageLocal))
-		Expect(err).ToNot(HaveOccurred())
-		Expect(nw).To(Equal(len(helloMessageLocal)))
+		if nw, err := conn.Write([]byte(helloMessageLocal)); err != nil {
+			return err
+		} else {
+			Expect(nw).To(Equal(len(helloMessageLocal)))
+		}
 
 		// reading hello message from remote (VMI)
-		nr, err := conn.Read(buf)
-		Expect(err).ToNot(HaveOccurred())
-		Expect(buf[0:nr]).ToNot(BeEmpty(), "response should not be empty")
-		Expect(buf[0:nr]).To(HaveLen(len(helloMessageRemote)))
+		if nr, err := conn.Read(buf); err != nil {
+			return err
+		} else {
+			Expect(buf[0:nr]).ToNot(BeEmpty(), "response should not be empty")
+			Expect(buf[0:nr]).To(HaveLen(len(helloMessageRemote)))
+		}
+
+		// Signal connected after read/write to be sure no TCP operation failed too
+		if connected, ok := inCtx.Value("connected").(chan struct{}); ok {
+			connected <- struct{}{}
+		}
+
 		select {
 		case <-inCtx.Done():
 			return inCtx.Err()
