@@ -1,3 +1,22 @@
+/*
+ * This file is part of the KubeVirt project
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ * Copyright The KubeVirt Authors
+ *
+ */
+
 package virtctl
 
 import (
@@ -25,13 +44,13 @@ import (
 	"kubevirt.io/kubevirt/tests/testsuite"
 )
 
-var _ = Describe("[sig-compute][virtctl]SSH", decorators.SigCompute, func() {
+var _ = VirtctlDescribe("[sig-compute]SSH", decorators.SigCompute, func() {
 	var pub ssh.PublicKey
 	var keyFile string
 	var virtClient kubecli.KubevirtClient
 
 	cmdNative := func(vmiName string) {
-		Expect(clientcmd.NewRepeatableVirtctlCommand(
+		Expect(newRepeatableVirtctlCommand(
 			"ssh",
 			"--local-ssh=false",
 			"--namespace", testsuite.GetTestNamespace(nil),
@@ -39,7 +58,7 @@ var _ = Describe("[sig-compute][virtctl]SSH", decorators.SigCompute, func() {
 			"--identity-file", keyFile,
 			"--known-hosts=",
 			"--command", "true",
-			vmiName,
+			"vmi/"+vmiName,
 		)()).To(Succeed())
 	}
 
@@ -57,10 +76,10 @@ var _ = Describe("[sig-compute][virtctl]SSH", decorators.SigCompute, func() {
 			if appendLocalSSH {
 				args = append(args, "--local-ssh=true")
 			}
-			args = append(args, vmiName)
+			args = append(args, "vmi/"+vmiName)
 
 			// The virtctl binary needs to run here because of the way local SSH client wrapping works.
-			// Running the command through NewRepeatableVirtctlCommand does not suffice.
+			// Running the command through newRepeatableVirtctlCommand does not suffice.
 			_, cmd, err := clientcmd.CreateCommandWithNS(testsuite.GetTestNamespace(nil), "virtctl", args...)
 			Expect(err).ToNot(HaveOccurred())
 			out, err := cmd.CombinedOutput()
@@ -80,7 +99,7 @@ var _ = Describe("[sig-compute][virtctl]SSH", decorators.SigCompute, func() {
 		Expect(libssh.DumpPrivateKey(priv, keyFile)).To(Succeed())
 	})
 
-	DescribeTable("should succeed to execute a command on the VM", func(cmdFn func(string)) {
+	DescribeTable("[test_id:11661]should succeed to execute a command on the VM", func(cmdFn func(string)) {
 		By("injecting a SSH public key into a VMI")
 		vmi := libvmifact.NewAlpineWithTestTooling(
 			libvmi.WithCloudInitNoCloud(libvmici.WithNoCloudUserData(libssh.RenderUserDataWithKey(pub))),
@@ -93,14 +112,14 @@ var _ = Describe("[sig-compute][virtctl]SSH", decorators.SigCompute, func() {
 		By("ssh into the VM")
 		cmdFn(vmi.Name)
 	},
-		Entry("using the native ssh method", decorators.NativeSsh, cmdNative),
-		Entry("using the local ssh method with --local-ssh flag", decorators.NativeSsh, cmdLocal(true)),
-		Entry("using the local ssh method without --local-ssh flag", decorators.ExcludeNativeSsh, cmdLocal(false)),
+		Entry("using the local ssh method", cmdLocal(false)),
+		Entry("using the local ssh method with --local-ssh=true flag", decorators.NativeSSH, cmdLocal(true)),
+		Entry("using the native ssh method with --local-ssh=false flag", decorators.NativeSSH, cmdNative),
 	)
 
-	It("local-ssh flag should be unavailable in virtctl", decorators.ExcludeNativeSsh, func() {
+	It("[test_id:11666]local-ssh flag should be unavailable in virtctl", decorators.ExcludeNativeSSH, func() {
 		// The built virtctl binary should be tested here, therefore clientcmd.CreateCommandWithNS needs to be used.
-		// Running the command through NewRepeatableVirtctlCommand would test the test binary instead.
+		// Running the command through newRepeatableVirtctlCommand would test the test binary instead.
 		_, cmd, err := clientcmd.CreateCommandWithNS(testsuite.NamespaceTestDefault, "virtctl", "ssh", "--local-ssh=false")
 		Expect(err).ToNot(HaveOccurred())
 		out, err := cmd.CombinedOutput()
