@@ -24,6 +24,7 @@ import (
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 
+	"kubevirt.io/kubevirt/pkg/libvmi"
 	"kubevirt.io/kubevirt/tests/libmigration"
 	"kubevirt.io/kubevirt/tests/libnet"
 	"kubevirt.io/kubevirt/tests/libvmifact"
@@ -32,33 +33,22 @@ import (
 	"kubevirt.io/kubevirt/tests/decorators"
 	"kubevirt.io/kubevirt/tests/framework/kubevirt"
 
-	"kubevirt.io/kubevirt/tests/framework/checks"
-
-	v1 "kubevirt.io/api/core/v1"
-
-	"kubevirt.io/client-go/kubecli"
-
 	"kubevirt.io/kubevirt/tests/console"
 )
 
 var _ = Describe("[sig-compute]vTPM", decorators.SigCompute, func() {
-	var virtClient kubecli.KubevirtClient
-	var err error
-
-	BeforeEach(func() {
-		virtClient = kubevirt.Client()
-	})
 
 	Context("[rfe_id:5168][crit:high][vendor:cnv-qe@redhat.com][level:component] with TPM VMI option enabled", func() {
-		It("[test_id:8607] should expose a functional emulated TPM which persists across migrations", func() {
+		It("[test_id:8607] should expose a functional emulated TPM which persists across migrations", decorators.RequiresTwoSchedulableNodes, decorators.Conformance, func() {
 			By("Creating a VMI with TPM enabled")
-			vmi := libvmifact.NewFedora(libnet.WithMasqueradeNetworking())
-			vmi.Spec.Domain.Devices.TPM = &v1.TPMDevice{}
+			vmi := libvmifact.NewFedora(
+				libnet.WithMasqueradeNetworking(),
+				libvmi.WithTPM(false),
+			)
 			vmi = libvmops.RunVMIAndExpectLaunch(vmi, 60)
 
-			By("Logging in as root")
-			err = console.LoginToFedora(vmi)
-			Expect(err).ToNot(HaveOccurred())
+			By("Logging in")
+			Expect(console.LoginToFedora(vmi)).To(Succeed())
 
 			By("Ensuring a TPM device is present")
 			Expect(console.SafeExpectBatch(vmi, []expect.Batcher{
@@ -66,6 +56,7 @@ var _ = Describe("[sig-compute]vTPM", decorators.SigCompute, func() {
 				&expect.BExp{R: "/dev/tpm0"},
 			}, 300)).To(Succeed(), "Could not find a TPM device")
 
+			const expectedState = "0x1EE66777C372B96BC74AC4CB892E0879FA3CCF6A2F53DB1D00FD18B264797F49"
 			By("Ensuring the TPM device is functional")
 			Expect(console.SafeExpectBatch(vmi, []expect.Batcher{
 				&expect.BSnd{S: "tpm2_pcrread sha256:15\n"},
@@ -73,18 +64,17 @@ var _ = Describe("[sig-compute]vTPM", decorators.SigCompute, func() {
 				&expect.BSnd{S: "tpm2_pcrextend 15:sha256=54d626e08c1c802b305dad30b7e54a82f102390cc92c7d4db112048935236e9c && echo 'do''ne'\n"},
 				&expect.BExp{R: "done"},
 				&expect.BSnd{S: "tpm2_pcrread sha256:15\n"},
-				&expect.BExp{R: "0x1EE66777C372B96BC74AC4CB892E0879FA3CCF6A2F53DB1D00FD18B264797F49"},
+				&expect.BExp{R: expectedState},
 			}, 300)).To(Succeed(), "PCR extension doesn't work correctly")
 
 			By("Migrating the VMI")
-			checks.SkipIfMigrationIsNotPossible()
-			migration := libmigration.New(vmi.Name, vmi.Namespace)
-			libmigration.RunMigrationAndExpectToCompleteWithDefaultTimeout(virtClient, migration)
+			libmigration.RunMigrationAndExpectToCompleteWithDefaultTimeout(kubevirt.Client(),
+				libmigration.New(vmi.Name, vmi.Namespace))
 
 			By("Ensuring the TPM is still functional and its state carried over")
 			Expect(console.SafeExpectBatch(vmi, []expect.Batcher{
 				&expect.BSnd{S: "tpm2_pcrread sha256:15\n"},
-				&expect.BExp{R: "0x1EE66777C372B96BC74AC4CB892E0879FA3CCF6A2F53DB1D00FD18B264797F49"},
+				&expect.BExp{R: expectedState},
 			}, 300)).To(Succeed(), "Migrating broke the TPM")
 		})
 	})
